@@ -38,12 +38,12 @@
 #include "broker/version.hh"
 
 #ifdef BROKER_WINDOWS
-#include <io.h>
-#define STDOUT_FILENO 1
-#define STDERR_FILENO 2
-#define isatty _isatty
+#  include <io.h>
+#  define STDOUT_FILENO 1
+#  define STDERR_FILENO 2
+#  define isatty _isatty
 #else
-#include <unistd.h>
+#  include <unistd.h>
 #endif
 
 namespace broker {
@@ -63,9 +63,9 @@ auto concat(Ts... xs) {
 }
 
 [[noreturn]] void throw_illegal_log_level(const char* var, const char* cstr) {
-  auto what
-    = concat("illegal value for environment variable ", var, ": '", cstr,
-             "' (legal values: 'trace', 'debug', 'info', 'warning', 'error')");
+  auto what =
+    concat("illegal value for environment variable ", var, ": '", cstr,
+           "' (legal values: 'trace', 'debug', 'info', 'warning', 'error')");
   throw std::invalid_argument(what);
 }
 
@@ -206,7 +206,7 @@ configuration::configuration() : configuration(skip_init) {
   init(0, nullptr);
 }
 
-configuration::configuration(configuration&& other)
+configuration::configuration(configuration&& other) noexcept
   : impl_(std::move(other.impl_)) {
   // cannot '= default' this because impl is incomplete in the header.
 }
@@ -233,7 +233,7 @@ void configuration::impl::init(int argc, char** argv) {
       return str.compare(0, 14, "--config-file=") != 0;
     };
     auto sep = std::stable_partition(args.begin(), args.end(), predicate);
-    if(sep != args.end()) {
+    if (sep != args.end()) {
       args_subset.assign(std::make_move_iterator(sep),
                          std::make_move_iterator(args.end()));
       args.erase(sep, args.end());
@@ -309,9 +309,8 @@ void configuration::impl::init(int argc, char** argv) {
     char* end = nullptr;
     auto value = strtol(env, &end, 10);
     if (errno == ERANGE || *end != '\0' || value < 0) {
-      auto what
-        = concat("invalid value for BROKER_OUTPUT_GENERATOR_FILE_CAP: ", env,
-                 " (expected a positive integer)");
+      auto what = concat("invalid value for BROKER_OUTPUT_GENERATOR_FILE_CAP: ",
+                         env, " (expected a positive integer)");
       throw std::invalid_argument(what);
     }
     set("broker.output-generator-file-cap", static_cast<size_t>(value));
@@ -444,28 +443,28 @@ void configuration::add_option(std::vector<std::string>* dst,
                                                           description);
 }
 
-void configuration::set(std::string key, timespan val) {
-  impl_->set(std::move(key), val);
+void configuration::set(std::string_view key, timespan val) {
+  impl_->set(key, val);
 }
 
-void configuration::set(std::string key, std::string val) {
-  impl_->set(std::move(key), std::move(val));
+void configuration::set(std::string_view key, std::string val) {
+  impl_->set(key, std::move(val));
 }
 
-void configuration::set(std::string key, std::vector<std::string> val) {
-  impl_->set(std::move(key), std::move(val));
+void configuration::set(std::string_view key, std::vector<std::string> val) {
+  impl_->set(key, std::move(val));
 }
 
-void configuration::set_i64(std::string key, int64_t val) {
-  impl_->set(std::move(key), val);
+void configuration::set_i64(std::string_view key, int64_t val) {
+  impl_->set(key, val);
 }
 
-void configuration::set_u64(std::string key, uint64_t val) {
-  impl_->set(std::move(key), val);
+void configuration::set_u64(std::string_view key, uint64_t val) {
+  impl_->set(key, val);
 }
 
-void configuration::set_bool(std::string key, bool val) {
-  impl_->set(std::move(key), val);
+void configuration::set_bool(std::string_view key, bool val) {
+  impl_->set(key, val);
 }
 
 std::optional<int64_t> configuration::read_i64(std::string_view key,
@@ -516,7 +515,7 @@ std::once_flag init_global_state_flag;
 
 void configuration::init_global_state() {
   std::call_once(init_global_state_flag, [] {
-    caf::init_global_meta_objects<caf::id_block::broker>();
+    caf::init_global_meta_objects<caf::id_block::broker_internal>();
     caf::io::middleman::init_global_meta_objects();
     caf::core::init_global_meta_objects();
   });
