@@ -189,7 +189,7 @@ void endpoint::deinit_ssl_api() {
 
 } // namespace broker
 
-namespace broker::internal{
+namespace broker::internal {
 
 /// Creates an SSL context for the connector.
 caf::net::openssl::ctx_ptr
@@ -449,22 +449,22 @@ private:
       switch (msg_type) {
         case connector_msg::connect: {
           BROKER_DEBUG("received connect event");
-          auto&& [eid, addr]
-            = from_source<connector_event_id, network_info>(src);
+          auto&& [eid, addr] =
+            from_source<connector_event_id, network_info>(src);
           mgr.connect(eid, addr);
           break;
         }
         case connector_msg::drop: {
           BROKER_DEBUG("received drop event");
-          auto&& [eid, addr]
-            = from_source<connector_event_id, network_info>(src);
+          auto&& [eid, addr] =
+            from_source<connector_event_id, network_info>(src);
           mgr.drop(eid, addr);
           break;
         }
         case connector_msg::listen: {
           BROKER_DEBUG("received listen event");
-          auto&& [eid, host, port, reuse_addr]
-            = from_source<connector_event_id, std::string, uint16_t, bool>(src);
+          auto&& [eid, host, port, reuse_addr] =
+            from_source<connector_event_id, std::string, uint16_t, bool>(src);
           mgr.listen(eid, host, port, reuse_addr);
           break;
         }
@@ -845,7 +845,6 @@ public:
             return read_result::stop;
           payload_size = 0;
           read_pos = 0;
-          read_size = 4;
           return reached_fin_state() ? read_result::stop : read_result::again;
         } else {
           return read_result::again;
@@ -982,17 +981,6 @@ struct connect_manager {
 
   connect_manager& operator=(const connect_manager&) = delete;
 
-  ~connect_manager() {
-    for (auto& entry : fdset) {
-      BROKER_DEBUG("close socket" << entry.fd);
-      caf::net::close(caf::net::socket{entry.fd});
-    }
-    for (auto& entry : pending_fdset) {
-      BROKER_DEBUG("close socket" << entry.fd);
-      caf::net::close(caf::net::socket{entry.fd});
-    }
-  }
-
   /// Returns the relative timeout for the next retry in milliseconds or -1.
   int next_timeout_ms() {
     if (retry_schedule.empty())
@@ -1025,7 +1013,7 @@ struct connect_manager {
                    << (event == read_mask ? "reading" : "writing")
                    << BROKER_ARG2("fd", i->first));
       if (auto fds_ptr = find_pollfd(i->first)) {
-        fds_ptr->events |= event;
+        fds_ptr->events = static_cast<short>(fds_ptr->events | event);
       } else {
         pending_fdset.emplace_back(pollfd{i->first, event, 0});
       }
@@ -1541,9 +1529,9 @@ bool connect_state::proceed_with_handshake(endpoint_id id, bool is_originator) {
               BROKER_DEBUG("detected redundant connection but "
                            "find_pending_handshake failed");
               send(wire_format::make_drop_conn_msg(
-                  this_peer(), ec::logic_error,
-                  "detected redundant connection but "
-                  "find_pending_handshake failed"));
+                this_peer(), ec::logic_error,
+                "detected redundant connection but "
+                "find_pending_handshake failed"));
               transition(&connect_state::err);
               return false;
             }
@@ -1766,7 +1754,8 @@ connector::connector(endpoint_id this_peer, broker_options broker_cfg,
               static_cast<int>(max_ssl_passphrase_size));
       ::abort();
     }
-    strcpy(ssl_passphrase_buf, ssl_cfg_->passphrase.c_str());
+    strncpy(ssl_passphrase_buf, ssl_cfg_->passphrase.c_str(),
+            max_ssl_passphrase_size);
   }
 }
 
@@ -1880,7 +1869,6 @@ public:
     }
   }
 
-
   ~ssl_lib_guard() {
     if (ssl_initialized_)
       endpoint::deinit_ssl_api();
