@@ -1,13 +1,11 @@
 #include "broker/internal/logger.hh" // Needs to come before CAF includes.
 
 #include <caf/actor.hpp>
-#include <caf/attach_stream_sink.hpp>
 #include <caf/behavior.hpp>
 #include <caf/error.hpp>
 #include <caf/event_based_actor.hpp>
 #include <caf/make_message.hpp>
 #include <caf/stateful_actor.hpp>
-#include <caf/sum_type.hpp>
 #include <caf/system_messages.hpp>
 #include <caf/unit.hpp>
 
@@ -57,8 +55,8 @@ master_state::master_state(
   backend_pointer bp, caf::actor parent, endpoint::clock* ep_clock,
   caf::async::consumer_resource<command_message> in_res,
   caf::async::producer_resource<command_message> out_res)
-  : output(this), metrics(ptr->system(), nm) {
-  super::init(ptr, this_endpoint, ep_clock, std::move(nm), std::move(parent),
+  : super(ptr), output(this), metrics(ptr->system(), nm) {
+  super::init(this_endpoint, ep_clock, std::move(nm), std::move(parent),
               std::move(in_res), std::move(out_res));
   super::init(output);
   clones_topic = store_name / topic::clone_suffix();
