@@ -13,7 +13,7 @@ std::vector<std::string> topic::split(const topic& t) {
       ++i;
       continue;
     }
-    if (j == std::string::npos)  {
+    if (j == std::string::npos) {
       result.push_back(t.str_.substr(i));
       break;
     }
@@ -79,11 +79,6 @@ topic operator/(const topic& lhs, const topic& rhs) {
   return result /= rhs;
 }
 
-bool convert(const topic& t, std::string& str) {
-  str = t.string();
-  return true;
-}
-
 namespace {
 
 constexpr caf::string_view internal_prefix = "<$>/local/";
@@ -119,6 +114,6 @@ topic topic::store_events() {
 
 } // namespace broker
 
-broker::topic operator "" _t(const char* str, size_t) {
-  return str;
+broker::topic operator"" _t(const char* str, size_t len) {
+  return broker::topic{std::string{str, len}};
 }
