@@ -7,25 +7,27 @@
 #include <chrono>
 #include <regex>
 
-#include <caf/test/io_dsl.hpp>
-
-#include "broker/atoms.hh"
 #include "broker/backend.hh"
 #include "broker/data.hh"
 #include "broker/defaults.hh"
-#include "broker/detail/clone_actor.hh"
-#include "broker/detail/master_actor.hh"
 #include "broker/endpoint.hh"
 #include "broker/error.hh"
 #include "broker/filter_type.hh"
+#include "broker/internal/clone_actor.hh"
+#include "broker/internal/master_actor.hh"
+#include "broker/internal/native.hh"
+#include "broker/internal/type_id.hh"
 #include "broker/internal_command.hh"
 #include "broker/store_event.hh"
 #include "broker/topic.hh"
 
+using broker::internal::native;
 using std::cout;
 using std::endl;
 using std::string;
 
+namespace atom = broker::internal::atom;
+
 using namespace broker;
 using namespace broker::detail;
 
@@ -86,18 +88,18 @@ bool operator==(const string_list& xs, const pattern_list& ys) {
 
 struct fixture : base_fixture {
   string_list log;
-  caf::actor logger;
+  worker logger;
 
   caf::timespan tick_interval = defaults::store::tick_interval;
 
   fixture() {
-    logger = ep.subscribe_nosync(
+    logger = ep.subscribe(
       // Topics.
       {topic::store_events()},
       // Init.
-      [](caf::unit_t&) {},
+      [] {},
       // Consume.
-      [this](caf::unit_t&, data_message msg) {
+      [this](data_message msg) {
         auto content = get_data(msg);
         if (auto insert = store_event::insert::make(content))
           log.emplace_back(to_string(insert));
@@ -109,11 +111,11 @@ struct fixture : base_fixture {
           FAIL("unknown event: " << to_string(content));
       },
       // Cleanup.
-      [](caf::unit_t&) {});
+      [](const error&) {});
   }
 
   ~fixture() {
-    anon_send_exit(logger, caf::exit_reason::user_shutdown);
+    anon_send_exit(internal::native(logger), caf::exit_reason::user_shutdown);
   }
 };
 
@@ -122,7 +124,7 @@ struct fixture : base_fixture {
 FIXTURE_SCOPE(local_store_master, fixture)
 
 TEST(local_master) {
-  auto core = ep.core();
+  auto core = native(ep.core());
   run(tick_interval);
   sched.inline_next_enqueue(); // ep.attach talks to the core (blocking)
   // ep.attach sends a message to the core that will then spawn a new master
@@ -154,7 +156,7 @@ TEST(local_master) {
   ds.clear();
   run(tick_interval);
   sched.inline_next_enqueue();
-  CHECK_EQUAL(error_of(ds.get("hello")), caf::error{ec::no_such_key});
+  CHECK_EQUAL(error_of(ds.get("hello")), ec::no_such_key);
   // test put_unique
   sched.inline_next_enqueue(); // ds.put_unique also talks to the master_actor
   CHECK_EQUAL(unbox(ds.put_unique("bar", "baz")), data{true});
@@ -169,18 +171,19 @@ TEST(local_master) {
                      "insert\\(foo, bar, baz, .+\\)",
                    }));
   // done
-  anon_send_exit(core, caf::exit_reason::user_shutdown);
+  caf::anon_send_exit(core, caf::exit_reason::user_shutdown);
 }
 
 FIXTURE_SCOPE_END()
 
+/*
 FIXTURE_SCOPE(store_master, net_fixture<fixture>)
 
 TEST(master_with_clone) {
   caf::timespan tick_interval = defaults::store::tick_interval;
   // --- phase 1: get state from fixtures and initialize cores -----------------
-  auto core1 = earth.ep.core();
-  auto core2 = mars.ep.core();
+  auto core1 = native(earth.ep.core());
+  auto core2 = native(mars.ep.core());
   // --- phase 2: connect earth and mars at CAF level --------------------------
   // Prepare publish and remote_actor calls.
   MESSAGE("prepare connections on earth and mars");
@@ -206,7 +209,7 @@ TEST(master_with_clone) {
     FAIL(
       "could not attach master: " << to_string(expected_ds_earth.error()));
   auto& ds_earth = *expected_ds_earth;
-  auto ms_earth = ds_earth.frontend();
+  auto ms_earth = native(ds_earth.frontend());
   // the core adds the master immediately to the topic and sends a stream
   // handshake
   run(tick_interval);
@@ -218,8 +221,8 @@ TEST(master_with_clone) {
   CHECK_EQUAL(value_of(ds_earth.get("test")), data{123});
   // --- phase 5: peer from earth to mars --------------------------------------
   auto foo_master = "foo" / topic::master_suffix();
-// Initiate handshake between core1 and core2.
-  earth.self->send(core1, atom::peer_v, core2_proxy);
+  // Initiate handshake between core1 and core2.
+  earth.self->send(core1, atom::peer_v, core2_proxy.node(), core2_proxy);
   run(tick_interval);
   // --- phase 6: attach a clone on mars ---------------------------------------
   mars.sched.inline_next_enqueue();
@@ -234,10 +237,18 @@ TEST(master_with_clone) {
   MESSAGE("put 'user' -> 'neverlord'");
   ds_mars.put("user", "neverlord");
   expect_on(mars, (atom::local, internal_command),
-            from(_).to(ds_mars.frontend()));
+            from(_).to(native(ds_mars.frontend())));
   auto run_until_idle = [&] {
-    // Calls idle() on masters and clones after switching to the ALM backend.
-    run(tick_interval);
+    auto idle = [&] {
+      return earth.deref<detail::master_actor_type>(ms_earth).state.idle()
+             && mars.deref<detail::clone_actor_type>(cl_mars).state.idle();
+    };
+    size_t iteration = 0;
+    do {
+      if (++iteration == 100)
+        FAIL("system reached no idle state within 100 ticks");
+      run(tick_interval);
+    } while (!idle());
   };
   run_until_idle();
   MESSAGE("once clone and master are idle, they are in sync");
@@ -255,8 +266,8 @@ TEST(master_with_clone) {
   mars.sched.after_next_enqueue(run_until_idle);
   CHECK_EQUAL(value_of(ds_mars.put_unique("bar", "unicorn")), data{false});
   // done
-  anon_send_exit(earth.ep.core(), caf::exit_reason::user_shutdown);
-  anon_send_exit(mars.ep.core(), caf::exit_reason::user_shutdown);
+  anon_send_exit(native(earth.ep.core()), caf::exit_reason::user_shutdown);
+  anon_send_exit(native(mars.ep.core()), caf::exit_reason::user_shutdown);
   exec_all();
   // check log
   CHECK_EQUAL(mars.log, earth.log);
@@ -268,3 +279,4 @@ TEST(master_with_clone) {
 }
 
 FIXTURE_SCOPE_END()
+*/
