@@ -76,6 +76,25 @@ kevent_fflags_dump(const struct kevent *kev)
         KEVFFL_DUMP(NOTE_EXEC);
         break;
 
+    case EVFILT_TIMER:
+        KEVFFL_DUMP(NOTE_SECONDS);
+        KEVFFL_DUMP(NOTE_USECONDS);
+        KEVFFL_DUMP(NOTE_NSECONDS);
+        KEVFFL_DUMP(NOTE_ABSOLUTE);
+        break;
+
+    case EVFILT_LIBKQUEUE:
+        KEVFFL_DUMP(NOTE_VERSION);
+        KEVFFL_DUMP(NOTE_VERSION_STR);
+        KEVFFL_DUMP(NOTE_THREAD_SAFE);
+        KEVFFL_DUMP(NOTE_FORK_CLEANUP);
+#ifndef NDEBUG
+        KEVFFL_DUMP(NOTE_DEBUG);
+        KEVFFL_DUMP(NOTE_DEBUG_PREFIX);
+        KEVFFL_DUMP(NOTE_DEBUG_FUNC);
+#endif
+        break;
+
     default:
         break;
     }
@@ -136,8 +155,22 @@ kevent_dump(const struct kevent *kev)
     return ((const char *) buf);
 }
 
+/** Process a single entry in the changelist
+ *
+ * @param[out] out    The knote the src kevent resolved to (if any).
+ * @param[in] kq      to apply the change against.
+ * @param[in] src     the change being applied.
+ * @return
+ *     - 1 on success.  Caller should add a receipt entry based on the kev
+ *       contained within the knote.  This is used for the EVFILT_LIBKQUEUE
+ *       to support its use as a query interface.
+ *     - 0 on success.  Caller should add a receipt entry if EV_RECEIPT was
+ *       set in the src kevent.
+ *     - -1 on failure.  Caller should add a receipt entry containing the error.
+ *       in the data field.
+ */
 static int
-kevent_copyin_one(struct kqueue *kq, const struct kevent *src)
+kevent_copyin_one(const struct knote **out, struct kqueue *kq, const struct kevent *src)
 {
     struct knote  *kn = NULL;
     struct filter *filt;
@@ -159,36 +192,39 @@ kevent_copyin_one(struct kqueue *kq, const struct kevent *src)
         if (src->flags & EV_ADD) {
             if ((kn = knote_new()) == NULL) {
                 errno = ENOENT;
+                *out = NULL;
                 return (-1);
             }
             memcpy(&kn->kev, src, sizeof(kn->kev));
             kn->kev.flags &= ~EV_ENABLE;
-            kn->kev.flags |= EV_ADD;//FIXME why?
             kn->kn_kq = kq;
             assert(filt->kn_create);
-            if (filt->kn_create(filt, kn) < 0) {
+            rv = filt->kn_create(filt, kn);
+            if (rv < 0) {
                 dbg_puts("kn_create failed");
 
                 kn->kn_flags |= KNFL_KNOTE_DELETED;
                 knote_release(kn);
 
                 errno = EFAULT;
+                *out = NULL;
                 return (-1);
             }
             knote_insert(filt, kn);
             dbg_printf("kn=%p - created knote %s", kn, kevent_dump(src));
+            *out = kn;
 
 /* XXX- FIXME Needs to be handled in kn_create() to prevent races */
             if (src->flags & EV_DISABLE) {
                 kn->kev.flags |= EV_DISABLE;
-                return (filt->kn_disable(filt, kn));
+                return filt->kn_disable(filt, kn);
             }
             //........................................
-
-            return (0);
+            return (rv);
         } else {
             dbg_printf("ident=%u - no knote found", (unsigned int)src->ident);
             errno = ENOENT;
+            *out = NULL;
             return (-1);
         }
     } else {
@@ -202,10 +238,20 @@ kevent_copyin_one(struct kqueue *kq, const struct kevent *src)
     } else if (src->flags & EV_ENABLE) {
         rv = knote_enable(filt, kn);
     } else if (src->flags & EV_ADD || src->flags == 0 || src->flags & EV_RECEIPT) {
-        kn->kev.udata = src->udata;
         rv = filt->kn_modify(filt, kn, src);
+        /*
+         * Implement changes common to all filters
+         */
+        if (rv == 0) {
+            /* update udata */
+            kn->kev.udata = src->udata;
+
+            /* sync up the dispatch bit */
+            COPY_FLAGS_BIT(kn->kev, (*src), EV_DISPATCH);
+        }
         dbg_printf("kn=%p - kn_modify rv=%d", kn, rv);
     }
+    *out = kn;
 
     return (rv);
 }
@@ -216,44 +262,81 @@ kevent_copyin(struct kqueue *kq, const struct kevent *changelist, int nchanges,
         struct kevent *eventlist, int nevents)
 {
     int status;
+    int rv;
     struct kevent *el_p = eventlist, *el_end = el_p + nevents;
 
     dbg_printf("nchanges=%d nevents=%d", nchanges, nevents);
 
+
+#define CHECK_EVENTLIST_SPACE \
+    do { \
+        if (el_p == el_end) { \
+            if (errno == 0) errno = EFAULT; \
+            return (-1); \
+        } \
+    } while (0)
+
     for (struct kevent const *cl_p = changelist, *cl_end = cl_p + nchanges;
          cl_p < cl_end;
          cl_p++) {
-        if (kevent_copyin_one(kq, cl_p) < 0) {
+        const struct knote *kn;
+
+        rv = kevent_copyin_one(&kn, kq, cl_p);
+        if (rv == 1) {
+            if (el_p == el_end) {
+                errno = EFAULT;
+                return (-1);
+            }
+            memcpy(el_p, &kn->kev, sizeof(*el_p));
+            el_p->flags |= EV_RECEIPT;
+            el_p++;
+
+        } else if (rv < 0) {
             dbg_printf("errno=%s", strerror(errno));
+            /*
+             * We're out of kevent entries, just return -1 and leave
+             * the errno set.  This is... odd, because it means the
+             * caller won't have any idea which entries in the
+             * changelist were processed.  But I guess the
+             * requirement here is for the caller to always provide
+             * a kevent array with >= entries as the changelist.
+             */
+            if (el_p == el_end)
+                return (-1);
             status = errno;
-        } else if (cl_p->flags & EV_RECEIPT) {
-            status = 0;
-        } else {
-            continue;
-        }
+            errno = 0; /* Reset back to 0 if we recorded the error as a kevent */
+
+        receipt:
+            memcpy(el_p, cl_p, sizeof(*el_p));
+            el_p->flags |= EV_ERROR; /* This is set both on error and for EV_RECEIPT */
+            el_p->data = status;
+            el_p++;
 
         /*
-         * We're out of kevent entries, just return -1 and leave
-         * the errno set.  This is... odd, because it means the
-         * caller won't have any idea which entries in the
-         * changelist were processed.  But I guess the
-         * requirement here is for the caller to always provide
-         * a kevent array with >= entries as the changelist.
+         * This allows our custom filter to create eventlist
+         * entries in response to queries.
          */
-        if (el_p == el_end)
-            return (-1);
-
-        memcpy(el_p, cl_p, sizeof(*cl_p));
-        el_p->flags |= EV_ERROR; /* This is set both on error and for EV_RECEIPT */
-        el_p->data = status;
-        el_p++;
-
-        errno = 0; /* Reset back to 0 if we recorded the error as a kevent */
+        } else if (cl_p->flags & EV_RECEIPT) {
+            status = 0;
+            if (el_p == el_end) {
+                errno = EFAULT;
+                return (-1);
+            }
+            goto receipt;
+        }
     }
 
     return (el_p - eventlist);
 }
 
+#ifndef _WIN32
+static void
+kevent_release_kq_mutex(void *kq)
+{
+    kqueue_unlock((struct kqueue *)kq);
+}
+#endif
+
 int VISIBLE
 kevent(int kqfd, const struct kevent *changelist, int nchanges,
         struct kevent *eventlist, int nevents,
@@ -262,13 +345,14 @@ kevent(int kqfd, const struct kevent *changelist, int nchanges,
     struct kqueue *kq;
     struct kevent *el_p, *el_end;
     int rv = 0;
+#ifndef _WIN32
+    int prev_cancel_state;
+#endif
 #ifndef NDEBUG
     static atomic_uint _kevent_counter = 0;
     unsigned int myid = 0;
-
     (void) myid;
 #endif
-
     /* deal with ubsan "runtime error: applying zero offset to null pointer" */
     if (eventlist) {
         if (nevents > MAX_KEVENT)
@@ -281,17 +365,46 @@ kevent(int kqfd, const struct kevent *changelist, int nchanges,
     }
     if (!changelist) changelist = &null_kev;
 
+#ifndef _WIN32
+    prev_cancel_state = pthread_setcancelstate(PTHREAD_CANCEL_DISABLE, NULL);
+#endif
+    /*
+     * Grab the global mutex.  This prevents
+     * any operations that might free the
+     * kqueue from progressing.
+     */
+    if (libkqueue_thread_safe)
+        tracing_mutex_lock(&kq_mtx);
+
     /* Convert the descriptor into an object pointer */
     kq = kqueue_lookup(kqfd);
     if (kq == NULL) {
         errno = ENOENT;
+        if (libkqueue_thread_safe)
+            tracing_mutex_unlock(&kq_mtx);
+#ifndef _WIN32
+        pthread_setcancelstate(prev_cancel_state, NULL);
+#endif
         return (-1);
     }
 
+    kqueue_lock(kq);
+
+#ifndef _WIN32
+    pthread_cleanup_push(kevent_release_kq_mutex, kq);
+#endif
+
+    /*
+     * We no longer need the global mutex as
+     * nothing else can use this kqueue until
+     * we release the lock.
+     */
+    if (libkqueue_thread_safe)
+        tracing_mutex_unlock(&kq_mtx);
 #ifndef NDEBUG
-    if (DEBUG_KQUEUE) {
+    if (libkqueue_debug) {
         myid = atomic_inc(&_kevent_counter);
-        dbg_printf("--- kevent %u --- (nchanges = %d nevents = %d)", myid, nchanges, nevents);
+        dbg_printf("--- START kevent %u --- (nchanges = %d nevents = %d)", myid, nchanges, nevents);
     }
 #endif
 
@@ -299,9 +412,12 @@ kevent(int kqfd, const struct kevent *changelist, int nchanges,
      * Process each kevent on the changelist.
      */
     if (nchanges > 0) {
-        kqueue_lock(kq);
+        /*
+         * Grab the kqueue specific mutex, this
+         * prevents any operations on the specific
+         * kqueue from progressing.
+         */
         rv = kevent_copyin(kq, changelist, nchanges, el_p, el_end - el_p);
-        kqueue_unlock(kq);
         dbg_printf("(%u) kevent_copyin rv=%d", myid, rv);
         if (rv < 0)
             goto out;
@@ -315,12 +431,23 @@ kevent(int kqfd, const struct kevent *changelist, int nchanges,
      * the changelist, copy events out.
      */
     if ((el_end - el_p) > 0) {
+        /*
+         * Allow cancellation in kevent_wait as we
+         * may be waiting a long time for the thread
+         * to exit...
+         */
+#ifndef _WIN32
+        (void)pthread_setcancelstate(prev_cancel_state, NULL);
+        if (prev_cancel_state == PTHREAD_CANCEL_ENABLE)
+            pthread_testcancel();
+#endif
         rv = kqops.kevent_wait(kq, nevents, timeout);
+#ifndef _WIN32
+        (void)pthread_setcancelstate(PTHREAD_CANCEL_DISABLE, NULL);
+#endif
         dbg_printf("kqops.kevent_wait rv=%i", rv);
         if (likely(rv > 0)) {
-            kqueue_lock(kq);
             rv = kqops.kevent_copyout(kq, rv, el_p, el_end - el_p);
-            kqueue_unlock(kq);
             dbg_printf("(%u) kevent_copyout rv=%i", myid, rv);
             if (rv >= 0) {
                 el_p += rv;             /* Add events from copyin */
@@ -342,7 +469,7 @@ kevent(int kqfd, const struct kevent *changelist, int nchanges,
     }
 
 #ifndef NDEBUG
-    if (DEBUG_KQUEUE && (rv > 0)) {
+    if (libkqueue_debug && (rv > 0)) {
         int n;
 
         dbg_printf("(%u) returning %zu events", myid, el_p - eventlist);
@@ -353,6 +480,17 @@ kevent(int kqfd, const struct kevent *changelist, int nchanges,
 #endif
 
 out:
+#ifndef _WIN32
+    pthread_cleanup_pop(0);
+#endif
+    kqueue_unlock(kq);
     dbg_printf("--- END kevent %u ret %d ---", myid, rv);
+
+#ifndef _WIN32
+    pthread_setcancelstate(prev_cancel_state, NULL);
+    if (prev_cancel_state == PTHREAD_CANCEL_ENABLE)
+        pthread_testcancel();
+#endif
+
     return (rv);
 }
