@@ -17,6 +17,8 @@
 #define _GNU_SOURCE
 #include <poll.h>
 #include <signal.h>
+
+#include <inttypes.h>
 #include <sys/prctl.h>
 #include <sys/resource.h>
 
@@ -30,20 +32,25 @@
  */
 static __thread struct epoll_event epoll_events[MAX_KEVENT];
 
-extern pthread_mutex_t kq_mtx;
 /*
  * Monitoring thread that takes care of cleaning up kqueues (on linux only)
  */
 static pthread_t monitoring_thread;
 static pid_t monitoring_tid; /* Monitoring thread */
-pthread_once_t monitoring_thread_initialized = PTHREAD_ONCE_INIT;
-pthread_cond_t monitoring_thread_cond = PTHREAD_COND_INITIALIZER;
+
+static pthread_mutex_t monitoring_thread_mtx = PTHREAD_MUTEX_INITIALIZER;
+static pthread_cond_t monitoring_thread_cond = PTHREAD_COND_INITIALIZER;
+
+enum thread_exit_state {
+    THREAD_EXIT_STATE_SELF_CANCEL = 0,
+    THREAD_EXIT_STATE_CANCEL_LOCKED,
+    THREAD_EXIT_STATE_CANCEL_UNLOCKED,
+};
 
 /*
- * Number of active kqueues.
- * When the last kqueue is closed, the monitoring thread can be stopped.
+ * Monitoring thread is exiting because the process is terminating
  */
-static unsigned int kqueue_cnt = 0;
+static enum thread_exit_state monitoring_thread_state;
 
 /*
  * Map for kqueue pipes where index is the read side (for which signals are received)
@@ -57,19 +64,112 @@ static int *fd_map;
 /*
  * Map kqueue id to counter for kq cleanups.
  * When use counter is at 0, cleanup can be performed by signal handler.
- * Otherwise, it means cleanup was already performed for this FD in linux_kqueue_free.
+ * Otherwise, it means cleanup was already performed for this FD in linux_kqueue_reused.
  */
 static unsigned int *fd_use_cnt;
 
 static int nb_max_fd;
 
 static void
-linux_kqueue_cleanup(struct kqueue *kq);
-
-static bool end_monitoring_thread = false;
+linux_kqueue_free(struct kqueue *kq);
 
 static void
-monitoring_thread_kq_cleanup(int signal_fd, bool ignore_use_count)
+monitoring_thread_cleanup(UNUSED void *arg)
+{
+    struct kqueue *kq, *kq_tmp;
+
+    /*
+     * If the entire process is exiting, then free all
+     * the kqueues
+     *
+     * We do this because we don't reliably receive all the
+     * close MONITORING_THREAD_SIGNALs before the process
+     * exits, and this avoids ASAN or valgrind raising
+     * spurious memory leaks.
+     *
+     * If the user _hasn't_ closed a KQ fd, then we don't
+     * free the underlying memory, and it'll be correctly
+     * reported as a memory leak.
+     */
+    if ((monitoring_thread_state == THREAD_EXIT_STATE_CANCEL_LOCKED) ||
+        (monitoring_thread_state == THREAD_EXIT_STATE_CANCEL_UNLOCKED)) {
+
+        /*
+         * Keep the assertion in kqueue_free happy
+         */
+        if (monitoring_thread_state == THREAD_EXIT_STATE_CANCEL_UNLOCKED)
+            tracing_mutex_lock(&kq_mtx);
+
+        LIST_FOREACH_SAFE(kq, &kq_list, kq_entry, kq_tmp) {
+            /*
+             * We only cleanup kqueues where their file descriptor
+             * has been closed.
+             *
+             * This is necessary because we can be told to exit
+             * before the monitoring thread has a chance to process
+             * the signal indicating that a kqueue has been
+             * cleaned up, and this can lead to spurious reports
+             * from LSAN.
+             *
+             * We only cleanup kqueues where the file descriptor has
+             * been closed, because other kqueues may be in the
+             * middle of operations with kq->kq_mtx held, and
+             * attempting to clean them up would cause a deadlock.
+             *
+             * These kqueues are legitimate leaks, and should have
+             * been freed by the user application before it exited.
+             */
+            dbg_printf("kq=%p - fd=%i explicitly checking for closeure", kq, kq->kq_id);
+            if (fcntl(kq->kq_id, F_GETFD) < 0) {
+                dbg_printf("kq=%p - fd=%i forcefully cleaning up, current use_count=%u: %s",
+                           kq,
+                           kq->kq_id, fd_use_cnt[kq->kq_id],
+                           errno == EBADF ? "File descriptor already closed" : strerror(errno));
+                fd_use_cnt[kq->kq_id] = 0;
+            } else {
+                /*
+                 * If there's no use cnt for the kqueue then something
+                 * has gone very wrong.
+                 */
+                assert(fd_use_cnt[kq->kq_id] > 0);
+            }
+
+            if (fd_use_cnt[kq->kq_id] == 0) {
+                dbg_printf("kq=%p - fd=%i use_count=%u cleaning up...", kq, kq->kq_id, fd_use_cnt[kq->kq_id]);
+                kqueue_free(kq);
+            } else {
+                dbg_printf("kq=%p - fd=%i is alive use_count=%u.  Skipping, this is likely a leak...",
+                           kq, kq->kq_id, fd_use_cnt[kq->kq_id]);
+            }
+        }
+
+        if (monitoring_thread_state == THREAD_EXIT_STATE_CANCEL_UNLOCKED)
+            tracing_mutex_unlock(&kq_mtx);
+    }
+
+    dbg_printf("tid=%u - monitoring thread exiting (%s)",
+               monitoring_tid,
+               monitoring_thread_state == THREAD_EXIT_STATE_SELF_CANCEL ? "no kqueues" : "process term");
+    /* Free thread resources */
+    free(fd_map);
+    fd_map = NULL;
+    free(fd_use_cnt);
+    fd_use_cnt = NULL;
+
+    /* Reset so that thread can be restarted */
+    monitoring_tid = 0;
+
+    if (monitoring_thread_state == THREAD_EXIT_STATE_CANCEL_LOCKED)
+        tracing_mutex_unlock(&kq_mtx);
+}
+
+
+/** Clean up a kqueue from the perspective of the monitoring thread
+ *
+ * Called with the kq_mtx held.
+ */
+static void
+monitoring_thread_kqueue_cleanup(int signal_fd)
 {
     int fd;
     struct kqueue *kq;
@@ -82,94 +182,55 @@ monitoring_thread_kq_cleanup(int signal_fd, bool ignore_use_count)
     if (fd < 0) {
        /* Should not happen */
         dbg_printf("fd=%i - not a known FD", fd);
-        goto check_count;
+        return;
     }
 
     kq = kqueue_lookup(fd);
     if (!kq) {
         /* Should not happen */
         dbg_printf("fd=%i - no kqueue associated", fd);
-        goto check_count;
+        assert(0);
+        return;
     }
 
     /*
-     * If kqueue instance for this FD hasn't been cleaned yet
-     *
-     * The issue the fd_use_cnt array prevents, is where kqueue
-     * allocates a KQ, and takes the opportunity to cleanup an
-     * old KQ instance, and this happens before the monitoring
-     * thread is woken up to reap the KQ itself.
-     *
-     * If the KQ has already been freed, we don't want to do
-     * anything here, as that will destroy the newly allocated
-     * KQ that shares an identifier with the old KQ.
-     *
-     * It's a counter because multiple signals may be queued.
+     * We should never have more pending signals than we have
+     * allocated kqueues against a given ID.
      */
-    if (ignore_use_count || (fd_use_cnt[fd] == 0)) {
-        dbg_printf("kq=%p - fd=%i use_count=%u cleaning up...", kq, fd, fd_use_cnt[fd]);
+    assert(fd_use_cnt[kq->kq_id] > 0);
+
+    /*
+     * Decrement use counter as signal handler has been run for
+     * this FD.  We rely on using an RT signal so that multiple
+     * signals are queued.
+     *
+     * Use count is tracked with the kq_id.
+     */
+    fd_use_cnt[kq->kq_id]--;
+
+    /*
+     * If kqueue instance for this FD hasn't been cleaned up yet
+     *
+     * When the main kqueue code frees a kq, the file descriptor
+     * of the kq often gets reused.
+     *
+     * We maintain a count of how many allocations have been
+     * performed against a given file descriptor ID, and only
+     * free the kqueue here if that count is zero.
+     */
+    if (fd_use_cnt[kq->kq_id] == 0) {
+        dbg_printf("kq=%p - fd=%i use_count=%u cleaning up...", kq, fd, fd_use_cnt[kq->kq_id]);
         kqueue_free(kq);
     } else {
-        dbg_printf("kq=%p - fd=%i use_count=%u skipping...", kq, fd, fd_use_cnt[fd]);
+        dbg_printf("kq=%p - fd=%i use_count=%u skipping...", kq, fd, fd_use_cnt[kq->kq_id]);
     }
-
-check_count:
-    /*
-     * Forcefully cleaning up like this breaks use counting
-     * so we reset the use count to 0, and don't allow it to
-     * go below 0 if we later receive delayed signals.
-     */
-    if (ignore_use_count) {
-        fd_use_cnt[fd] = 0;
-    } else if (fd_use_cnt[fd] > 0) {
-        fd_use_cnt[fd]--; /* Decrement use counter as signal handler has been run for this FD */
-    }
-
-    /*
-     * Stop thread if all kqueues have been closed
-     */
-    if (kqueue_cnt == 0) end_monitoring_thread = true;
-}
-
-static void
-monitoring_thread_cleanup(void *arg)
-{
-    int i;
-
-    /* Reset so that thread can be restarted */
-    monitoring_thread_initialized = PTHREAD_ONCE_INIT;
-
-    for (i = 0; i < nb_max_fd; i++) {
-        if (fd_use_cnt[i] > 0) {
-            int fd;
-
-            fd = fd_map[i];
-            dbg_printf("Checking rfd=%i wfd=%i", i, fd);
-            if (fcntl(fd, F_GETFD) < 0) {
-                dbg_printf("fd=%i - forcefully cleaning up, use_count=%u: %s",
-                           fd, fd_use_cnt[fd], strerror(errno));
-                fd_use_cnt[fd] = 0;
-                monitoring_thread_kq_cleanup(i, true);
-                fd_use_cnt[fd] = 0;
-             }
-        }
-    }
-
-    dbg_printf("tid=%u - monitoring thread exiting", monitoring_tid);
-    /* Free thread resources */
-    free(fd_map);
-    fd_map = NULL;
-    free(fd_use_cnt);
-    fd_use_cnt = NULL;
-
-    (void) pthread_mutex_unlock(&kq_mtx);
 }
 
 /*
  * Monitoring thread that loops on waiting for signals to be received
  */
 static void *
-monitoring_thread_loop(void *arg)
+monitoring_thread_loop(UNUSED void *arg)
 {
     int res = 0;
     siginfo_t info;
@@ -193,8 +254,6 @@ monitoring_thread_loop(void *arg)
     sigemptyset(&monitoring_sig_set);
     sigaddset(&monitoring_sig_set, MONITORING_THREAD_SIGNAL);
 
-    end_monitoring_thread = false;    /* reset */
-
     monitoring_tid = syscall(SYS_gettid);
 
     dbg_printf("tid=%u - monitoring thread started", monitoring_tid);
@@ -216,11 +275,11 @@ monitoring_thread_loop(void *arg)
     /*
      * Now that thread is initialized, let kqueue init resume
      */
-    pthread_mutex_lock(arg);    /* Must try to lock to ensure parent is waiting on signal */
+    pthread_mutex_lock(&monitoring_thread_mtx);    /* Must try to lock to ensure parent is waiting on signal */
     pthread_cond_signal(&monitoring_thread_cond);
-    pthread_mutex_unlock(arg);
-    pthread_detach(pthread_self());
+    pthread_mutex_unlock(&monitoring_thread_mtx);
 
+    monitoring_thread_state = THREAD_EXIT_STATE_CANCEL_UNLOCKED;
     pthread_cleanup_push(monitoring_thread_cleanup, NULL)
     while (true) {
         /*
@@ -229,38 +288,168 @@ monitoring_thread_loop(void *arg)
          * should be performed on the kqueue.
          */
         res = sigwaitinfo(&monitoring_sig_set, &info);
-        (void) pthread_mutex_lock(&kq_mtx);
-        if (res != -1) {
-            dbg_printf("fd=%i - freeing kqueue due to fd closure", fd_map[info.si_fd]);
-            monitoring_thread_kq_cleanup(info.si_fd, false);
-        } else {
-            dbg_perror("sigwaitinfo returned early");
+        if (res == -1) {
+            dbg_printf("sigwaitinfo(2): %s", strerror(errno));
+            continue;
         }
 
-        if (end_monitoring_thread)
+        /*
+         * Don't allow cancellation in the middle of cleaning up resources
+         */
+        pthread_setcancelstate(PTHREAD_CANCEL_DISABLE, NULL);
+        tracing_mutex_lock(&kq_mtx);
+        dbg_printf("fd=%i - freeing kqueue due to fd closure (signal) for sfd=%i ", fd_map[info.si_fd], info.si_fd);
+
+        /*
+         * Release resources used by this kqueue
+         */
+        monitoring_thread_kqueue_cleanup(info.si_fd);
+
+        /*
+         * Exit if there are no more kqueues to monitor
+         */
+        if (kq_cnt == 0)
             break;
 
-        (void) pthread_mutex_unlock(&kq_mtx);
+        tracing_mutex_unlock(&kq_mtx);
+        pthread_setcancelstate(PTHREAD_CANCEL_ENABLE, NULL);
     }
-    pthread_cleanup_pop(true);
+
+    /*
+     * Ensure that any cancellation requests are acted on
+     */
+    monitoring_thread_state = THREAD_EXIT_STATE_CANCEL_LOCKED;
+    pthread_setcancelstate(PTHREAD_CANCEL_ENABLE, NULL);
+    pthread_testcancel();
+
+    monitoring_thread_state = THREAD_EXIT_STATE_SELF_CANCEL;
+    pthread_cleanup_pop(true); /* Executes the cleanup function (monitoring_thread_cleanup) */
+    res = pthread_detach(pthread_self());
+    if (res != 0)
+        dbg_printf("pthread_detach(3): %s", strerror(res));
+    tracing_mutex_unlock(&kq_mtx);
 
     return NULL;
 }
 
-static void
+static int
 linux_kqueue_start_thread(void)
 {
-    static pthread_mutex_t  mt_mtx = PTHREAD_MUTEX_INITIALIZER;
-
-    pthread_mutex_lock(&mt_mtx);
-
-    if (pthread_create(&monitoring_thread, NULL, &monitoring_thread_loop, &mt_mtx)) {
+    pthread_mutex_lock(&monitoring_thread_mtx);
+    if (pthread_create(&monitoring_thread, NULL, monitoring_thread_loop, NULL)) {
          dbg_perror("linux_kqueue_start_thread failure");
-    }
+         pthread_mutex_unlock(&monitoring_thread_mtx);
 
+         return (-1);
+    }
     /* Wait for thread creating to be done as we need monitoring_tid to be available */
-    pthread_cond_wait(&monitoring_thread_cond, &mt_mtx); /* unlocks mt_mtx allowing child to lock it */
-    pthread_mutex_unlock(&mt_mtx);
+    pthread_cond_wait(&monitoring_thread_cond, &monitoring_thread_mtx); /* unlocks mt_mtx allowing child to lock it */
+    pthread_mutex_unlock(&monitoring_thread_mtx);
+
+    return (0);
+}
+
+/** Free kqueues on fork
+ *
+ * Called with kq_mtx held.
+ */
+static void
+linux_libkqueue_fork(void)
+{
+    struct kqueue *kq, *kq_tmp;
+
+    /*
+     * We don't have to cancel the monitor thread here
+     * as fork() typically only duplicates the thread
+     * which called it.
+     *
+     * Ensure we don't try and cancel it on exit by
+     * clearing the thread id.
+     *
+     * We don't need to lock the kq_mtx here as we're in
+     * the child, and none of our threads will have been
+     * duplicated.
+     */
+    monitoring_tid = 0;
+
+    /*
+     * If the process has been forked, then we need
+     * to destroy all of the kqueue instances in
+     * the fork.
+     *
+     * This replicates the behaviour of real kqueues
+     * on FreeBSD, and also prevents spurious leak
+     * reports being raised by LSAN.
+     */
+    LIST_FOREACH_SAFE(kq, &kq_list, kq_entry, kq_tmp) {
+        dbg_printf("kq=%p - cleaning up on fork", kq);
+
+        /*
+         * There's very limited cleanups we can do
+         * here, as we're only allowed to call
+         * async-signal-safe functions in this
+         * handler.
+         *
+         * This means any functions which alloc or
+         * free memory are ruled out, meaning we
+         * can't release any of the memory allocated
+         * to the kqueues or filters.
+         *
+         * Fortunately close() is async-signal-safe.
+         */
+        close(kq->epollfd);
+        kq->epollfd = -1;
+
+        if ((kq->pipefd[0] > 0) && (close(kq->pipefd[0]) < 0))
+            dbg_perror("close(2)");
+        kq->pipefd[0] = -1;
+
+        if ((kq->pipefd[1] > 0) && (close(kq->pipefd[1]) < 0))
+            dbg_perror("close(2)");
+        kq->pipefd[1] = -1;
+    }
+}
+
+/*
+ * We have to use this instead of pthread_detach as there
+ * seems to be some sort of race with LSAN and thread cleanup
+ * on exit, and if we don't explicitly join the monitoring
+ * thread, LSAN reports kqueues as leaked.
+ */
+static void
+linux_libkqueue_free(void)
+{
+    pid_t tid;
+
+    tracing_mutex_lock(&kq_mtx);
+    tid = monitoring_tid; /* Gets trashed when the thread exits */
+    if (tid) {
+        void *retval;
+        int ret;
+
+        dbg_printf("tid=%u - cancelling", tid);
+        ret = pthread_cancel(monitoring_thread);
+        if (ret != 0)
+           dbg_printf("tid=%u - cancel failed: %s", tid, strerror(ret));
+        /*
+         * We unlock here to allow the monitoring thread
+         * to continue if it was processing a cleanup.
+         */
+        tracing_mutex_unlock(&kq_mtx);
+
+        ret = pthread_join(monitoring_thread, &retval);
+        if (ret == 0) {
+            if (retval == PTHREAD_CANCELED) {
+                dbg_printf("tid=%u - joined with exit_status=PTHREAD_CANCELED", tid);
+            } else {
+                dbg_printf("tid=%u - joined with exit_status=%" PRIdPTR, tid, (intptr_t)retval);
+            }
+        } else {
+            dbg_printf("tid=%u - join failed: %s", tid, strerror(ret));
+        }
+    }
+    else
+        tracing_mutex_unlock(&kq_mtx);
 }
 
 static int
@@ -268,7 +457,7 @@ linux_kqueue_init(struct kqueue *kq)
 {
     struct f_owner_ex sig_owner;
 
-    kq->epollfd = epoll_create(1);
+    kq->epollfd = epoll_create1(EPOLL_CLOEXEC);
     if (kq->epollfd < 0) {
         dbg_perror("epoll_create(2)");
         return (-1);
@@ -282,7 +471,7 @@ linux_kqueue_init(struct kqueue *kq)
      * Closing the end will cause the pipe to be close which
      * will be caught by the monitoring thread.
      */
-    if (pipe(kq->pipefd)) {
+    if (pipe2(kq->pipefd, O_CLOEXEC)) {
         if (close(kq->epollfd) < 0)
             dbg_perror("close(2)");
         kq->epollfd = -1;
@@ -329,6 +518,9 @@ linux_kqueue_init(struct kqueue *kq)
      *
      * We may want to make this configurable at runtime later
      * so we won't conflict with the application.
+     *
+     * Note: MONITORING_THREAD_SIGNAL must be >= SIGRTMIN so that
+     * multiple signals are queued.
      */
     if (fcntl(kq->pipefd[0], F_SETSIG, MONITORING_THREAD_SIGNAL) < 0) {
         dbg_printf("fd=%i - failed settting F_SETSIG sig=%u: %s",
@@ -336,23 +528,19 @@ linux_kqueue_init(struct kqueue *kq)
         goto error;
     }
 
-    (void) pthread_mutex_lock(&kq_mtx);
-
-    /*
-     * Increment kqueue counter - must be incremented before
-     * starting the monitoring thread in case there's a spurious
-     * wakeup and the thread immediately checks that there
-     * are no kqueues, and exits.
-     */
-    kqueue_cnt++;
-
     /* Start monitoring thread during first initialization */
-    (void) pthread_once(&monitoring_thread_initialized, linux_kqueue_start_thread);
+    if (monitoring_tid == 0) {
+        if (linux_kqueue_start_thread() < 0)
+            goto error;
+    }
 
     /* Update pipe FD map */
-    fd_map[kq->pipefd[0]] = kq->pipefd[1];
+    fd_map[kq->pipefd[0]] = kq->kq_id;
 
-    dbg_printf("active_kqueues=%u", kqueue_cnt);
+    /* Mark this id as in use */
+    fd_use_cnt[kq->kq_id]++;
+
+    dbg_printf("kq=%p - fd=%i use_count=%u", kq, kq->kq_id, fd_use_cnt[kq->kq_id]);
 
     assert(monitoring_tid != 0);
 
@@ -364,15 +552,12 @@ linux_kqueue_init(struct kqueue *kq)
     sig_owner.type = F_OWNER_TID;
     sig_owner.pid = monitoring_tid;
     if (fcntl(kq->pipefd[0], F_SETOWN_EX, &sig_owner) < 0) {
-        dbg_printf("fd=%i - failed settting F_SETOWN to tid=%u: %s", monitoring_tid, kq->pipefd[0], strerror(errno));
-        kqueue_cnt--;
-        (void) pthread_mutex_unlock(&kq_mtx);
+        dbg_printf("fd=%i - failed settting F_SETOWN to tid=%u: %s", monitoring_tid, kq->kq_id, strerror(errno));
+        tracing_mutex_unlock(&kq_mtx);
         goto error;
     }
     dbg_printf("kq=%p - monitoring fd=%i for closure", kq, kq->pipefd[0]);
 
-    (void) pthread_mutex_unlock(&kq_mtx);
-
     return (0);
 }
 
@@ -384,7 +569,7 @@ linux_kqueue_init(struct kqueue *kq)
  * - false if epoll fd was already closed
  */
 static void
-linux_kqueue_cleanup(struct kqueue *kq)
+linux_kqueue_free(struct kqueue *kq)
 {
     char buffer;
     ssize_t ret;
@@ -394,7 +579,7 @@ linux_kqueue_cleanup(struct kqueue *kq)
         dbg_printf("epoll_fd=%i - closed", kq->epollfd);
 
         if (close(kq->epollfd) < 0)
-            dbg_perror("close(2)");
+            dbg_perror("close(2) - epoll_fd=%i", kq->epollfd);
         kq->epollfd = -1;
     }
 
@@ -409,8 +594,11 @@ linux_kqueue_cleanup(struct kqueue *kq)
         // Shoudn't happen unless kqops.kqueue_free is called on an open FD
         dbg_puts("kqueue wasn't closed");
 
-        if (close(kq->pipefd[1]) < 0)
-            dbg_perror("close(2)");
+        if (close(kq->pipefd[1]) < 0) {
+            dbg_perror("close(2) - pipefd[1]=%i", kq->pipefd[1]);
+        } else {
+            dbg_printf("pipefd[1]=%i - closed", kq->pipefd[1]);
+        }
         kq->pipefd[1] = -1;
     } else if (ret > 0) {
         // Shouldn't happen unless data is written to kqueue FD
@@ -421,31 +609,13 @@ linux_kqueue_cleanup(struct kqueue *kq)
 
     pipefd = kq->pipefd[0];
     if (pipefd > 0) {
-        dbg_printf("kq_fd=%i - closed", pipefd);
-
-        if (close(pipefd) < 0)
-            dbg_perror("close(2)");
+        if (close(pipefd) < 0) {
+            dbg_perror("close(2) - kq_fd=%i", kq->pipefd[0]);
+        } else {
+            dbg_printf("kq_fd=%i - closed", kq->pipefd[0]);
+        }
         kq->pipefd[0] = -1;
     }
-
-    /* Decrement kqueue counter */
-    kqueue_cnt--;
-    dbg_printf("kq=%p - cleaned up kqueue, active_kqueues=%u", kq, kqueue_cnt);
-}
-
-/** Explicitly free the kqueue
- *
- * This is only called from the public kqueue function when a map
- * slot is going to be re-used, so it's an indicator that the
- * KQ fd is in use, and we shouldn't attempt to free it if we
- * receive a signal in the monitoring thread.
- */
-static void
-linux_kqueue_free(struct kqueue *kq)
-{
-    linux_kqueue_cleanup(kq);
-    fd_use_cnt[kq->kq_id]++;
-    dbg_printf("kq=%p - increased fd=%i use_count=%u", kq, kq->kq_id, fd_use_cnt[kq->kq_id]);
 }
 
 static int
@@ -525,6 +695,8 @@ static inline int linux_kevent_copyout_ev(struct kevent *el, int nevents, struct
     int rv;
 
     rv = filt->kf_copyout(el, nevents, filt, kn, ev);
+    dbg_printf("rv=%i", rv);
+
     if (unlikely(rv < 0)) {
         dbg_puts("knote_copyout failed");
         assert(0);
@@ -545,12 +717,115 @@ static inline int linux_kevent_copyout_ev(struct kevent *el, int nevents, struct
     return rv;
 }
 
+char const *epoll_op_dump(int op)
+{
+    static __thread char buf[14];
+
+    buf[0] = '\0';
+
+#define EPOP_DUMP(attrib) \
+    if (op == attrib) { \
+        strcpy(buf, #attrib); \
+        return buf; \
+    }
+
+    EPOP_DUMP(EPOLL_CTL_MOD);
+    EPOP_DUMP(EPOLL_CTL_ADD);
+    EPOP_DUMP(EPOLL_CTL_DEL);
+
+    return buf;
+}
+
+static const char *
+udata_type(enum epoll_udata_type ud_type)
+{
+    const char *ud_name[] = {
+        [EPOLL_UDATA_KNOTE] = "EPOLL_UDATA_KNOTE",
+        [EPOLL_UDATA_FD_STATE] = "EPOLL_UDATA_FD_STATE",
+        [EPOLL_UDATA_EVENT_FD] = "EPOLL_UDATA_EVENT_FD",
+    };
+
+    if (ud_type < 0 || ud_type >= NUM_ELEMENTS(ud_name))
+        return "EPOLL_UDATA_INVALID";
+    else
+        return ud_name[ud_type];
+}
+
+static const char *
+epoll_udata_type_dump(const struct epoll_event *ev)
+{
+    static __thread char buf[64];
+    enum epoll_udata_type ud_type;
+
+    ud_type = ((struct epoll_udata *)(ev->data.ptr))->ud_type;
+
+    snprintf(buf, sizeof(buf), "%d (%s)",
+             ud_type, udata_type(ud_type));
+    return ((const char *) buf);
+}
+
+static const char *
+epoll_flags_dump(uint32_t events)
+{
+    static __thread char buf[1024];
+    size_t len;
+
+#define EEVENT_DUMP(attrib) \
+    if (events & attrib) \
+    strncat((char *) buf, #attrib" ", 64);
+
+    snprintf(buf, sizeof(buf), "events=0x%08x (", events);
+    EEVENT_DUMP(EPOLLIN);
+    EEVENT_DUMP(EPOLLPRI);
+    EEVENT_DUMP(EPOLLOUT);
+    EEVENT_DUMP(EPOLLRDNORM);
+    EEVENT_DUMP(EPOLLRDBAND);
+    EEVENT_DUMP(EPOLLWRNORM);
+    EEVENT_DUMP(EPOLLWRBAND);
+    EEVENT_DUMP(EPOLLMSG);
+    EEVENT_DUMP(EPOLLERR);
+    EEVENT_DUMP(EPOLLHUP);
+    EEVENT_DUMP(EPOLLRDHUP);
+    EEVENT_DUMP(EPOLLONESHOT);
+    EEVENT_DUMP(EPOLLET);
+
+    len = strlen(buf);
+    if (buf[len - 1] == ' ') buf[len - 1] = '\0';    /* Trim trailing space */
+    strcat(buf, ")");
+
+#undef EEVENT_DUMP
+
+    return ((const char *) buf);
+}
+
+const char *
+epoll_event_flags_dump(const struct epoll_event *ev)
+{
+    return epoll_flags_dump(ev->events);
+}
+
+const char *
+epoll_event_dump(const struct epoll_event *ev)
+{
+    static __thread char buf[2147];
+
+    snprintf((char *) buf, sizeof(buf),
+             "{ %s, udata=%p, udata_type=%s }",
+             epoll_event_flags_dump(ev),
+             ev->data.ptr,
+             epoll_udata_type_dump(ev));
+
+    return ((const char *) buf);
+}
+
 int
 linux_kevent_copyout(struct kqueue *kq, int nready, struct kevent *el, int nevents)
 {
     struct kevent   *el_p = el, *el_end = el + nevents;
     int             i;
 
+    dbg_printf("got %i events from epoll", nready);
+
     for (i = 0; i < nready; i++) {
         struct epoll_event    *ev = &epoll_events[i];    /* Thread local storage populated in linux_kevent_wait */
         struct epoll_udata    *epoll_udata = ev->data.ptr;
@@ -561,6 +836,8 @@ linux_kevent_copyout(struct kqueue *kq, int nready, struct kevent *el, int neven
             continue;
         }
 
+        dbg_printf("[%i] %s", i, epoll_event_dump(ev));
+
         /*
          * epoll event is associated with a single filter
          * so we just have one knote per event.
@@ -581,7 +858,7 @@ linux_kevent_copyout(struct kqueue *kq, int nready, struct kevent *el, int neven
                 goto done;
             }
 
-            rv = linux_kevent_copyout_ev(el_p, (el_end - el_p), ev, &kq->kq_filt[~(kn->kev.filter)], kn);
+            rv = linux_kevent_copyout_ev(el_p, (el_end - el_p), ev, knote_get_filter(kn), kn);
             if (rv < 0) goto done;
             el_p += rv;
         }
@@ -594,41 +871,33 @@ linux_kevent_copyout(struct kqueue *kq, int nready, struct kevent *el, int neven
         case EPOLL_UDATA_FD_STATE:
         {
             struct fd_state   *fds = epoll_udata->ud_fds;
-            struct knote      *kn;
-
+            struct knote      *kn, *write;
             assert(fds);
+
             /*
-             *    FD is readable
+             * fds can be freed after the first linux_kevent_copyout_ev
+             * so cache the pointer value here.
              */
-            if (ev->events & EPOLLIN) {
+            write = fds->fds_write;
+
+            /*
+             *    FD, or errored, or other side shutdown
+             */
+            if ((kn = fds->fds_read) && (ev->events & (EPOLLIN | EPOLLHUP | EPOLLRDHUP | EPOLLERR))) {
                 if (el_p >= el_end) goto oos;
 
-                kn = fds->fds_read;
-
-                /*
-                 * We shouldn't receive events we didn't register for
-                 * This assume's the Linux's epoll implementation isn't
-                 * complete garbage... so um... this assert may need
-                 * to be removed later.
-                 */
-                assert(kn);
-
-                rv = linux_kevent_copyout_ev(el_p, (el_end - el_p), ev, &kq->kq_filt[~(kn->kev.filter)], kn);
+                rv = linux_kevent_copyout_ev(el_p, (el_end - el_p), ev, knote_get_filter(kn), kn);
                 if (rv < 0) goto done;
                 el_p += rv;
             }
 
             /*
-             *    FD is writable
+             *    FD is writable, or errored, or other side shutdown
              */
-            if (ev->events & EPOLLOUT) {
+            if ((kn = write) && (ev->events & (EPOLLOUT | POLLHUP | EPOLLERR))) {
                 if (el_p >= el_end) goto oos;
 
-                kn = fds->fds_write;
-
-                assert(kn);    /* We shouldn't receive events we didn't request */
-
-                rv = linux_kevent_copyout_ev(el_p, (el_end - el_p), ev, &kq->kq_filt[~(kn->kev.filter)], kn);
+                rv = linux_kevent_copyout_ev(el_p, (el_end - el_p), ev, knote_get_filter(kn), kn);
                 if (rv < 0) goto done;
                 el_p += rv;
             }
@@ -641,8 +910,6 @@ linux_kevent_copyout(struct kqueue *kq, int nready, struct kevent *el, int neven
 
             assert(efd);
 
-            dbg_printf("eventfd=%u - received event", (unsigned int)efd->ef_id);
-
             rv = linux_kevent_copyout_ev(el_p, (el_end - el_p), ev, efd->ef_filt, NULL);
             if (rv < 0) goto done;
             el_p += rv;
@@ -668,18 +935,18 @@ linux_eventfd_register(struct kqueue *kq, struct eventfd *efd)
     EVENTFD_UDATA(efd); /* setup udata for the efd */
 
     if (epoll_ctl(kq->epollfd, EPOLL_CTL_ADD, kqops.eventfd_descriptor(efd), EPOLL_EV_EVENTFD(EPOLLIN, efd)) < 0) {
-        dbg_perror("epoll_ctl(2)");
-        return -1;
+        dbg_perror("epoll_ctl(2) - register epoll_fd=%i eventfd=%i", kq->epollfd, kqops.eventfd_descriptor(efd));
+        return (-1);
     }
 
-    return 0;
+    return (0);
 }
 
 void
 linux_eventfd_unregister(struct kqueue *kq, struct eventfd *efd)
 {
     if (epoll_ctl(kq->epollfd, EPOLL_CTL_DEL, kqops.eventfd_descriptor(efd), NULL) < 0)
-        dbg_perror("epoll_ctl(2)");
+        dbg_perror("epoll_ctl(2) - unregister epoll_fd=%i eventfd=%i", kq->epollfd, kqops.eventfd_descriptor(efd));
 }
 
 static int
@@ -687,7 +954,7 @@ linux_eventfd_init(struct eventfd *efd, struct filter *filt)
 {
     int evfd;
 
-    evfd = eventfd(0, EFD_NONBLOCK);
+    evfd = eventfd(0, EFD_NONBLOCK | EFD_CLOEXEC);
     if (evfd < 0) {
         dbg_perror("eventfd");
         return (-1);
@@ -942,61 +1209,6 @@ linux_get_descriptor_type(struct knote *kn)
     return (0);
 }
 
-char *epoll_event_op_dump(int op)
-{
-    static __thread char buf[14];
-
-    buf[0] = '\0';
-
-#define EPOP_DUMP(attrib) \
-    if (op == attrib) { \
-        strcpy(buf, #attrib); \
-        return buf; \
-    }
-
-    EPOP_DUMP(EPOLL_CTL_MOD);
-    EPOP_DUMP(EPOLL_CTL_ADD);
-    EPOP_DUMP(EPOLL_CTL_DEL);
-
-    return buf;
-}
-
-char *epoll_event_flags_dump(int events)
-{
-    static __thread char buf[128];
-
-    buf[0] = '\0';
-
-#define EPEVT_DUMP(attrib) \
-    if (events & attrib) strcat(buf, #attrib" ");
-
-    EPEVT_DUMP(EPOLLIN);
-    EPEVT_DUMP(EPOLLOUT);
-#if defined(HAVE_EPOLLRDHUP)
-    EPEVT_DUMP(EPOLLRDHUP);
-#endif
-    EPEVT_DUMP(EPOLLONESHOT);
-    EPEVT_DUMP(EPOLLET);
-
-    if (buf[0] != '\0') buf[strlen(buf) - 1] = '\0';    /* Trim trailing space */
-
-    return buf;
-}
-
-char *
-epoll_event_dump(struct epoll_event *evt)
-{
-    static __thread char buf[128];
-
-    if (evt == NULL)
-        return "(null)";
-
-    snprintf(buf, sizeof(buf), "{ data = %p, events = %s }", evt->data.ptr, epoll_event_flags_dump(evt->events));
-
-    return (buf);
-#undef EPEVT_DUMP
-}
-
 /** Determine if two fd state entries are equal
  *
  * @param[in] a           first entry.
@@ -1051,8 +1263,8 @@ int epoll_fd_state(struct fd_state **fds_p, struct knote *kn, bool disabled)
 
     *fds_p = fds;
 
-    if (fds->fds_read && (disabled == ((kn->kev.flags & EV_DISABLE) != 0))) state |= EPOLLIN;
-    if (fds->fds_write && (disabled == ((kn->kev.flags & EV_DISABLE) != 0))) state |= EPOLLOUT;
+    state |= (fds->fds_read && (disabled == ((fds->fds_read->kev.flags & (EV_DISABLE | EV_EOF)) != 0))) * EPOLLIN;
+    state |= (fds->fds_write && (disabled == ((fds->fds_write->kev.flags & (EV_DISABLE | EV_EOF)) != 0))) * EPOLLOUT;
 
     return state;
 }
@@ -1100,7 +1312,7 @@ int epoll_fd_state_mod(struct fd_state **fds_p, struct knote *kn, int ev)
 
         fds = RB_FIND(fd_st, &kq->kq_fd_st, &query);
         if (!fds) {
-            dbg_printf("fd_state: new fd=%i events=0x%04x (%s)", fd, ev, epoll_event_flags_dump(ev));
+            dbg_printf("fd_state: new fd=%i events=0x%08x (%s)", fd, ev, epoll_flags_dump(ev));
 
             fds = malloc(sizeof(struct fd_state));
             if (!fds) return (-1);
@@ -1111,7 +1323,7 @@ int epoll_fd_state_mod(struct fd_state **fds_p, struct knote *kn, int ev)
 
         } else {
         mod:
-            dbg_printf("fd_state: mod fd=%i events=0x%04x (%s)", fd, ev, epoll_event_flags_dump(ev));
+            dbg_printf("fd_state: mod fd=%i events=0x%08x (%s)", fd, ev, epoll_flags_dump(ev));
         }
     } else goto mod;
 
@@ -1168,7 +1380,7 @@ void epoll_fd_state_del(struct fd_state **fds_p, struct knote *kn, int ev)
         free(fds);
         *fds_p = NULL;
     } else {
-        dbg_printf("fd_state: mod fd=%i events=0x%04x (%s)", fds->fds_fd, ev, epoll_event_flags_dump(ev));
+        dbg_printf("fd_state: mod fd=%i events=0x%08x (%s)", fds->fds_fd, ev, epoll_flags_dump(ev));
     }
     kn->kn_fds = NULL;
 }
@@ -1210,7 +1422,8 @@ epoll_update(int op, struct filter *filt, struct knote *kn, int ev, bool delete)
 
 #define EV_EPOLLINOUT(_x) ((_x) & (EPOLLIN | EPOLLOUT))
 
-    if (kn->kev.flags & EV_DISABLE) dbg_printf("fd=%i kn=%p is disabled", fd, kn);
+    if (KNOTE_DISABLED(kn)) dbg_printf("fd=%i kn=%p is disabled", fd, kn);
+    if (KNOTE_IS_EOF(kn)) dbg_printf("fd=%i kn=%p is EOF", fd, kn);
 
     /*
      * Determine the current state of the file descriptor
@@ -1218,7 +1431,7 @@ epoll_update(int op, struct filter *filt, struct knote *kn, int ev, bool delete)
      */
     have_ev = epoll_fd_state(&fds, kn, false);            /* ...enabled only */
 
-    dbg_printf("fd=%i have_ev=0x%04x (%s)", fd, have_ev, epoll_event_flags_dump(have_ev));
+    dbg_printf("fd=%i have_ev=0x%04x (%s)", fd, have_ev, epoll_flags_dump(have_ev));
     switch (op) {
     case EPOLL_CTL_ADD:
         want = have_ev | ev;            /* This also preserves other option flags */
@@ -1236,7 +1449,7 @@ epoll_update(int op, struct filter *filt, struct knote *kn, int ev, bool delete)
             int to_delete;
 
             to_delete = epoll_fd_state(&fds, kn, true); /* ...disabled only */
-            dbg_printf("fd=%i disabled_ev=0x%04x (%s)", fd, to_delete, epoll_event_flags_dump(to_delete));
+            dbg_printf("fd=%i disabled_ev=0x%04x (%s)", fd, to_delete, epoll_flags_dump(to_delete));
             to_delete &= EV_EPOLLINOUT(ev);
 
             if (to_delete) {
@@ -1253,7 +1466,7 @@ epoll_update(int op, struct filter *filt, struct knote *kn, int ev, bool delete)
             int to_delete;
 
             to_delete = epoll_fd_state(&fds, kn, true); /* ...disabled only */
-            dbg_printf("fd=%i disabled_ev=0x%04x (%s)", fd, to_delete, epoll_event_flags_dump(to_delete));
+            dbg_printf("fd=%i disabled_ev=0x%04x (%s)", fd, to_delete, epoll_flags_dump(to_delete));
             to_delete &= ~ev;
 
             if (to_delete) {
@@ -1285,8 +1498,8 @@ epoll_update(int op, struct filter *filt, struct knote *kn, int ev, bool delete)
 
     dbg_printf("fd=%i op=0x%04x (%s) opn=0x%04x (%s) %s",
                fd,
-               op, epoll_event_op_dump(op),
-               opn, epoll_event_op_dump(opn),
+               op, epoll_op_dump(op),
+               opn, epoll_op_dump(opn),
                epoll_event_dump(EPOLL_EV_FDS(want, fds)));
 
     if (epoll_ctl(filter_epoll_fd(filt), opn, fd, EPOLL_EV_FDS(want, fds)) < 0) {
@@ -1314,7 +1527,7 @@ epoll_update(int op, struct filter *filt, struct knote *kn, int ev, bool delete)
                 kn_ev &= ~want_ev;    /* If it wasn't wanted... */
 
                 if (kn_ev) {
-                    dbg_printf("clearing fd=%i fds=%p ev=%s", fd, fds, epoll_event_flags_dump(kn_ev));
+                    dbg_printf("clearing fd=%i fds=%p ev=%s", fd, fds, epoll_flags_dump(kn_ev));
                     epoll_fd_state_del(&fds, kn, kn_ev);
                     return (0);
                 }
@@ -1373,6 +1586,8 @@ linux_fd_to_path(char *buf, size_t bufsz, int fd)
 }
 
 const struct kqueue_vtable kqops = {
+    .libkqueue_fork     = linux_libkqueue_fork,
+    .libkqueue_free     = linux_libkqueue_free,
     .kqueue_init        = linux_kqueue_init,
     .kqueue_free        = linux_kqueue_free,
     .kevent_wait        = linux_kevent_wait,
