@@ -51,12 +51,14 @@ struct filter;
 #include <sys/time.h>
 #include <unistd.h>
 
-
 /*
  * Check to see if we have SYS_pidfd_open support if we don't,
  * fall back to the POSIX EVFILT_PROC code.
+ *
+ * Using the build system macro makes it slightly easier to
+ * toggle between POSIX/Linux implementations.
  */
-#ifdef SYS_pidfd_open
+#if HAVE_SYS_PIDFD_OPEN
 #define KNOTE_PROC_PLATFORM_SPECIFIC  int kn_procfd;
 #define FILTER_PROC_PLATFORM_SPECIFIC
 #else
@@ -87,6 +89,11 @@ struct filter;
 extern long int syscall (long int __sysno, ...);
 #endif
 
+/* Workaround for Android */
+#ifndef EPOLLONESHOT
+# define EPOLLONESHOT (1 << 30)
+#endif
+
 /* Convenience macros to access the epoll descriptor for the kqueue */
 #define kqueue_epoll_fd(kq)     ((kq)->epollfd)
 #define filter_epoll_fd(filt)   ((filt)->kf_kqueue->epollfd)
@@ -248,9 +255,9 @@ int     linux_fd_to_path(char *, size_t, int);
 
 /* epoll-related functions */
 
-char *  epoll_event_op_dump(int);
-char *  epoll_event_flags_dump(int);
-char *  epoll_event_dump(struct epoll_event *);
+char const *  epoll_op_dump(int);
+char const *  epoll_event_flags_dump(const struct epoll_event *);
+char const *  epoll_event_dump(const struct epoll_event *);
 
 int     epoll_fd_state(struct fd_state **, struct knote *, bool);
 int     epoll_fd_state_init(struct fd_state **, struct knote *, int);
