@@ -16,7 +16,7 @@
 
 #include "private.h"
 
-#ifndef HAVE_SYS_TIMERFD_H
+#if HAVE_SYS_TIMERFD_H != 1
 
 /* Android 4.0 does not have this header, but the kernel supports timerfds */
 #ifndef SYS_timerfd_create
@@ -93,7 +93,7 @@ convert_timedata_to_itimerspec(struct itimerspec *dst, long src,
     switch (flags & NOTE_TIMER_MASK) {
     case NOTE_USECONDS:
         sec = src / 1000000;
-        nsec = (src % 1000000);
+        nsec = (src % 1000000) * 1000;
         break;
 
     case NOTE_NSECONDS:
@@ -163,7 +163,7 @@ evfilt_timer_knote_create(struct filter *filt, struct knote *kn)
 
     kn->kev.flags |= EV_CLEAR;
 
-    tfd = timerfd_create(CLOCK_MONOTONIC, 0);
+    tfd = timerfd_create(CLOCK_MONOTONIC, TFD_CLOEXEC);
     if (tfd < 0) {
         if ((errno == EMFILE) || (errno == ENFILE)) {
             dbg_perror("timerfd_create(2) fd_used=%u fd_max=%u", get_fd_used(), get_fd_limit());
@@ -202,10 +202,24 @@ int
 evfilt_timer_knote_modify(struct filter *filt, struct knote *kn,
         const struct kevent *kev)
 {
-    (void)filt;
-    (void)kn;
-    (void)kev;
-    return (0); /* STUB */
+    struct itimerspec ts;
+    int flags;
+
+    dbg_printf("timer_fd=%i - modified", kn->kn_timerfd);
+
+    convert_timedata_to_itimerspec(&ts, kev->data, kev->fflags,
+                                   kev->flags & EV_ONESHOT);
+    flags = (kev->fflags & NOTE_ABSOLUTE) ? TFD_TIMER_ABSTIME : 0;
+    if (timerfd_settime(kn->kn_timerfd, flags, &ts, NULL) < 0) {
+        dbg_printf("timerfd_settime(2): %s", strerror(errno));
+        return (-1);
+    }
+
+    kn->kev.flags = kev->flags | EV_CLEAR;
+    kn->kev.fflags = kev->fflags;
+    kn->kev.data = kev->data;
+
+    return (0);
 }
 
 int
