@@ -31,22 +31,26 @@ evfilt_write_copyout(struct kevent *dst, UNUSED int nevents, struct filter *filt
 
     epoll_event_dump(ev);
     memcpy(dst, &src->kev, sizeof(*dst));
-#if defined(HAVE_EPOLLRDHUP)
-    if (ev->events & EPOLLRDHUP || ev->events & EPOLLHUP)
-        dst->flags |= EV_EOF;
-#else
+
     if (ev->events & EPOLLHUP)
         dst->flags |= EV_EOF;
-#endif
+
     if (ev->events & EPOLLERR) {
         if (src->kn_flags & KNFL_SOCKET) {
             ret = getsockopt(src->kev.ident, SOL_SOCKET, SO_ERROR, &serr, &slen);
             dst->fflags = ((ret < 0) ? errno : serr);
-        } else { dst->fflags = EIO; }
+        } else
+            dst->fflags = EIO;
+
+        /*
+         * The only way we seem to be able to signal an error
+         * is by setting EOF on the socket.
+         */
+        dst->flags |= EV_EOF;
     }
 
     /* On return, data contains the the amount of space remaining in the write buffer */
-    if (ioctl(dst->ident, SIOCOUTQ, &dst->data) < 0) {
+    if (!(dst->flags & EV_EOF) && (ioctl(dst->ident, SIOCOUTQ, &dst->data) < 0)) {
             /* race condition with socket close, so ignore this error */
             dbg_puts("ioctl(2) of socket failed");
             dst->data = 0;
@@ -87,13 +91,23 @@ evfilt_write_knote_create(struct filter *filt, struct knote *kn)
 }
 
 int
-evfilt_write_knote_modify(struct filter *filt, struct knote *kn,
+evfilt_write_knote_modify(UNUSED struct filter *filt, struct knote *kn,
         const struct kevent *kev)
 {
-    (void) filt;
-    (void) kn;
-    (void) kev;
-    return (-1); /* STUB */
+    if (!(kn->kn_flags & KNFL_FILE)) {
+        /*
+         * This should reset the EOF sate of the socket.
+         * but it's not even clear what that really means.
+         *
+         * With the native kqueue implementations it
+         * basically does nothing.
+         */
+        if ((kev->flags & EV_CLEAR))
+            return (0);
+        return (-1);
+    }
+
+    return (-1);
 }
 
 int
