@@ -43,7 +43,7 @@ FileAnalyzer::~FileAnalyzer() {}
 
 void FileAnalyzer::Init() {}
 
-void FileAnalyzer::Done() { Finish(); }
+void FileAnalyzer::Done() {}
 
 bool FileAnalyzer::DeliverStream(const u_char* data, uint64_t len) {
     ::zeek::file_analysis::Analyzer::DeliverStream(data, len);
@@ -100,12 +100,6 @@ bool FileAnalyzer::Process(int len, const u_char* data) {
         STATE_DEBUG_MSG(hilti::rt::fmt("parse error, triggering analyzer violation: %s", e.what()));
         auto tag = OurPlugin->tagForFileAnalyzer(_state.cookie().analyzer->Tag());
         spicy::zeek::compat::Analyzer_AnalyzerViolation(_state.cookie().analyzer, e.what(), nullptr, 0, tag);
-    } catch ( const hilti::rt::RecoverableFailure& e ) {
-        // Spicy changed the exception hierarchy between 1.5 and 1.7 so that `RecoverableFailure`
-        // is a `ParseError` as well. Explicitly handle it for earlier versions.
-        STATE_DEBUG_MSG(hilti::rt::fmt("parse error, triggering analyzer violation: %s", e.what()));
-        auto tag = OurPlugin->tagForFileAnalyzer(_state.cookie().analyzer->Tag());
-        spicy::zeek::compat::Analyzer_AnalyzerViolation(_state.cookie().analyzer, e.what(), nullptr, 0, tag);
     } catch ( const hilti::rt::Exception& e ) {
         STATE_DEBUG_MSG(e.what());
         reporter::analyzerError(_state.cookie().analyzer, e.description(),
@@ -123,12 +117,6 @@ void FileAnalyzer::Finish() {
         STATE_DEBUG_MSG(hilti::rt::fmt("parse error, triggering analyzer violation: %s", e.what()));
         auto tag = OurPlugin->tagForFileAnalyzer(_state.cookie().analyzer->Tag());
         spicy::zeek::compat::Analyzer_AnalyzerViolation(_state.cookie().analyzer, e.what(), nullptr, 0, tag);
-    } catch ( const hilti::rt::RecoverableFailure& e ) {
-        // Spicy changed the exception hierarchy between 1.5 and 1.7 so that `RecoverableFailure`
-        // is a `ParseError` as well. Explicitly handle it for earlier versions.
-        STATE_DEBUG_MSG(hilti::rt::fmt("parse error, triggering analyzer violation: %s", e.what()));
-        auto tag = OurPlugin->tagForFileAnalyzer(_state.cookie().analyzer->Tag());
-        spicy::zeek::compat::Analyzer_AnalyzerViolation(_state.cookie().analyzer, e.what(), nullptr, 0, tag);
     } catch ( const hilti::rt::Exception& e ) {
         reporter::analyzerError(_state.cookie().analyzer, e.description(),
                                 e.location()); // this sets Zeek to skip sending any further input
