@@ -37,10 +37,7 @@ ProtocolAnalyzer::~ProtocolAnalyzer() {}
 
 void ProtocolAnalyzer::Init() {}
 
-void ProtocolAnalyzer::Done() {
-    Finish(true);
-    Finish(false);
-}
+void ProtocolAnalyzer::Done() {}
 
 void ProtocolAnalyzer::Process(bool is_orig, int len, const u_char* data) {
     auto* endp = is_orig ? &_originator : &_responder;
@@ -73,15 +70,6 @@ void ProtocolAnalyzer::Process(bool is_orig, int len, const u_char* data) {
         originator().skipRemaining();
         responder().skipRemaining();
         endp->cookie().analyzer->SetSkip(true);
-    } catch ( const hilti::rt::RecoverableFailure& e ) {
-        // Spicy changed the exception hierarchy between 1.5 and 1.7 so that `RecoverableFailure`
-        // is a `ParseError` as well. Explicitly handle it for earlier versions.
-        STATE_DEBUG_MSG(is_orig, hilti::rt::fmt("parse error, triggering analyzer violation: %s", e.what()));
-        auto tag = OurPlugin->tagForProtocolAnalyzer(endp->cookie().analyzer->GetAnalyzerTag());
-        spicy::zeek::compat::Analyzer_AnalyzerViolation(endp->cookie().analyzer, e.what(), nullptr, 0, tag);
-        originator().skipRemaining();
-        responder().skipRemaining();
-        endp->cookie().analyzer->SetSkip(true);
     } catch ( const hilti::rt::Exception& e ) {
         reporter::analyzerError(endp->cookie().analyzer, e.description(),
                                 e.location()); // this sets Zeek to skip sending any further input
@@ -102,13 +90,6 @@ void ProtocolAnalyzer::Finish(bool is_orig) {
         auto tag = OurPlugin->tagForProtocolAnalyzer(endp->cookie().analyzer->GetAnalyzerTag());
         spicy::zeek::compat::Analyzer_AnalyzerViolation(endp->cookie().analyzer, e.what(), nullptr, 0, tag);
         endp->skipRemaining();
-    } catch ( const hilti::rt::RecoverableFailure& e ) {
-        // Spicy changed the exception hierarchy between 1.5 and 1.7 so that `RecoverableFailure`
-        // is a `ParseError` as well. Explicitly handle it for earlier versions.
-        STATE_DEBUG_MSG(is_orig, hilti::rt::fmt("parse error, triggering analyzer violation: %s", e.what()));
-        auto tag = OurPlugin->tagForProtocolAnalyzer(endp->cookie().analyzer->GetAnalyzerTag());
-        spicy::zeek::compat::Analyzer_AnalyzerViolation(endp->cookie().analyzer, e.what(), nullptr, 0, tag);
-        endp->skipRemaining();
     } catch ( const hilti::rt::Exception& e ) {
         reporter::analyzerError(endp->cookie().analyzer, e.description(),
                                 e.location()); // this sets Zeek to skip sending any further input
