@@ -359,7 +359,7 @@ void rt::protocol_gap(const hilti::rt::Bool& is_orig, const hilti::rt::integer::
     if ( ! c )
         throw ValueUnavailable("no current connection available");
 
-    c->analyzer->ForwardUndelivered(offset, len, is_orig);
+    c->analyzer->ForwardUndelivered(is_orig, offset, len);
 }
 
 void rt::protocol_end() {
