@@ -5,7 +5,6 @@
 #include <type_traits>
 
 #include <hilti/rt/doctest.h>
-#include <hilti/rt/exception.h>
 #include <hilti/rt/types/bytes.h>
 #include <hilti/rt/types/integer.h>
 #include <hilti/rt/types/regexp.h>
@@ -66,13 +65,13 @@ TEST_CASE("decode") {
 TEST_CASE("extract") {
     SUBCASE("sufficient data") {
         unsigned char dst1[3] = {0};
-        CHECK_EQ("123456"_b.extract(dst1, 3), "456"_b);
+        CHECK_EQ("123456"_b.extract(dst1), "456"_b);
         CHECK_EQ(dst1[0], '1');
         CHECK_EQ(dst1[1], '2');
         CHECK_EQ(dst1[2], '3');
 
         unsigned char dst2[3] = {0};
-        CHECK_EQ("123"_b.extract(dst2, 3), ""_b);
+        CHECK_EQ("123"_b.extract(dst2), ""_b);
         CHECK_EQ(dst2[0], '1');
         CHECK_EQ(dst2[1], '2');
         CHECK_EQ(dst2[2], '3');
@@ -81,11 +80,11 @@ TEST_CASE("extract") {
     SUBCASE("insufficient data") {
         unsigned char dst1[3] = {0};
         // NOLINTNEXTLINE(bugprone-throw-keyword-missing)
-        CHECK_THROWS_WITH_AS(""_b.extract(dst1, 3), "insufficient data in source", const InvalidArgument&);
+        CHECK_THROWS_WITH_AS(""_b.extract(dst1), "insufficient data in source", const InvalidArgument&);
 
         unsigned char dst2[1] = {0};
         // NOLINTNEXTLINE(bugprone-throw-keyword-missing)
-        CHECK_THROWS_WITH_AS(""_b.extract(dst2, 1), "insufficient data in source", const InvalidArgument&);
+        CHECK_THROWS_WITH_AS(""_b.extract(dst2), "insufficient data in source", const InvalidArgument&);
     }
 }
 
@@ -299,7 +298,6 @@ TEST_CASE("sub") {
     SUBCASE("end offset") {
         CHECK_EQ(b.sub(0), ""_b);
         CHECK_EQ(b.sub(b.size()), b);
-        CHECK_EQ(b.sub(b.size() + 1024), b);
         CHECK_EQ(b.sub(99), b);
         CHECK_EQ(b.sub(3), "123"_b);
     }
@@ -310,34 +308,21 @@ TEST_CASE("sub") {
         CHECK_EQ(b.sub(0, b.size()), b);
         CHECK_EQ(b.sub(0, 3), "123"_b);
         CHECK_EQ(b.sub(3, 0), "456"_b);
-
-        CHECK_THROWS_WITH_AS(b.sub(b.size() + 1024, b.size() + 2048),
-                             "start index 1030 out of range for bytes with length 6", const OutOfRange);
     }
 
     SUBCASE("end iterator") {
         CHECK_EQ(b.sub(b.begin()), ""_b);
         CHECK_EQ(b.sub(b.end()), b);
-        CHECK_EQ(b.sub(++b.end()), b);
-
-        const auto bb = "123"_b;
-        CHECK_THROWS_WITH_AS(b.sub(bb.begin()), "start and end iterator cannot belong to different bytes",
-                             const InvalidArgument&);
     }
 
     SUBCASE("start/end iterator") {
         CHECK_EQ(b.sub(b.begin(), b.end()), b);
         CHECK_EQ(b.sub(b.begin(), b.begin()), ""_b);
-        CHECK_EQ(b.sub(b.end(), b.begin()), ""_b);
-        CHECK_THROWS_WITH_AS(b.sub(++b.end(), ++b.begin()), "start index 7 out of range for bytes with length 6",
-                             const OutOfRange&);
-        CHECK_THROWS_WITH_AS(b.sub(++b.end(), ++b.end()), "start index 7 out of range for bytes with length 6",
-                             const OutOfRange&);
 
         const auto bb = "123"_b;
         // NOLINTNEXTLINE(bugprone-throw-keyword-missing)
-        CHECK_THROWS_WITH_AS(b.sub(b.begin(), bb.begin()), "start and end iterator cannot belong to different bytes",
-                             const InvalidArgument&);
+        CHECK_THROWS_WITH_AS(b.sub(b.begin(), bb.begin()),
+                             "cannot perform arithmetic with iterators into different bytes", const InvalidArgument&);
     }
 }
 
