@@ -59,14 +59,6 @@ const Chunk* Chain::findChunk(Offset offset, const Chunk* hint_prev) const {
 
     const Chunk* c = _head.get();
 
-    // A very common way this function gets called without `hint_prev` is
-    // `Stream::unsafeEnd` via `Chain::unsafeEnd` in construction of an
-    // `UnsafeConstIterator` from a `SafeConstIterator`; in this case the chunk
-    // for `end()` will be `nullptr`. Optimize for that case by assuming we
-    // always want a chunk near the end if no hint is given.
-    if ( ! hint_prev )
-        hint_prev = _tail;
-
     if ( hint_prev && hint_prev->offset() <= offset )
         c = hint_prev;
 
@@ -84,10 +76,6 @@ Chunk* Chain::findChunk(Offset offset, Chunk* hint_prev) {
 
     Chunk* c = _head.get();
 
-    // See comment above.
-    if ( ! hint_prev )
-        hint_prev = _tail;
-
     if ( hint_prev && hint_prev->offset() <= offset )
         c = hint_prev;
 
@@ -209,16 +197,13 @@ View View::advanceToNextData() const {
         c = c->next();
     }
 
-    // Iterator to zero point in original stream. All offsets are relative to this.
-    const auto zero = _begin - _begin.offset();
-
     // If we have found a non-gap chunk its offset points to the next data.
     if ( c )
-        return View(zero + c->offset(), _end);
+        return View(_begin + c->offset(), _end);
 
     // If we have seen a previous chunk, return a View starting after its end.
     if ( last_end )
-        return View(zero + *last_end, _end);
+        return View(_begin + *last_end, _end);
 
     // If we have not found a next non-gap chunk simply return a view at the next
     // byte. Since this is a gap chunk this can cause recovery in the caller.
