@@ -461,8 +461,7 @@ void Unit::resetAST() {
 
     HILTI_DEBUG(logging::debug::Compiler, fmt("resetting nodes for module %s", uniqueID()));
 
-    auto v = hilti::visitor::PreOrder<>();
-    for ( auto&& i : v.walk(&*_module) ) {
+    for ( auto&& i : hilti::visitor::PreOrder<>().walk(&*_module) ) {
         i.node.clearScope();
         i.node.clearErrors();
     }
