@@ -1,5 +1,7 @@
 // Copyright (c) 2020-2021 by the Zeek Project. See LICENSE for details.
 
+#include <optional>
+
 #include <hilti/ast/all.h>
 #include <hilti/ast/builder/expression.h>
 #include <hilti/ast/detail/visitor.h>
@@ -130,6 +132,39 @@ struct Visitor : public visitor::PreOrder<void, Visitor> {
             return {std::nullopt};
     }
 
+    /**
+     * Coerces a specific call argument to a given type returning the coerced
+     * expression (only) if its type has changed.
+     */
+    Result<std::optional<Expression>> coerceMethodArgument(const expression::ResolvedOperatorBase& o, size_t i,
+                                                           const Type& t) {
+        auto ops = o.op2();
+
+        // If the argument list was the result of a coercion unpack its result.
+        if ( auto coerced = ops.tryAs<expression::Coerced>() )
+            ops = coerced->expression();
+
+        auto ctor_ = ops.as<expression::Ctor>().ctor();
+
+        // If the argument was the result of a coercion unpack its result.
+        if ( auto x = ctor_.tryAs<ctor::Coerced>() )
+            ctor_ = x->coercedCtor();
+
+        const auto& args = ctor_.as<ctor::Tuple>().value();
+        if ( i >= args.size() )
+            return {std::nullopt};
+
+        if ( auto narg = hilti::coerceExpression(args[i], t); ! narg )
+            return result::Error(fmt("cannot coerce argument %d from %s to %s", i, args[i].type(), t));
+        else if ( narg.nexpr ) {
+            auto nargs = args.copy();
+            nargs[i] = *narg.nexpr;
+            return {expression::Ctor(ctor::Tuple(nargs))};
+        }
+
+        return {std::nullopt};
+    }
+
     void operator()(const Attribute& n) {
         // TODO(robin): Coerce attributes with expressions.
     }
@@ -308,6 +343,19 @@ struct Visitor : public visitor::PreOrder<void, Visitor> {
         }
     }
 
+    void operator()(const expression::Ternary& n, position_t p) {
+        if ( ! (type::isResolved(n.true_().type()) && type::isResolved(n.false_().type())) )
+            return;
+
+        // Coerce the second branch to the type of the first. This isn't quite
+        // ideal, but as good as we can do right now.
+        if ( auto coerced = coerceExpression(n.false_(), n.true_().type()); coerced && coerced.nexpr ) {
+            logChange(p.node, *coerced.nexpr, "ternary");
+            p.node.as<expression::Ternary>().setFalse(*coerced.nexpr);
+            modified = true;
+        }
+    }
+
     void operator()(const operator_::generic::New& n, position_t p) {
         auto etype = n.op0().tryAs<expression::Type_>();
         if ( ! etype )
@@ -324,6 +372,18 @@ struct Visitor : public visitor::PreOrder<void, Visitor> {
         }
     }
 
+    void operator()(const operator_::map::Get& n, position_t p) {
+        if ( auto nargs = coerceMethodArgument(n, 1, n.result()) ) {
+            if ( *nargs ) {
+                logChange(p.node, **nargs, "default value");
+                p.node.as<operator_::map::Get>().setOp2(**nargs);
+                modified = true;
+            }
+        }
+        else
+            p.node.addError(nargs.error());
+    }
+
     // TODO(bbannier): Ideally instead of inserting this coercion we would
     // define the operator to take some `keyType` derived from the type of the
     // passed `map` and perform the coercion automatically when resolving the
