@@ -1,7 +1,7 @@
 # Common material sourced by Bash CI scripts in this directory
 
-# On Cirrus, oversubscribe the CPUs when on Linux. This uses Cirrus' "greedy" feature.
-if [[ "${CIRRUS_OS}" == linux ]]; then
+# On Cirrus, oversubscribe the CPUs when on Linux or FreeBSD. This uses Cirrus' "greedy" feature.
+if [[ "${CIRRUS_OS}" == linux || "${CIRRUS_OS}" == freebsd ]]; then
     if [[ -n "${ZEEK_CI_CPUS}" ]]; then
         ZEEK_CI_CPUS=$((2 * ${ZEEK_CI_CPUS}))
     fi
