@@ -6,8 +6,13 @@ set -e
 set -x
 
 env ASSUME_ALWAYS_YES=YES pkg bootstrap
-pkg install -y bash git cmake swig bison python3 base64
+pkg install -y bash git cmake swig bison python3 base64 flex ccache
 pkg upgrade -y curl
 pyver=$(python3 -c 'import sys; print(f"py{sys.version_info[0]}{sys.version_info[1]}")')
 pkg install -y $pyver-sqlite3 $pyver-pip
-pip install junit2html
+
+python -m pip install websockets junit2html
+
+# Spicy detects whether it is run from build directory via `/proc`.
+echo "proc /proc procfs rw,noauto 0 0" >>/etc/fstab
+mount /proc
