@@ -161,11 +161,26 @@ void Attr::DescribeReST(ODesc* d, bool shorten) const
 void Attr::AddTag(ODesc* d) const
 	{
 	if ( d->IsBinary() )
-		d->Add(static_cast<bro_int_t>(Tag()));
+		d->Add(static_cast<zeek_int_t>(Tag()));
 	else
 		d->Add(attr_name(Tag()));
 	}
 
+detail::TraversalCode Attr::Traverse(detail::TraversalCallback* cb) const
+	{
+	auto tc = cb->PreAttr(this);
+	HANDLE_TC_ATTR_PRE(tc);
+
+	if ( expr )
+		{
+		auto tc = expr->Traverse(cb);
+		HANDLE_TC_ATTR_PRE(tc);
+		}
+
+	tc = cb->PostAttr(this);
+	HANDLE_TC_ATTR_POST(tc);
+	}
+
 Attributes::Attributes(TypePtr t, bool arg_in_record, bool is_global)
 	: Attributes(std::vector<AttrPtr>{}, std::move(t), arg_in_record, is_global)
 	{
@@ -192,6 +207,9 @@ void Attributes::AddAttr(AttrPtr attr, bool is_redef)
 	{
 	auto acceptable_duplicate_attr = [](const AttrPtr& attr, const AttrPtr& existing) -> bool
 	{
+		if ( attr == existing )
+			return true;
+
 		AttrTag new_tag = attr->Tag();
 
 		if ( new_tag == ATTR_DEPRECATED )
@@ -282,7 +300,7 @@ void Attributes::Describe(ODesc* d) const
 
 	for ( size_t i = 0; i < attrs.size(); ++i )
 		{
-		if ( (d->IsReadable() || d->IsPortable()) && i > 0 )
+		if ( d->IsReadable() && i > 0 )
 			d->Add(", ");
 
 		attrs[i]->Describe(d);
@@ -341,116 +359,12 @@ void Attributes::CheckAttr(Attr* a)
 
 		case ATTR_DEFAULT:
 			{
-			// &default is allowed for global tables, since it's used in initialization
-			// of table fields. it's not allowed otherwise.
-			if ( global_var && ! type->IsTable() )
-				{
-				Error("&default is not valid for global variables except for tables");
-				break;
-				}
-
-			const auto& atype = a->GetExpr()->GetType();
-
-			if ( type->Tag() != TYPE_TABLE || (type->IsSet() && ! in_record) )
-				{
-				if ( same_type(atype, type) )
-					// Ok.
-					break;
-
-				// Record defaults may be promotable.
-				if ( (type->Tag() == TYPE_RECORD && atype->Tag() == TYPE_RECORD &&
-				      record_promotion_compatible(atype->AsRecordType(), type->AsRecordType())) )
-					// Ok.
-					break;
-
-				if ( type->Tag() == TYPE_TABLE && type->AsTableType()->IsUnspecifiedTable() )
-					// Ok.
-					break;
-
-				auto e = check_and_promote_expr(a->GetExpr(), type);
-
-				if ( e )
-					{
-					a->SetAttrExpr(std::move(e));
-					// Ok.
-					break;
-					}
-
-				a->GetExpr()->Error("&default value has inconsistent type", type.get());
-				return;
-				}
-
-			TableType* tt = type->AsTableType();
-			const auto& ytype = tt->Yield();
-
-			if ( ! in_record )
-				{
-				// &default applies to the type itself.
-				if ( ! same_type(atype, ytype) )
-					{
-					// It can still be a default function.
-					if ( atype->Tag() == TYPE_FUNC )
-						{
-						FuncType* f = atype->AsFuncType();
-						if ( ! f->CheckArgs(tt->GetIndexTypes()) || ! same_type(f->Yield(), ytype) )
-							Error("&default function type clash");
-
-						// Ok.
-						break;
-						}
-
-					// Table defaults may be promotable.
-					if ( (ytype->Tag() == TYPE_RECORD && atype->Tag() == TYPE_RECORD &&
-					      record_promotion_compatible(atype->AsRecordType(),
-					                                  ytype->AsRecordType())) )
-						// Ok.
-						break;
-
-					auto e = check_and_promote_expr(a->GetExpr(), ytype);
-
-					if ( e )
-						{
-						a->SetAttrExpr(std::move(e));
-						// Ok.
-						break;
-						}
-
-					Error("&default value has inconsistent type 2");
-					}
-
-				// Ok.
-				break;
-				}
-
-			else
-				{
-				// &default applies to record field.
-
-				if ( same_type(atype, type) )
-					// Ok.
-					break;
-
-				if ( (atype->Tag() == TYPE_TABLE && atype->AsTableType()->IsUnspecifiedTable()) )
-					{
-					auto e = check_and_promote_expr(a->GetExpr(), type);
-
-					if ( e )
-						{
-						a->SetAttrExpr(std::move(e));
-						break;
-						}
-					}
-
-				// Table defaults may be promotable.
-				if ( ytype && ytype->Tag() == TYPE_RECORD && atype->Tag() == TYPE_RECORD &&
-				     record_promotion_compatible(atype->AsRecordType(), ytype->AsRecordType()) )
-					// Ok.
-					break;
-
-				Error("&default value has inconsistent type");
-				}
-			}
+			std::string err_msg;
+			if ( ! check_default_attr(a, type, global_var, in_record, err_msg) &&
+			     ! err_msg.empty() )
+				Error(err_msg.c_str());
 			break;
+			}
 
 		case ATTR_EXPIRE_READ:
 			{
@@ -748,4 +662,128 @@ bool Attributes::operator==(const Attributes& other) const
 	return true;
 	}
 
+bool check_default_attr(Attr* a, const TypePtr& type, bool global_var, bool in_record,
+                        std::string& err_msg)
+	{
+	// &default is allowed for global tables, since it's used in
+	// initialization of table fields. It's not allowed otherwise.
+	if ( global_var && ! type->IsTable() )
+		{
+		err_msg = "&default is not valid for global variables except for tables";
+		return false;
+		}
+
+	const auto& atype = a->GetExpr()->GetType();
+
+	if ( type->Tag() != TYPE_TABLE || (type->IsSet() && ! in_record) )
+		{
+		if ( same_type(atype, type) )
+			// Ok.
+			return true;
+
+		// Record defaults may be promotable.
+		if ( (type->Tag() == TYPE_RECORD && atype->Tag() == TYPE_RECORD &&
+		      record_promotion_compatible(atype->AsRecordType(), type->AsRecordType())) )
+			// Ok.
+			return true;
+
+		if ( type->Tag() == TYPE_TABLE && type->AsTableType()->IsUnspecifiedTable() )
+			// Ok.
+			return true;
+
+		auto e = check_and_promote_expr(a->GetExpr(), type);
+
+		if ( e )
+			{
+			a->SetAttrExpr(std::move(e));
+			// Ok.
+			return true;
+			}
+
+		a->GetExpr()->Error("&default value has inconsistent type", type.get());
+		return false;
+		}
+
+	TableType* tt = type->AsTableType();
+	const auto& ytype = tt->Yield();
+
+	if ( ! in_record )
+		{ // &default applies to the type itself.
+		if ( same_type(atype, ytype) )
+			return true;
+
+		// It can still be a default function.
+		if ( atype->Tag() == TYPE_FUNC )
+			{
+			FuncType* f = atype->AsFuncType();
+			if ( ! f->CheckArgs(tt->GetIndexTypes()) || ! same_type(f->Yield(), ytype) )
+				{
+				err_msg = "&default function type clash";
+				return false;
+				}
+
+			// Ok.
+			return true;
+			}
+
+		// Table defaults may be promotable.
+		if ( (ytype->Tag() == TYPE_RECORD && atype->Tag() == TYPE_RECORD &&
+		      record_promotion_compatible(atype->AsRecordType(), ytype->AsRecordType())) )
+			// Ok.
+			return true;
+
+		auto e = check_and_promote_expr(a->GetExpr(), ytype);
+
+		if ( e )
+			{
+			a->SetAttrExpr(std::move(e));
+			// Ok.
+			return true;
+			}
+
+		err_msg = "&default value has inconsistent type";
+		return false;
+		}
+
+	// &default applies to record field.
+
+	if ( same_type(atype, type) )
+		return true;
+
+	if ( (atype->Tag() == TYPE_TABLE && atype->AsTableType()->IsUnspecifiedTable()) )
+		{
+		auto e = check_and_promote_expr(a->GetExpr(), type);
+
+		if ( e )
+			{
+			a->SetAttrExpr(std::move(e));
+			return true;
+			}
+		}
+
+	// Table defaults may be promotable.
+	if ( ytype && ytype->Tag() == TYPE_RECORD && atype->Tag() == TYPE_RECORD &&
+	     record_promotion_compatible(atype->AsRecordType(), ytype->AsRecordType()) )
+		// Ok.
+		return true;
+
+	err_msg = "&default value has inconsistent type";
+	return false;
+	}
+
+detail::TraversalCode Attributes::Traverse(detail::TraversalCallback* cb) const
+	{
+	auto tc = cb->PreAttrs(this);
+	HANDLE_TC_ATTRS_PRE(tc);
+
+	for ( const auto& a : attrs )
+		{
+		tc = a->Traverse(cb);
+		HANDLE_TC_ATTRS_PRE(tc);
+		}
+
+	tc = cb->PostAttrs(this);
+	HANDLE_TC_ATTRS_POST(tc);
+	}
+
 	}
