@@ -2,7 +2,7 @@
 
 #include "zeek/zeek-config.h"
 
-#include <math.h>
+#include <cmath>
 
 #include "zeek/Conn.h"
 #include "zeek/Reporter.h"
@@ -184,17 +184,17 @@ int Base64Converter::Decode(int len, const char* data, int* pblen, char** pbuf)
 		if ( dlen >= len )
 			break;
 
-		unsigned char c = (unsigned char)data[dlen];
-		if ( c == '=' )
+		if ( data[dlen] == '=' )
 			++base64_padding;
 
-		int k = base64_table[c];
+		int k = base64_table[(unsigned char)data[dlen]];
 		if ( k >= 0 )
 			base64_group[base64_group_next++] = k;
 		else
 			{
 			if ( ++errored == 1 )
-				IllegalEncoding(util::fmt("character %d ignored by Base64 decoding", (int)c));
+				IllegalEncoding(
+					util::fmt("character %d ignored by Base64 decoding", (int)(data[dlen])));
 			}
 
 		++dlen;
