@@ -1,11 +1,12 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
 #include "zeek/BifReturnVal.h"
+
 #include "zeek/Val.h"
 
-namespace zeek::detail {
+namespace zeek::detail
+	{
 
-BifReturnVal::BifReturnVal(std::nullptr_t) noexcept
-	{}
+BifReturnVal::BifReturnVal(std::nullptr_t) noexcept { }
 
-} // namespace zeek::detail
+	} // namespace zeek::detail
