@@ -418,18 +418,6 @@ void DFA_Machine::Dump(FILE* f)
 	start_state->ClearMarks();
 	}
 
-unsigned int DFA_Machine::MemoryAllocation() const
-	{
-	DFA_State_Cache::Stats s;
-	dfa_state_cache->GetStats(&s);
-
-	// FIXME: Count *ec?
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-	return padded_sizeof(*this) + s.mem + padded_sizeof(*start_state) + nfa->MemoryAllocation();
-#pragma GCC diagnostic pop
-	}
-
 bool DFA_Machine::StateSetToDFA_State(NFA_state_list* state_set, DFA_State*& d,
                                       const EquivClass* ec)
 	{
