@@ -4,25 +4,25 @@
 
 #include "zeek/zeek-config.h"
 
-#include <errno.h>
 #include <netdb.h>
 #include <netinet/in.h>
-#include <stdlib.h>
 #include <sys/select.h>
 #include <sys/socket.h>
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <unistd.h>
 #include <algorithm>
+#include <cerrno>
+#include <cstdlib>
 #include <vector>
 
 #ifdef TIME_WITH_SYS_TIME
 #include <sys/time.h>
-#include <time.h>
+#include <ctime>
 #elif defined(HAVE_SYS_TIME_H)
 #include <sys/time.h>
 #else
-#include <time.h>
+#include <ctime>
 #endif
 
 #include <ztd/out_ptr.hpp>
@@ -1256,11 +1256,7 @@ TableValPtr DNS_Mgr::LookupNameInCache(const std::string& name, bool cleanup_exp
 	if ( cleanup_expired && (d && d->Expired()) )
 		{
 		all_mappings.erase(it);
-
-		// If the TTL is zero, we're immediately expiring the response. We don't want
-		// to return though because the response was valid for a brief moment in time.
-		if ( d->TTL() != 0 )
-			return nullptr;
+		return nullptr;
 		}
 
 	if ( check_failed && (d && d->Failed()) )
@@ -1283,11 +1279,7 @@ StringValPtr DNS_Mgr::LookupAddrInCache(const IPAddr& addr, bool cleanup_expired
 	if ( cleanup_expired && d->Expired() )
 		{
 		all_mappings.erase(it);
-
-		// If the TTL is zero, we're immediately expiring the response. We don't want
-		// to return though because the response was valid for a brief moment in time.
-		if ( d->TTL() != 0 )
-			return nullptr;
+		return nullptr;
 		}
 	else if ( check_failed && d->Failed() )
 		{
@@ -1314,11 +1306,7 @@ StringValPtr DNS_Mgr::LookupOtherInCache(const std::string& name, int request_ty
 	if ( cleanup_expired && d->Expired() )
 		{
 		all_mappings.erase(it);
-
-		// If the TTL is zero, we're immediately expiring the response. We don't want
-		// to return though because the response was valid for a brief moment in time.
-		if ( d->TTL() != 0 )
-			return nullptr;
+		return nullptr;
 		}
 
 	if ( d->Host() )
@@ -1552,6 +1540,12 @@ TableValPtr DNS_Mgr::empty_addr_set()
 //////////////////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////////////////
 
+// Unit testing coverage for the DNS_Mgr code, including making actual DNS requests to
+// test responses and timeouts. Note that all of these tests are marked with the skip
+// decorator, since they take some time to run and this slows down local developement. To
+// run them manually, pass the --no-skip flag when running tests. These tests are
+// run automatically as part of CI builds.
+
 static std::vector<IPAddr> get_result_addresses(TableValPtr addrs)
 	{
 	std::vector<IPAddr> results;
@@ -1617,7 +1611,7 @@ void TestDNS_Mgr::Process()
 	IssueAsyncRequests();
 	}
 
-TEST_CASE("dns_mgr priming")
+TEST_CASE("dns_mgr priming" * doctest::skip(true))
 	{
 	char prefix[] = "/tmp/zeek-unit-test-XXXXXX";
 	auto tmpdir = mkdtemp(prefix);
@@ -1666,7 +1660,7 @@ TEST_CASE("dns_mgr priming")
 	rmdir(tmpdir);
 	}
 
-TEST_CASE("dns_mgr alternate server")
+TEST_CASE("dns_mgr alternate server" * doctest::skip(true))
 	{
 	char* old_server = getenv("ZEEK_DNS_RESOLVER");
 
@@ -1695,7 +1689,7 @@ TEST_CASE("dns_mgr alternate server")
 		unsetenv("ZEEK_DNS_RESOLVER");
 	}
 
-TEST_CASE("dns_mgr default mode")
+TEST_CASE("dns_mgr default mode" * doctest::skip(true))
 	{
 	TestDNS_Mgr mgr(DNS_DEFAULT);
 	mgr.InitPostScript();
@@ -1727,7 +1721,7 @@ TEST_CASE("dns_mgr default mode")
 	CHECK(strcmp(addr_result->CheckString(), "240.0.0.0") == 0);
 	}
 
-TEST_CASE("dns_mgr async host")
+TEST_CASE("dns_mgr async host" * doctest::skip(true))
 	{
 	TestDNS_Mgr mgr(DNS_DEFAULT);
 	mgr.InitPostScript();
@@ -1758,7 +1752,7 @@ TEST_CASE("dns_mgr async host")
 	mgr.Flush();
 	}
 
-TEST_CASE("dns_mgr async addr")
+TEST_CASE("dns_mgr async addr" * doctest::skip(true))
 	{
 	TestDNS_Mgr mgr(DNS_DEFAULT);
 	mgr.InitPostScript();
@@ -1784,7 +1778,7 @@ TEST_CASE("dns_mgr async addr")
 	mgr.Flush();
 	}
 
-TEST_CASE("dns_mgr async text")
+TEST_CASE("dns_mgr async text" * doctest::skip(true))
 	{
 	TestDNS_Mgr mgr(DNS_DEFAULT);
 	mgr.InitPostScript();
@@ -1810,7 +1804,7 @@ TEST_CASE("dns_mgr async text")
 	mgr.Flush();
 	}
 
-TEST_CASE("dns_mgr timeouts")
+TEST_CASE("dns_mgr timeouts" * doctest::skip(true))
 	{
 	char* old_server = getenv("ZEEK_DNS_RESOLVER");
 
@@ -1836,7 +1830,7 @@ TEST_CASE("dns_mgr timeouts")
 		unsetenv("ZEEK_DNS_RESOLVER");
 	}
 
-TEST_CASE("dns_mgr async timeouts")
+TEST_CASE("dns_mgr async timeouts" * doctest::skip(true))
 	{
 	char* old_server = getenv("ZEEK_DNS_RESOLVER");
 
