@@ -1,9 +1,9 @@
-// Support routines to help deal with Bro debugging commands and
+// Support routines to help deal with Zeek debugging commands and
 // implementation of most commands.
 
 #pragma once
 
-#include <stdlib.h>
+#include <cstdlib>
 #include <deque>
 #include <string>
 #include <vector>
