@@ -1,20 +1,21 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
-#include "zeek/zeek-config.h"
-
 #include "zeek/Discard.h"
 
+#include "zeek/zeek-config.h"
+
 #include <algorithm>
 
-#include "zeek/ZeekString.h"
-#include "zeek/RunState.h"
 #include "zeek/Func.h"
-#include "zeek/Var.h"
-#include "zeek/Val.h"
 #include "zeek/IP.h"
 #include "zeek/Reporter.h" // for InterpreterException
+#include "zeek/RunState.h"
+#include "zeek/Val.h"
+#include "zeek/Var.h"
+#include "zeek/ZeekString.h"
 
-namespace zeek::detail {
+namespace zeek::detail
+	{
 
 Discarder::Discarder()
 	{
@@ -26,16 +27,14 @@ Discarder::Discarder()
 	discarder_maxlen = static_cast<int>(id::find_val("discarder_maxlen")->AsCount());
 	}
 
-Discarder::~Discarder()
-	{
-	}
+Discarder::~Discarder() { }
 
 bool Discarder::IsActive()
 	{
 	return check_ip || check_tcp || check_udp || check_icmp;
 	}
 
-bool Discarder::NextPacket(const std::unique_ptr<IP_Hdr>& ip, int len, int caplen)
+bool Discarder::NextPacket(const std::shared_ptr<IP_Hdr>& ip, int len, int caplen)
 	{
 	bool discard_packet = false;
 
@@ -58,8 +57,7 @@ bool Discarder::NextPacket(const std::unique_ptr<IP_Hdr>& ip, int len, int caple
 		}
 
 	int proto = ip->NextProto();
-	if ( proto != IPPROTO_TCP && proto != IPPROTO_UDP &&
-	     proto != IPPROTO_ICMP )
+	if ( proto != IPPROTO_TCP && proto != IPPROTO_UDP && proto != IPPROTO_ICMP )
 		// This is not a protocol we understand.
 		return false;
 
@@ -69,14 +67,13 @@ bool Discarder::NextPacket(const std::unique_ptr<IP_Hdr>& ip, int len, int caple
 		return false;
 
 	int ip_hdr_len = ip->HdrLen();
-	len -= ip_hdr_len;	// remove IP header
+	len -= ip_hdr_len; // remove IP header
 	caplen -= ip_hdr_len;
 
 	bool is_tcp = (proto == IPPROTO_TCP);
 	bool is_udp = (proto == IPPROTO_UDP);
-	int min_hdr_len = is_tcp ?
-		sizeof(struct tcphdr) :
-		(is_udp ? sizeof(struct udphdr) : sizeof(struct icmp));
+	int min_hdr_len = is_tcp ? sizeof(struct tcphdr)
+	                         : (is_udp ? sizeof(struct udphdr) : sizeof(struct icmp));
 
 	if ( len < min_hdr_len || caplen < min_hdr_len )
 		// we don't have a complete protocol header
@@ -90,7 +87,7 @@ bool Discarder::NextPacket(const std::unique_ptr<IP_Hdr>& ip, int len, int caple
 		{
 		if ( check_tcp )
 			{
-			const struct tcphdr* tp = (const struct tcphdr*) data;
+			const struct tcphdr* tp = (const struct tcphdr*)data;
 			int th_len = tp->th_off * 4;
 
 			zeek::Args args{
@@ -114,8 +111,8 @@ bool Discarder::NextPacket(const std::unique_ptr<IP_Hdr>& ip, int len, int caple
 		{
 		if ( check_udp )
 			{
-			const struct udphdr* up = (const struct udphdr*) data;
-			int uh_len = sizeof (struct udphdr);
+			const struct udphdr* up = (const struct udphdr*)data;
+			int uh_len = sizeof(struct udphdr);
 
 			zeek::Args args{
 				ip->ToPktHdrVal(),
@@ -138,7 +135,7 @@ bool Discarder::NextPacket(const std::unique_ptr<IP_Hdr>& ip, int len, int caple
 		{
 		if ( check_icmp )
 			{
-			const struct icmp* ih = (const struct icmp*) data;
+			const struct icmp* ih = (const struct icmp*)data;
 
 			zeek::Args args{ip->ToPktHdrVal()};
 
@@ -168,4 +165,4 @@ Val* Discarder::BuildData(const u_char* data, int hdrlen, int len, int caplen)
 	return new StringVal(new String(data, len, true));
 	}
 
-} // namespace zeek::detail
+	} // namespace zeek::detail
