@@ -7,23 +7,26 @@
 
 #include "zeek/IntrusivePtr.h"
 
-namespace zeek {
+namespace zeek
+	{
 
 class IP_Hdr;
 class Val;
 class Func;
 using FuncPtr = IntrusivePtr<Func>;
 
-namespace detail {
+namespace detail
+	{
 
-class Discarder {
+class Discarder
+	{
 public:
 	Discarder();
 	~Discarder();
 
 	bool IsActive();
 
-	bool NextPacket(const std::unique_ptr<IP_Hdr>& ip, int len, int caplen);
+	bool NextPacket(const std::shared_ptr<IP_Hdr>& ip, int len, int caplen);
 
 protected:
 	Val* BuildData(const u_char* data, int hdrlen, int len, int caplen);
@@ -35,7 +38,7 @@ protected:
 
 	// Maximum amount of application data passed to filtering functions.
 	int discarder_maxlen;
-};
+	};
 
-} // namespace detail
-} // namespace zeek
+	} // namespace detail
+	} // namespace zeek
