@@ -20,9 +20,9 @@ class EventHandler
 public:
 	explicit EventHandler(std::string name);
 
-	const char* Name() { return name.data(); }
+	const char* Name() const { return name.data(); }
 
-	const FuncPtr& GetFunc() { return local; }
+	const FuncPtr& GetFunc() const { return local; }
 
 	const FuncTypePtr& GetType(bool check_export = true);
 
