@@ -31,7 +31,7 @@ struct function_ingredients;
 using IDPtr = IntrusivePtr<ID>;
 using ScopePtr = IntrusivePtr<Scope>;
 
-enum BroExprTag : int
+enum ExprTag : int
 	{
 	EXPR_ANY = -1,
 	EXPR_NAME,
@@ -53,6 +53,8 @@ enum BroExprTag : int
 	EXPR_AND,
 	EXPR_OR,
 	EXPR_XOR,
+	EXPR_LSHIFT,
+	EXPR_RSHIFT,
 	EXPR_AND_AND,
 	EXPR_OR_OR,
 	EXPR_LT,
@@ -104,7 +106,9 @@ enum BroExprTag : int
 #define NUM_EXPRS (int(EXPR_NOP) + 1)
 	};
 
-extern const char* expr_name(BroExprTag t);
+using BroExprTag [[deprecated("Remove in v6.1. Use ExprTag.")]] = ExprTag;
+
+extern const char* expr_name(ExprTag t);
 
 class AddToExpr;
 class AnyIndexExpr;
@@ -137,6 +141,7 @@ using EventExprPtr = IntrusivePtr<EventExpr>;
 using ExprPtr = IntrusivePtr<Expr>;
 using NameExprPtr = IntrusivePtr<NameExpr>;
 using RefExprPtr = IntrusivePtr<RefExpr>;
+using LambdaExprPtr = IntrusivePtr<LambdaExpr>;
 
 class Stmt;
 using StmtPtr = IntrusivePtr<Stmt>;
@@ -150,7 +155,7 @@ public:
 
 	template <class T> IntrusivePtr<T> GetType() const { return cast_intrusive<T>(type); }
 
-	BroExprTag Tag() const { return tag; }
+	ExprTag Tag() const { return tag; }
 
 	Expr* Ref()
 		{
@@ -163,12 +168,6 @@ public:
 	// or nil if the expression's value isn't fixed.
 	virtual ValPtr Eval(Frame* f) const = 0;
 
-	// Same, but the context is that we are adding an element
-	// into the given aggregate of the given type.  Note that
-	// return type is void since it's updating an existing
-	// value, rather than creating a new one.
-	virtual void EvalIntoAggregate(const zeek::Type* t, Val* aggr, Frame* f) const;
-
 	// Assign to the given value, if appropriate.
 	virtual void Assign(Frame* f, ValPtr v);
 
@@ -182,15 +181,8 @@ public:
 	// TypeDecl with a description of the element.
 	virtual bool IsRecordElement(TypeDecl* td) const;
 
-	// Returns a value corresponding to this expression interpreted
-	// as an initialization, or nil if the expression is inconsistent
-	// with the given type.  If "aggr" is non-nil, then this expression
-	// is an element of the given aggregate, and it is added to it
-	// accordingly.
-	virtual ValPtr InitVal(const zeek::Type* t, ValPtr aggr) const;
-
 	// True if the expression has no side effects, false otherwise.
-	virtual bool IsPure() const;
+	virtual bool IsPure() const { return true; }
 
 	// True if the expression is a constant, false otherwise.
 	bool IsConst() const { return tag == EXPR_CONST; }
@@ -418,11 +410,17 @@ public:
 	// this statement.
 	ExprOptInfo* GetOptInfo() const { return opt_info; }
 
+	// Returns the number of expressions created since the last reset.
+	static int GetNumExprs() { return num_exprs; }
+
+	// Clears the number of expressions created.
+	static void ResetNumExprs() { num_exprs = 0; }
+
 	~Expr() override;
 
 protected:
 	Expr() = default;
-	explicit Expr(BroExprTag arg_tag);
+	explicit Expr(ExprTag arg_tag);
 
 	virtual void ExprDescribe(ODesc* d) const = 0;
 	void AddTag(ODesc* d) const;
@@ -441,7 +439,7 @@ protected:
 	[[noreturn]] void RuntimeError(const std::string& msg) const;
 	[[noreturn]] void RuntimeErrorWithCallStack(const std::string& msg) const;
 
-	BroExprTag tag;
+	ExprTag tag;
 	bool paren;
 	TypePtr type;
 
@@ -453,6 +451,9 @@ protected:
 	// Information associated with the Expr for purposes of
 	// script optimization.
 	ExprOptInfo* opt_info;
+
+	// Number of expressions created thus far.
+	static int num_exprs;
 	};
 
 class NameExpr final : public Expr
@@ -466,7 +467,6 @@ public:
 	ValPtr Eval(Frame* f) const override;
 	void Assign(Frame* f, ValPtr v) override;
 	ExprPtr MakeLvalue() override;
-	bool IsPure() const override;
 
 	TraversalCode Traverse(TraversalCallback* cb) const override;
 
@@ -537,7 +537,7 @@ public:
 	void SetOp1(ExprPtr _op) override final { op = std::move(_op); }
 
 protected:
-	UnaryExpr(BroExprTag arg_tag, ExprPtr arg_op);
+	UnaryExpr(ExprTag arg_tag, ExprPtr arg_op);
 
 	void ExprDescribe(ODesc* d) const override;
 
@@ -577,7 +577,7 @@ public:
 	void SetOp2(ExprPtr _op) override final { op2 = std::move(_op); }
 
 protected:
-	BinaryExpr(BroExprTag arg_tag, ExprPtr arg_op1, ExprPtr arg_op2)
+	BinaryExpr(ExprTag arg_tag, ExprPtr arg_op1, ExprPtr arg_op2)
 		: Expr(arg_tag), op1(std::move(arg_op1)), op2(std::move(arg_op2))
 		{
 		if ( ! (op1 && op2) )
@@ -598,6 +598,9 @@ protected:
 	// Same for when the constants are sets.
 	virtual ValPtr SetFold(Val* v1, Val* v2) const;
 
+	// Same for when the constants are tables.
+	virtual ValPtr TableFold(Val* v1, Val* v2) const;
+
 	// Same for when the constants are addresses or subnets.
 	virtual ValPtr AddrFold(Val* v1, Val* v2) const;
 	virtual ValPtr SubNetFold(Val* v1, Val* v2) const;
@@ -621,6 +624,20 @@ protected:
 
 	void ExprDescribe(ODesc* d) const override;
 
+	// Reports on if this BinaryExpr involves a scalar and aggregate
+	// type (vec, list, table, record).
+	bool IsScalarAggregateOp() const;
+
+	// Warns about deprecated scalar vector operations like
+	// `[1, 2, 3] == 1` or `["a", "b", "c"] + "a"`.
+	void CheckScalarAggOp() const;
+
+	// For assignment operations (=, +=, -=) checks for a valid
+	// expression-list on the RHS (op2), potentially transforming
+	// op2 in the process.  Returns true if the list is present
+	// and type-checks correctly, false otherwise.
+	bool CheckForRHSList();
+
 	ExprPtr op1;
 	ExprPtr op2;
 	};
@@ -641,11 +658,11 @@ protected:
 class IncrExpr final : public UnaryExpr
 	{
 public:
-	IncrExpr(BroExprTag tag, ExprPtr op);
+	IncrExpr(ExprTag tag, ExprPtr op);
 
 	ValPtr Eval(Frame* f) const override;
 	ValPtr DoSingleEval(Frame* f, Val* v) const;
-	bool IsPure() const override;
+	bool IsPure() const override { return false; }
 
 	// Optimization-related:
 	ExprPtr Duplicate() override;
@@ -748,21 +765,33 @@ public:
 	ValPtr Eval(Frame* f) const override;
 
 	// Optimization-related:
+	bool IsPure() const override { return false; }
 	ExprPtr Duplicate() override;
+	bool HasReducedOps(Reducer* c) const override { return false; }
 	bool WillTransform(Reducer* c) const override { return true; }
+	bool IsReduced(Reducer* c) const override;
 	ExprPtr Reduce(Reducer* c, StmtPtr& red_stmt) override;
+	ExprPtr ReduceToSingleton(Reducer* c, StmtPtr& red_stmt) override;
+
+private:
+	// Whether this operation is appending a single element to a vector.
+	bool is_vector_elem_append = false;
 	};
 
 class RemoveFromExpr final : public BinaryExpr
 	{
 public:
+	bool IsPure() const override { return false; }
 	RemoveFromExpr(ExprPtr op1, ExprPtr op2);
 	ValPtr Eval(Frame* f) const override;
 
 	// Optimization-related:
 	ExprPtr Duplicate() override;
+	bool HasReducedOps(Reducer* c) const override { return false; }
 	bool WillTransform(Reducer* c) const override { return true; }
+	bool IsReduced(Reducer* c) const override;
 	ExprPtr Reduce(Reducer* c, StmtPtr& red_stmt) override;
+	ExprPtr ReduceToSingleton(Reducer* c, StmtPtr& red_stmt) override;
 	};
 
 class SubExpr final : public BinaryExpr
@@ -814,7 +843,7 @@ public:
 class BoolExpr final : public BinaryExpr
 	{
 public:
-	BoolExpr(BroExprTag tag, ExprPtr op1, ExprPtr op2);
+	BoolExpr(ExprTag tag, ExprPtr op1, ExprPtr op2);
 
 	ValPtr Eval(Frame* f) const override;
 	ValPtr DoSingleEval(Frame* f, ValPtr v1, Expr* op2) const;
@@ -833,7 +862,7 @@ protected:
 class BitExpr final : public BinaryExpr
 	{
 public:
-	BitExpr(BroExprTag tag, ExprPtr op1, ExprPtr op2);
+	BitExpr(ExprTag tag, ExprPtr op1, ExprPtr op2);
 
 	// Optimization-related:
 	ExprPtr Duplicate() override;
@@ -844,7 +873,7 @@ public:
 class EqExpr final : public BinaryExpr
 	{
 public:
-	EqExpr(BroExprTag tag, ExprPtr op1, ExprPtr op2);
+	EqExpr(ExprTag tag, ExprPtr op1, ExprPtr op2);
 	void Canonicize() override;
 
 	// Optimization-related:
@@ -860,7 +889,7 @@ protected:
 class RelExpr final : public BinaryExpr
 	{
 public:
-	RelExpr(BroExprTag tag, ExprPtr op1, ExprPtr op2);
+	RelExpr(ExprTag tag, ExprPtr op1, ExprPtr op2);
 	void Canonicize() override;
 
 	// Optimization-related:
@@ -939,11 +968,9 @@ public:
 	           const AttributesPtr& attrs = nullptr, bool type_check = true);
 
 	ValPtr Eval(Frame* f) const override;
-	void EvalIntoAggregate(const zeek::Type* t, Val* aggr, Frame* f) const override;
 	TypePtr InitType() const override;
 	bool IsRecordElement(TypeDecl* td) const override;
-	ValPtr InitVal(const zeek::Type* t, ValPtr aggr) const override;
-	bool IsPure() const override;
+	bool IsPure() const override { return false; }
 
 	// Optimization-related:
 	ExprPtr Duplicate() override;
@@ -959,6 +986,15 @@ public:
 	bool IsTemp() const { return is_temp; }
 	void SetIsTemp() { is_temp = true; }
 
+	// The following is a hack that's used in "when" expressions to support
+	// assignments to new locals, like "when ( (local l = foo()) && ...".
+	// These methods return the value to use when evaluating such
+	// assignments.  That would normally be the RHS of the assignment,
+	// but to get when's to work in a convenient fashion, for them it's
+	// instead boolean T.
+	ValPtr AssignVal() { return val; }
+	const ValPtr& AssignVal() const { return val; }
+
 protected:
 	bool TypeCheck(const AttributesPtr& attrs = nullptr);
 	bool TypeCheckArithmetics(TypeTag bt1, TypeTag bt2);
@@ -982,7 +1018,7 @@ public:
 class IndexExpr : public BinaryExpr
 	{
 public:
-	IndexExpr(ExprPtr op1, ListExprPtr op2, bool is_slice = false);
+	IndexExpr(ExprPtr op1, ListExprPtr op2, bool is_slice = false, bool is_inside_when = false);
 
 	bool CanAdd() const override;
 	bool CanDel() const override;
@@ -998,6 +1034,7 @@ public:
 	ValPtr Eval(Frame* f) const override;
 
 	bool IsSlice() const { return is_slice; }
+	bool IsInsideWhen() const { return is_inside_when; }
 
 	// Optimization-related:
 	ExprPtr Duplicate() override;
@@ -1011,6 +1048,7 @@ protected:
 	void ExprDescribe(ODesc* d) const override;
 
 	bool is_slice;
+	bool is_inside_when;
 	};
 
 // The following execute the heart of IndexExpr functionality for
@@ -1036,6 +1074,13 @@ extern VectorValPtr vector_bool_select(VectorTypePtr vt, const VectorVal* v1, co
 // indices to select).
 extern VectorValPtr vector_int_select(VectorTypePtr vt, const VectorVal* v1, const VectorVal* v2);
 
+// The following is used for index expressions that occur inside "when"
+// clauses.  It tracks all the results produced by evaluating indexing
+// aggregates, so that if any of them are Modifiable(), the associated
+// Trigger can register interest in changes to them.
+//
+// TODO: One Fine Day we should do the equivalent for accessing fields
+// in records, too.
 class IndexExprWhen final : public IndexExpr
 	{
 public:
@@ -1054,7 +1099,7 @@ public:
 		}
 
 	IndexExprWhen(ExprPtr op1, ListExprPtr op2, bool is_slice = false)
-		: IndexExpr(std::move(op1), std::move(op2), is_slice)
+		: IndexExpr(std::move(op1), std::move(op2), is_slice, true)
 		{
 		}
 
@@ -1143,14 +1188,13 @@ public:
 
 	// Optimization-related:
 	ExprPtr Duplicate() override;
+	ExprPtr Inline(Inliner* inl) override;
 
 	bool HasReducedOps(Reducer* c) const override;
 	ExprPtr Reduce(Reducer* c, StmtPtr& red_stmt) override;
 	StmtPtr ReduceToSingletons(Reducer* c) override;
 
 protected:
-	ValPtr InitVal(const zeek::Type* t, ValPtr aggr) const override;
-
 	void ExprDescribe(ODesc* d) const override;
 
 	ListExprPtr op;
@@ -1163,10 +1207,13 @@ public:
 	TableConstructorExpr(ListExprPtr constructor_list, std::unique_ptr<std::vector<AttrPtr>> attrs,
 	                     TypePtr arg_type = nullptr, AttributesPtr arg_attrs = nullptr);
 
+	void SetAttrs(AttributesPtr _attrs) { attrs = std::move(_attrs); }
 	const AttributesPtr& GetAttrs() const { return attrs; }
 
 	ValPtr Eval(Frame* f) const override;
 
+	TraversalCode Traverse(TraversalCallback* cb) const override;
+
 	// Optimization-related:
 	ExprPtr Duplicate() override;
 
@@ -1175,8 +1222,6 @@ public:
 	StmtPtr ReduceToSingletons(Reducer* c) override;
 
 protected:
-	ValPtr InitVal(const zeek::Type* t, ValPtr aggr) const override;
-
 	void ExprDescribe(ODesc* d) const override;
 
 	AttributesPtr attrs;
@@ -1188,10 +1233,13 @@ public:
 	SetConstructorExpr(ListExprPtr constructor_list, std::unique_ptr<std::vector<AttrPtr>> attrs,
 	                   TypePtr arg_type = nullptr, AttributesPtr arg_attrs = nullptr);
 
+	void SetAttrs(AttributesPtr _attrs) { attrs = std::move(_attrs); }
 	const AttributesPtr& GetAttrs() const { return attrs; }
 
 	ValPtr Eval(Frame* f) const override;
 
+	TraversalCode Traverse(TraversalCallback* cb) const override;
+
 	// Optimization-related:
 	ExprPtr Duplicate() override;
 
@@ -1200,8 +1248,6 @@ public:
 	StmtPtr ReduceToSingletons(Reducer* c) override;
 
 protected:
-	ValPtr InitVal(const zeek::Type* t, ValPtr aggr) const override;
-
 	void ExprDescribe(ODesc* d) const override;
 
 	AttributesPtr attrs;
@@ -1220,8 +1266,6 @@ public:
 	bool HasReducedOps(Reducer* c) const override;
 
 protected:
-	ValPtr InitVal(const zeek::Type* t, ValPtr aggr) const override;
-
 	void ExprDescribe(ODesc* d) const override;
 	};
 
@@ -1240,12 +1284,10 @@ public:
 	// (in which case an error is reported).
 	bool PromoteTo(TypePtr t);
 
-	void EvalIntoAggregate(const zeek::Type* t, Val* aggr, Frame* f) const override;
 	bool IsRecordElement(TypeDecl* td) const override;
 
 	// Optimization-related:
 	ExprPtr Duplicate() override;
-
 	bool WillTransform(Reducer* c) const override { return true; }
 	ExprPtr Reduce(Reducer* c, StmtPtr& red_stmt) override;
 
@@ -1282,7 +1324,6 @@ public:
 	const std::vector<int>& Map() const { return map; }
 
 protected:
-	ValPtr InitVal(const zeek::Type* t, ValPtr aggr) const override;
 	ValPtr Fold(Val* v) const override;
 
 	// For each super-record slot, gives subrecord slot with which to
@@ -1295,7 +1336,7 @@ extern RecordValPtr coerce_to_record(RecordTypePtr rt, Val* v, const std::vector
 class TableCoerceExpr final : public UnaryExpr
 	{
 public:
-	TableCoerceExpr(ExprPtr op, TableTypePtr r);
+	TableCoerceExpr(ExprPtr op, TableTypePtr r, bool type_check = true);
 	~TableCoerceExpr() override;
 
 	// Optimization-related:
@@ -1336,7 +1377,7 @@ class ScheduleExpr final : public Expr
 public:
 	ScheduleExpr(ExprPtr when, EventExprPtr event);
 
-	bool IsPure() const override;
+	bool IsPure() const override { return false; }
 
 	ValPtr Eval(Frame* f) const override;
 
@@ -1383,13 +1424,14 @@ protected:
 class CallExpr final : public Expr
 	{
 public:
-	CallExpr(ExprPtr func, ListExprPtr args, bool in_hook = false);
+	CallExpr(ExprPtr func, ListExprPtr args, bool in_hook = false, bool in_when = false);
 
 	Expr* Func() const { return func.get(); }
 	ListExpr* Args() const { return args.get(); }
 	ListExprPtr ArgsPtr() const { return args; }
 
 	bool IsPure() const override;
+	bool IsInWhen() const { return in_when; }
 
 	ValPtr Eval(Frame* f) const override;
 
@@ -1409,6 +1451,7 @@ protected:
 
 	ExprPtr func;
 	ListExprPtr args;
+	bool in_when;
 	};
 
 /**
@@ -1419,7 +1462,8 @@ protected:
 class LambdaExpr final : public Expr
 	{
 public:
-	LambdaExpr(std::unique_ptr<function_ingredients> ingredients, IDPList outer_ids);
+	LambdaExpr(std::unique_ptr<function_ingredients> ingredients, IDPList outer_ids,
+	           StmtPtr when_parent = nullptr);
 
 	const std::string& Name() const { return my_name; }
 	const IDPList& OuterIDs() const { return outer_ids; }
@@ -1440,12 +1484,11 @@ protected:
 	void ExprDescribe(ODesc* d) const override;
 
 private:
-	void CheckCaptures();
+	bool CheckCaptures(StmtPtr when_parent);
 
 	std::unique_ptr<function_ingredients> ingredients;
-
+	IDPtr lambda_id;
 	IDPList outer_ids;
-	bool capture_by_ref; // if true, use deprecated reference semantics
 
 	std::string my_name;
 	};
@@ -1470,7 +1513,6 @@ public:
 	ValPtr Eval(Frame* f) const override;
 
 	TypePtr InitType() const override;
-	ValPtr InitVal(const zeek::Type* t, ValPtr aggr) const override;
 	ExprPtr MakeLvalue() override;
 	void Assign(Frame* f, ValPtr v) override;
 
@@ -1486,8 +1528,6 @@ public:
 	StmtPtr ReduceToSingletons(Reducer* c) override;
 
 protected:
-	ValPtr AddSetInit(const zeek::Type* t, ValPtr aggr) const;
-
 	void ExprDescribe(ODesc* d) const override;
 
 	ExprPList exprs;
@@ -1605,10 +1645,12 @@ public:
 	AppendToExpr(ExprPtr op1, ExprPtr op2);
 	ValPtr Eval(Frame* f) const override;
 
+	ExprPtr Duplicate() override;
+
+	bool IsPure() const override { return false; }
 	bool IsReduced(Reducer* c) const override;
 	ExprPtr Reduce(Reducer* c, StmtPtr& red_stmt) override;
-
-	ExprPtr Duplicate() override;
+	ExprPtr ReduceToSingleton(Reducer* c, StmtPtr& red_stmt) override;
 	};
 
 // An internal class for reduced form.
@@ -1622,6 +1664,7 @@ public:
 
 	ExprPtr Duplicate() override;
 
+	bool IsPure() const override { return false; }
 	bool IsReduced(Reducer* c) const override;
 	bool HasReducedOps(Reducer* c) const override;
 	ExprPtr Reduce(Reducer* c, StmtPtr& red_stmt) override;
@@ -1653,6 +1696,7 @@ public:
 
 	ExprPtr Duplicate() override;
 
+	bool IsPure() const override { return false; }
 	bool IsReduced(Reducer* c) const override;
 	bool HasReducedOps(Reducer* c) const override;
 	ExprPtr Reduce(Reducer* c, StmtPtr& red_stmt) override;
@@ -1752,7 +1796,14 @@ inline Val* Expr::ExprVal() const
 	}
 
 // Decides whether to return an AssignExpr or a RecordAssignExpr.
-ExprPtr get_assign_expr(ExprPtr op1, ExprPtr op2, bool is_init);
+extern ExprPtr get_assign_expr(ExprPtr op1, ExprPtr op2, bool is_init);
+
+// Takes a RHS constructor list and returns a version with any embedded
+// indices within it (used to concisely represent multiple set/table entries)
+// expanded.
+//
+// Second argument gives the type that the list will expand to, if known.
+extern ListExprPtr expand_op(ListExprPtr op, const TypePtr& t);
 
 /**
  * Type-check the given expression(s) against the given type(s).  Complain
@@ -1767,13 +1818,13 @@ ExprPtr get_assign_expr(ExprPtr op1, ExprPtr op2, bool is_init);
  */
 extern ExprPtr check_and_promote_expr(ExprPtr e, TypePtr t);
 
-extern bool check_and_promote_exprs(ListExpr* elements, TypeList* types);
+extern bool check_and_promote_exprs(ListExpr* elements, const TypeListPtr& types);
 extern bool check_and_promote_args(ListExpr* args, const RecordType* types);
 extern bool check_and_promote_exprs_to_type(ListExpr* elements, TypePtr type);
 
 // Returns a ListExpr simplified down to a list a values, or nil
 // if they couldn't all be reduced.
-std::optional<std::vector<ValPtr>> eval_list(Frame* f, const ListExpr* l);
+extern std::optional<std::vector<ValPtr>> eval_list(Frame* f, const ListExpr* l);
 
 // Returns true if e1 is "greater" than e2 - here "greater" is just
 // a heuristic, used with commutative operators to put them into
@@ -1790,5 +1841,16 @@ inline bool is_vector(const ExprPtr& e)
 	return is_vector(e.get());
 	}
 
+// True if the given Expr* has a list type
+inline bool is_list(Expr* e)
+	{
+	return e->GetType()->Tag() == TYPE_LIST;
+	}
+
+inline bool is_list(const ExprPtr& e)
+	{
+	return is_list(e.get());
+	}
+
 	} // namespace detail
 	} // namespace zeek
