@@ -7,19 +7,19 @@
 #include <sys/types.h>
 #ifdef TIME_WITH_SYS_TIME
 #include <sys/time.h>
-#include <time.h>
+#include <ctime>
 #else
 #ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
 #else
-#include <time.h>
+#include <ctime>
 #endif
 #endif
-#include <errno.h>
 #include <sys/resource.h>
 #include <sys/stat.h>
 #include <unistd.h>
 #include <algorithm>
+#include <cerrno>
 
 #include "zeek/Attr.h"
 #include "zeek/Desc.h"
