@@ -5,34 +5,22 @@
 
 #include "zeek/zeek-config.h"
 
-#include <sys/stat.h>
-#include <sys/types.h>
-#ifdef TIME_WITH_SYS_TIME
-#include <sys/time.h>
-#include <time.h>
-#else
-#ifdef HAVE_SYS_TIME_H
-#include <sys/time.h>
-#else
-#include <time.h>
-#endif
-#endif
 #include <broker/error.hh>
-#include <ctype.h>
-#include <errno.h>
 #include <netdb.h>
 #include <netinet/in.h>
-#include <signal.h>
-#include <stdlib.h>
 #include <sys/param.h>
-#include <sys/resource.h>
 #include <unistd.h>
 #include <algorithm>
+#include <cctype>
+#include <cerrno>
+#include <csignal>
+#include <cstdlib>
 
 #include "zeek/Base64.h"
 #include "zeek/Debug.h"
 #include "zeek/Desc.h"
 #include "zeek/Event.h"
+#include "zeek/EventTrace.h"
 #include "zeek/Expr.h"
 #include "zeek/File.h"
 #include "zeek/Frame.h"
@@ -41,6 +29,7 @@
 #include "zeek/Reporter.h"
 #include "zeek/RunState.h"
 #include "zeek/Scope.h"
+#include "zeek/ScriptProfile.h"
 #include "zeek/Stmt.h"
 #include "zeek/Traverse.h"
 #include "zeek/Var.h"
@@ -132,20 +121,6 @@ std::string render_call_stack()
 	return rval;
 	}
 
-Func::Func()
-	{
-	unique_id = unique_ids.size();
-	unique_ids.push_back({NewRef{}, this});
-	}
-
-Func::Func(Kind arg_kind) : kind(arg_kind)
-	{
-	unique_id = unique_ids.size();
-	unique_ids.push_back({NewRef{}, this});
-	}
-
-Func::~Func() = default;
-
 void Func::AddBody(detail::StmtPtr /* new_body */,
                    const std::vector<detail::IDPtr>& /* new_inits */, size_t /* new_frame_size */,
                    int /* priority */)
@@ -237,7 +212,6 @@ void Func::CopyStateInto(Func* other) const
 	other->type = type;
 
 	other->name = name;
-	other->unique_id = unique_id;
 	}
 
 void Func::CheckPluginResult(bool handled, const ValPtr& hook_result, FunctionFlavor flavor) const
@@ -344,9 +318,6 @@ ScriptFunc::ScriptFunc(std::string _name, FuncTypePtr ft, std::vector<StmtPtr> b
 
 ScriptFunc::~ScriptFunc()
 	{
-	if ( ! weak_closure_ref )
-		Unref(closure);
-
 	delete captures_frame;
 	delete captures_offset_mapping;
 	}
@@ -362,9 +333,6 @@ bool ScriptFunc::IsPure() const
 
 ValPtr ScriptFunc::Invoke(zeek::Args* args, Frame* parent) const
 	{
-#ifdef PROFILE_BRO_FUNCTIONS
-	DEBUG_MSG("Function: %s\n", Name());
-#endif
 	SegmentProfiler prof(segment_logger, location);
 
 	if ( sample_logger )
@@ -387,20 +355,20 @@ ValPtr ScriptFunc::Invoke(zeek::Args* args, Frame* parent) const
 
 	auto f = make_intrusive<Frame>(frame_size, this, args);
 
-	if ( closure )
-		f->CaptureClosure(closure, outer_ids);
-
 	// Hand down any trigger.
 	if ( parent )
 		{
 		f->SetTrigger({NewRef{}, parent->GetTrigger()});
-		f->SetCall(parent->GetCall());
+		f->SetTriggerAssoc(parent->GetTriggerAssoc());
 		}
 
 	g_frame_stack.push_back(f.get()); // used for backtracing
 	const CallExpr* call_expr = parent ? parent->GetCall() : nullptr;
 	call_stack.emplace_back(CallInfo{call_expr, this, *args});
 
+	if ( etm && Flavor() == FUNC_FLAVOR_EVENT )
+		etm->StartEvent(this, args);
+
 	if ( g_trace_state.DoTrace() )
 		{
 		ODesc d;
@@ -428,6 +396,9 @@ ValPtr ScriptFunc::Invoke(zeek::Args* args, Frame* parent) const
 				f->SetElement(j, arg);
 			}
 
+		if ( spm )
+			spm->StartInvocation(this, body.stmts);
+
 		f->Reset(args->size());
 
 		try
@@ -450,6 +421,9 @@ ValPtr ScriptFunc::Invoke(zeek::Args* args, Frame* parent) const
 			continue;
 			}
 
+		if ( spm )
+			spm->EndInvocation();
+
 		if ( f->HasDelayed() )
 			{
 			assert(! result);
@@ -481,6 +455,9 @@ ValPtr ScriptFunc::Invoke(zeek::Args* args, Frame* parent) const
 			result = val_mgr->True();
 		}
 
+	else if ( etm && Flavor() == FUNC_FLAVOR_EVENT )
+		etm->EndEvent(this, args);
+
 	// Warn if the function returns something, but we returned from
 	// the function without an explicit return, or without a value.
 	else if ( GetType()->Yield() && GetType()->Yield()->Tag() != TYPE_VOID &&
@@ -603,71 +580,6 @@ void ScriptFunc::ReplaceBody(const StmtPtr& old_body, StmtPtr new_body)
 	current_body = new_body;
 	}
 
-void ScriptFunc::AddClosure(IDPList ids, Frame* f)
-	{
-	if ( ! f )
-		return;
-
-	SetOuterIDs(std::move(ids));
-	SetClosureFrame(f);
-	}
-
-bool ScriptFunc::StrengthenClosureReference(Frame* f)
-	{
-	if ( closure != f )
-		return false;
-
-	if ( ! weak_closure_ref )
-		return false;
-
-	closure = closure->SelectiveClone(outer_ids, this);
-	weak_closure_ref = false;
-	return true;
-	}
-
-bool ScriptFunc::HasCopySemantics() const
-	{
-	return type->GetCaptures().has_value();
-	}
-
-void ScriptFunc::SetClosureFrame(Frame* f)
-	{
-	if ( closure )
-		reporter->InternalError("Tried to override closure for ScriptFunc %s.", Name());
-
-	// Have to use weak references initially because otherwise Ref'ing the
-	// original frame creates a circular reference: the function holds a
-	// reference to the frame and the frame contains a reference to this
-	// function value.  And we can't just do a shallow clone of the frame
-	// up front because the closure semantics in Zeek allow mutating
-	// the outer frame.
-
-	closure = f;
-	weak_closure_ref = true;
-	f->AddFunctionWithClosureRef(this);
-	}
-
-bool ScriptFunc::UpdateClosure(const broker::vector& data)
-	{
-	auto result = Frame::Unserialize(data, {});
-
-	if ( ! result.first )
-		return false;
-
-	auto& new_closure = result.second;
-
-	if ( new_closure )
-		new_closure->SetFunction(this);
-
-	if ( ! weak_closure_ref )
-		Unref(closure);
-
-	weak_closure_ref = false;
-	closure = new_closure.release();
-
-	return true;
-	}
-
 bool ScriptFunc::DeserializeCaptures(const broker::vector& data)
 	{
 	auto result = Frame::Unserialize(data, GetType()->GetCaptures());
@@ -688,8 +600,6 @@ FuncPtr ScriptFunc::DoClone()
 	CopyStateInto(other.get());
 
 	other->frame_size = frame_size;
-	other->closure = closure ? closure->SelectiveClone(outer_ids, this) : nullptr;
-	other->weak_closure_ref = false;
 	other->outer_ids = outer_ids;
 
 	if ( captures_frame )
@@ -702,12 +612,13 @@ FuncPtr ScriptFunc::DoClone()
 	return other;
 	}
 
-broker::expected<broker::data> ScriptFunc::SerializeClosure() const
+broker::expected<broker::data> ScriptFunc::SerializeCaptures() const
 	{
 	if ( captures_frame )
 		return captures_frame->SerializeCopyFrame();
-	else
-		return closure->SerializeClosureFrame(outer_ids);
+
+	// No captures, return an empty vector.
+	return broker::vector{};
 	}
 
 void ScriptFunc::Describe(ODesc* d) const
@@ -762,9 +673,9 @@ bool BuiltinFunc::IsPure() const
 
 ValPtr BuiltinFunc::Invoke(Args* args, Frame* parent) const
 	{
-#ifdef PROFILE_BRO_FUNCTIONS
-	DEBUG_MSG("Function: %s\n", Name());
-#endif
+	if ( spm )
+		spm->StartInvocation(this);
+
 	SegmentProfiler prof(segment_logger, Name());
 
 	if ( sample_logger )
@@ -776,7 +687,11 @@ ValPtr BuiltinFunc::Invoke(Args* args, Frame* parent) const
 	CheckPluginResult(handled, hook_result, FUNC_FLAVOR_FUNCTION);
 
 	if ( handled )
+		{
+		if ( spm )
+			spm->EndInvocation();
 		return hook_result;
+		}
 
 	if ( g_trace_state.DoTrace() )
 		{
@@ -799,6 +714,9 @@ ValPtr BuiltinFunc::Invoke(Args* args, Frame* parent) const
 		g_trace_state.LogTrace("\tFunction return: %s\n", d.Description());
 		}
 
+	if ( spm )
+		spm->EndInvocation();
+
 	return result;
 	}
 
@@ -870,7 +788,7 @@ static int get_func_priority(const std::vector<AttrPtr>& attrs)
 
 	for ( const auto& a : attrs )
 		{
-		if ( a->Tag() == ATTR_DEPRECATED )
+		if ( a->Tag() == ATTR_DEPRECATED || a->Tag() == ATTR_IS_USED )
 			continue;
 
 		if ( a->Tag() != ATTR_PRIORITY )
@@ -909,7 +827,23 @@ function_ingredients::function_ingredients(ScopePtr scope, StmtPtr body)
 
 	const auto& attrs = this->scope->Attrs();
 
-	priority = (attrs ? get_func_priority(*attrs) : 0);
+	if ( attrs )
+		{
+		priority = get_func_priority(*attrs);
+
+		for ( const auto& a : *attrs )
+			if ( a->Tag() == ATTR_IS_USED )
+				{
+				// Associate this with the identifier, too.
+				std::vector<AttrPtr> used_attr;
+				used_attr.emplace_back(make_intrusive<Attr>(ATTR_IS_USED));
+				id->AddAttrs(make_intrusive<Attributes>(used_attr, nullptr, false, true));
+				break;
+				}
+		}
+	else
+		priority = 0;
+
 	this->body = std::move(body);
 	}
 
