@@ -54,8 +54,6 @@ private:
 	          TransportProto t, bool one_way);
 	};
 
-using ConnIDKey [[deprecated("Remove in v5.1. Use zeek::detail::ConnKey.")]] = ConnKey;
-
 	} // namespace detail
 
 /**
@@ -382,13 +380,6 @@ public:
 	 */
 	void ConvertToThreadingValue(threading::Value::addr_t* v) const;
 
-	[[deprecated("Remove in v5.1. MemoryAllocation() is deprecated and will be removed. See "
-	             "GHI-572.")]] unsigned int
-	MemoryAllocation() const
-		{
-		return padded_sizeof(*this);
-		}
-
 	/**
 	 * Check if an IP prefix length would be valid against this IP address.
 	 *
@@ -636,13 +627,6 @@ public:
 		prefix.ConvertToThreadingValue(&v->prefix);
 		}
 
-	[[deprecated("Remove in v5.1. MemoryAllocation() is deprecated and will be removed. See "
-	             "GHI-572.")]] unsigned int
-	MemoryAllocation() const
-		{
-		return padded_sizeof(*this);
-		}
-
 	/**
 	 * Comparison operator for IP prefix.
 	 */
