@@ -1,12 +1,11 @@
-#include "zeek/zeek-config.h"
 #include "zeek/IntSet.h"
 
-#ifdef HAVE_MEMORY_H
-#include <memory.h>
-#endif
-#include <stdlib.h>
+#include "zeek/zeek-config.h"
 
-namespace zeek::detail {
+#include <cstring>
+
+namespace zeek::detail
+	{
 
 void IntSet::Expand(unsigned int i)
 	{
@@ -16,9 +15,9 @@ void IntSet::Expand(unsigned int i)
 	memset(newset, 0, newsize);
 	memcpy(newset, set, size);
 
-	delete [] set;
+	delete[] set;
 	size = newsize;
 	set = newset;
 	}
 
-} // namespace zeek::detail
+	} // namespace zeek::detail
