@@ -1,7 +1,7 @@
 #pragma once
 
-#include <stdint.h> // for u_char
 #include <sys/types.h> // for u_char
+#include <cstdint> // for u_char
 
 #include "zeek/util.h"
 
@@ -122,7 +122,7 @@ private:
 	Comp comp;
 	};
 
-// Implements "eval" which evaluates the given Bro identifier.
+// Implements "eval" which evaluates the given Zeek identifier.
 class RuleConditionEval : public RuleCondition
 	{
 public:
