@@ -7,18 +7,18 @@
 #include <sys/types.h>
 #ifdef TIME_WITH_SYS_TIME
 #include <sys/time.h>
-#include <time.h>
+#include <ctime>
 #else
 #ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
 #else
-#include <time.h>
+#include <ctime>
 #endif
 #endif
 
-#include <signal.h>
-#include <stdlib.h>
 #include <unistd.h>
+#include <csignal>
+#include <cstdlib>
 
 extern "C"
 	{
@@ -227,10 +227,7 @@ void dispatch_packet(Packet* pkt, iosource::PktSrc* pkt_src)
 		}
 
 	current_iosrc = pkt_src;
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 	current_pktsrc = pkt_src;
-#pragma GCC diagnostic pop
 
 	// network_time never goes back.
 	update_network_time(zeek::detail::timer_mgr->Time() < t ? t : zeek::detail::timer_mgr->Time());
@@ -273,10 +270,7 @@ void dispatch_packet(Packet* pkt, iosource::PktSrc* pkt_src)
 		first_wallclock = util::current_time(true);
 
 	current_iosrc = nullptr;
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 	current_pktsrc = nullptr;
-#pragma GCC diagnostic pop
 	}
 
 void run_loop()
@@ -504,13 +498,12 @@ void continue_processing()
 		detail::current_wallclock = util::current_time(true);
 		}
 
-	if ( _processing_suspended > 0 )
-		--_processing_suspended;
+	--_processing_suspended;
 	}
 
 bool is_processing_suspended()
 	{
-	return _processing_suspended > 0;
+	return _processing_suspended;
 	}
 
 	} // namespace zeek::run_state
