@@ -158,6 +158,12 @@ const ReturnStmt* Stmt::AsReturnStmt() const
 	return (const ReturnStmt*)this;
 	}
 
+const NullStmt* Stmt::AsNullStmt() const
+	{
+	CHECK_TAG(tag, STMT_NULL, "Stmt::AsNullStmt", stmt_name)
+	return (const NullStmt*)this;
+	}
+
 bool Stmt::SetLocationInfo(const Location* start, const Location* end)
 	{
 	if ( ! Obj::SetLocationInfo(start, end) )
@@ -883,7 +889,7 @@ bool SwitchStmt::AddCaseLabelValueMapping(const Val* v, int idx)
 
 bool SwitchStmt::AddCaseLabelTypeMapping(ID* t, int idx)
 	{
-	for ( auto i : case_label_type_list )
+	for ( const auto& i : case_label_type_list )
 		{
 		if ( same_type(i.first->GetType(), t->GetType()) )
 			return false;
@@ -918,7 +924,7 @@ std::pair<int, ID*> SwitchStmt::FindCaseLabelMatch(const Val* v) const
 		}
 
 	// Find matching type cases.
-	for ( auto i : case_label_type_list )
+	for ( const auto& i : case_label_type_list )
 		{
 		auto id = i.first;
 		const auto& type = id->GetType();
@@ -1290,23 +1296,29 @@ ForStmt::ForStmt(IDPList* arg_loop_vars, ExprPtr loop_expr, IDPtr val_var)
 	{
 	value_var = std::move(val_var);
 
-	if ( e->GetType()->IsTable() )
-		{
-		const auto& yield_type = e->GetType()->AsTableType()->Yield();
+	auto t = e->GetType();
+	zeek::TypePtr yield_type;
 
-		// Verify value_vars type if its already been defined
-		if ( value_var->GetType() )
-			{
-			if ( ! same_type(value_var->GetType(), yield_type) )
-				value_var->GetType()->Error("type clash in iteration", yield_type.get());
-			}
-		else
-			{
-			add_local(value_var, yield_type, INIT_NONE, nullptr, nullptr, VAR_REGULAR);
-			}
+	if ( t->IsTable() )
+		yield_type = t->AsTableType()->Yield();
+
+	else if ( t->Tag() == TYPE_VECTOR )
+		yield_type = t->AsVectorType()->Yield();
+
+	else
+		{
+		e->Error("key value for loops only support iteration over tables or vectors");
+		return;
+		}
+
+	// Verify value_vars type if it's already been defined
+	if ( value_var->GetType() )
+		{
+		if ( ! same_type(value_var->GetType(), yield_type) )
+			value_var->GetType()->Error("type clash in iteration", yield_type.get());
 		}
 	else
-		e->Error("key value for loops only support iteration over tables");
+		add_local(value_var, yield_type, INIT_NONE, nullptr, nullptr, VAR_REGULAR);
 	}
 
 ForStmt::~ForStmt()
@@ -1331,7 +1343,7 @@ ValPtr ForStmt::DoExec(Frame* f, Val* v, StmtFlowType& flow)
 		for ( const auto& lve : *loop_vals )
 			{
 			auto k = lve.GetHashKey();
-			auto* current_tev = lve.GetValue<TableEntryVal*>();
+			auto* current_tev = lve.value;
 			auto ind_lv = tv->RecreateIndex(*k);
 
 			if ( value_var )
@@ -1358,8 +1370,11 @@ ValPtr ForStmt::DoExec(Frame* f, Val* v, StmtFlowType& flow)
 			if ( ! raw_vv[i] )
 				continue;
 
-			// Set the loop variable to the current index, and make
-			// another pass over the loop body.
+			// Set the loop variable to the current index, the value variable
+			// to the current value, and make another pass over the loop body.
+			if ( value_var )
+				f->SetElement(value_var, vv->ValAt(i));
+
 			f->SetElement((*loop_vars)[0], val_mgr->Count(i));
 			flow = FLOW_NEXT;
 			ret = body->Exec(f, flow);
@@ -1776,6 +1791,8 @@ TraversalCode InitStmt::Traverse(TraversalCallback* cb) const
 	HANDLE_TC_STMT_POST(tc);
 	}
 
+NullStmt::NullStmt(bool arg_is_directive) : Stmt(STMT_NULL), is_directive(arg_is_directive) { }
+
 ValPtr NullStmt::Exec(Frame* /* f */, StmtFlowType& flow)
 	{
 	RegisterAccess();
@@ -1876,7 +1893,7 @@ void WhenInfo::Build(StmtPtr ws)
 	{
 	if ( IsDeprecatedSemantics(ws) )
 		{
-		merge_top_scope();
+		pop_scope();
 		return;
 		}
 
@@ -2185,6 +2202,12 @@ TraversalCode WhenStmt::Traverse(TraversalCallback* cb) const
 			}
 		}
 
+	if ( wi->TimeoutExpr() )
+		{
+		tc = wi->TimeoutExpr()->Traverse(cb);
+		HANDLE_TC_STMT_PRE(tc);
+		}
+
 	tc = cb->PostStmt(this);
 	HANDLE_TC_STMT_POST(tc);
 	}
