@@ -1,7 +1,7 @@
 #include "zeek/Trigger.h"
 
-#include <assert.h>
 #include <algorithm>
+#include <cassert>
 
 #include "zeek/DebugLogger.h"
 #include "zeek/Desc.h"
@@ -504,6 +504,7 @@ void Trigger::Modified(notifier::detail::Modifiable* m)
 Manager::Manager() : iosource::IOSource()
 	{
 	pending = new TriggerList();
+	iosource_mgr->Register(this, true);
 	}
 
 Manager::~Manager()
@@ -511,11 +512,6 @@ Manager::~Manager()
 	delete pending;
 	}
 
-void Manager::InitPostScript()
-	{
-	iosource_mgr->Register(this, true);
-	}
-
 double Manager::GetNextTimeout()
 	{
 	return pending->empty() ? -1 : run_state::network_time + 0.100;
