@@ -13,6 +13,7 @@
 #include "zeek/ID.h"
 #include "zeek/IntrusivePtr.h"
 #include "zeek/Obj.h"
+#include "zeek/Traverse.h"
 #include "zeek/ZeekList.h"
 
 namespace zeek
@@ -49,21 +50,19 @@ enum TypeTag
 	TYPE_STRING, // 7
 	TYPE_PATTERN, // 8
 	TYPE_ENUM, // 9
-	TYPE_TIMER, // 10
-	TYPE_PORT, // 11
-	TYPE_ADDR, // 12
-	TYPE_SUBNET, // 13
-	TYPE_ANY, // 14
-	TYPE_TABLE, // 15
-	TYPE_UNION, // 16
-	TYPE_RECORD, // 17
-	TYPE_LIST, // 18
-	TYPE_FUNC, // 19
-	TYPE_FILE, // 20
-	TYPE_VECTOR, // 21
-	TYPE_OPAQUE, // 22
-	TYPE_TYPE, // 23
-	TYPE_ERROR // 24
+	TYPE_PORT, // 10
+	TYPE_ADDR, // 11
+	TYPE_SUBNET, // 12
+	TYPE_ANY, // 13
+	TYPE_TABLE, // 14
+	TYPE_RECORD, // 15
+	TYPE_LIST, // 16
+	TYPE_FUNC, // 17
+	TYPE_FILE, // 18
+	TYPE_VECTOR, // 19
+	TYPE_OPAQUE, // 20
+	TYPE_TYPE, // 21
+	TYPE_ERROR // 22
 #define NUM_TYPES (int(TYPE_ERROR) + 1)
 	};
 
@@ -126,10 +125,8 @@ constexpr InternalTypeTag to_internal_type_tag(TypeTag tag) noexcept
 			return TYPE_INTERNAL_SUBNET;
 
 		case TYPE_PATTERN:
-		case TYPE_TIMER:
 		case TYPE_ANY:
 		case TYPE_TABLE:
-		case TYPE_UNION:
 		case TYPE_RECORD:
 		case TYPE_LIST:
 		case TYPE_FUNC:
@@ -255,13 +252,11 @@ public:
 	void Describe(ODesc* d) const override;
 	virtual void DescribeReST(ODesc* d, bool roles_only = false) const;
 
-	[[deprecated("Remove in v5.1. MemoryAllocation() is deprecated and will be removed. See "
-	             "GHI-572.")]] virtual unsigned
-	MemoryAllocation() const;
-
 	void SetName(const std::string& arg_name) { name = arg_name; }
 	const std::string& GetName() const { return name; }
 
+	virtual detail::TraversalCode Traverse(detail::TraversalCallback* cb) const;
+
 	struct TypePtrComparer
 		{
 		bool operator()(const TypePtr& a, const TypePtr& b) const { return a.get() < b.get(); }
@@ -310,6 +305,8 @@ public:
 		}
 
 protected:
+	virtual void DoDescribe(ODesc* d) const;
+
 	Type() = default;
 
 	void SetError();
@@ -351,13 +348,11 @@ public:
 	void Append(TypePtr t);
 	void AppendEvenIfNotPure(TypePtr t);
 
-	void Describe(ODesc* d) const override;
-
-	[[deprecated("Remove in v5.1. MemoryAllocation() is deprecated and will be removed. See "
-	             "GHI-572.")]] unsigned int
-	MemoryAllocation() const override;
+	detail::TraversalCode Traverse(detail::TraversalCallback* cb) const override;
 
 protected:
+	void DoDescribe(ODesc* d) const override;
+
 	TypePtr pure_type;
 	std::vector<TypePtr> types;
 	};
@@ -373,12 +368,13 @@ public:
 
 	const TypePtr& Yield() const override { return yield_type; }
 
-	void Describe(ODesc* d) const override;
 	void DescribeReST(ODesc* d, bool roles_only = false) const override;
 
 	// Returns true if this table is solely indexed by subnet.
 	bool IsSubNetIndex() const;
 
+	detail::TraversalCode Traverse(detail::TraversalCallback* cb) const override;
+
 protected:
 	IndexType(TypeTag t, TypeListPtr arg_indices, TypePtr arg_yield_type)
 		: Type(t), indices(std::move(arg_indices)), yield_type(std::move(arg_yield_type))
@@ -387,6 +383,8 @@ protected:
 
 	~IndexType() override = default;
 
+	void DoDescribe(ODesc* d) const override;
+
 	TypeListPtr indices;
 	TypePtr yield_type;
 	};
@@ -410,6 +408,12 @@ public:
 	// Returns true if this table type is "unspecified", which is
 	// what one gets using an empty "set()" or "table()" constructor.
 	bool IsUnspecifiedTable() const;
+
+private:
+	bool DoExpireCheck(const detail::AttrPtr& attr);
+
+	// Used to prevent repeated error messages.
+	bool reported_error = false;
 	};
 
 class SetType final : public TableType
@@ -472,7 +476,6 @@ public:
 
 	const TypeListPtr& ParamList() const { return arg_types; }
 
-	void Describe(ODesc* d) const override;
 	void DescribeReST(ODesc* d, bool roles_only = false) const override;
 
 	/**
@@ -515,10 +518,29 @@ public:
 	 */
 	const std::optional<CaptureList>& GetCaptures() const { return captures; }
 
+	/**
+	 * Returns whether it's acceptable for a "return" inside the function
+	 * to not have an expression (even though the function has a return
+	 * type).  Used internally for lambdas built for "when" statements.
+	 */
+	bool ExpressionlessReturnOkay() const { return expressionless_return_okay; }
+
+	/**
+	 * Sets whether it's acceptable for a "return" inside the function
+	 * to not have an expression (even though the function has a return
+	 * type).  Used internally for lambdas built for "when" statements.
+	 */
+	void SetExpressionlessReturnOkay(bool is_ok) { expressionless_return_okay = is_ok; }
+
+	detail::TraversalCode Traverse(detail::TraversalCallback* cb) const override;
+
 protected:
 	friend FuncTypePtr make_intrusive<FuncType>();
 
 	FuncType() : Type(TYPE_FUNC) { flavor = FUNC_FLAVOR_FUNCTION; }
+
+	void DoDescribe(ODesc* d) const override;
+
 	RecordTypePtr args;
 	TypeListPtr arg_types;
 	TypePtr yield;
@@ -526,6 +548,11 @@ protected:
 	std::vector<Prototype> prototypes;
 
 	std::optional<CaptureList> captures; // if nil then no captures specified
+	// Used for internal lambdas built for "when" statements:
+	bool expressionless_return_okay = false;
+
+	// Used to prevent repeated error messages.
+	bool reported_error = false;
 	};
 
 class TypeType final : public Type
@@ -538,6 +565,8 @@ public:
 
 	template <class T> IntrusivePtr<T> GetType() const { return cast_intrusive<T>(type); }
 
+	detail::TraversalCode Traverse(detail::TraversalCallback* cb) const override;
+
 protected:
 	TypePtr type;
 	};
@@ -654,7 +683,6 @@ public:
 	 */
 	void Create(std::vector<std::optional<ZVal>>& r) const;
 
-	void Describe(ODesc* d) const override;
 	void DescribeReST(ODesc* d, bool roles_only = false) const override;
 	void DescribeFields(ODesc* d) const;
 	void DescribeFieldsReST(ODesc* d, bool func_args) const;
@@ -673,11 +701,15 @@ public:
 
 	std::string GetFieldDeprecationWarning(int field, bool has_check) const;
 
+	detail::TraversalCode Traverse(detail::TraversalCallback* cb) const override;
+
 protected:
 	RecordType() { types = nullptr; }
 
 	void AddField(unsigned int field, const TypeDecl* td);
 
+	void DoDescribe(ODesc* d) const override;
+
 	// Maps each field to how to initialize it.  Uses pointers due to
 	// keeping the FieldInit definition private to Type.cc (see above).
 	std::vector<FieldInit*> field_inits;
@@ -693,6 +725,7 @@ protected:
 	int num_orig_fields;
 
 	type_decl_list* types;
+	std::set<std::string> field_ids;
 	};
 
 class FileType final : public Type
@@ -704,9 +737,11 @@ public:
 
 	const TypePtr& Yield() const override { return yield; }
 
-	void Describe(ODesc* d) const override;
+	detail::TraversalCode Traverse(detail::TraversalCallback* cb) const override;
 
 protected:
+	void DoDescribe(ODesc* d) const override;
+
 	TypePtr yield;
 	};
 
@@ -719,19 +754,20 @@ public:
 
 	const std::string& Name() const { return name; }
 
-	void Describe(ODesc* d) const override;
 	void DescribeReST(ODesc* d, bool roles_only = false) const override;
 
 protected:
 	OpaqueType() { }
 
+	void DoDescribe(ODesc* d) const override;
+
 	std::string name;
 	};
 
 class EnumType final : public Type
 	{
 public:
-	using enum_name_list = std::list<std::pair<std::string, bro_int_t>>;
+	using enum_name_list = std::list<std::pair<std::string, zeek_int_t>>;
 
 	explicit EnumType(const EnumType* e);
 	explicit EnumType(const std::string& arg_name);
@@ -746,15 +782,15 @@ public:
 	// The value of this name is set to val. Once a value has been
 	// explicitly assigned using this method, no further names can be
 	// added that aren't likewise explicitly initalized.
-	void AddName(const std::string& module_name, const char* name, bro_int_t val, bool is_export,
+	void AddName(const std::string& module_name, const char* name, zeek_int_t val, bool is_export,
 	             detail::Expr* deprecation = nullptr, bool from_redef = false);
 
 	// -1 indicates not found.  Second version is for full names
 	// that already incorporate the module.
-	bro_int_t Lookup(const std::string& module_name, const char* name) const;
-	bro_int_t Lookup(const std::string& full_name) const;
+	zeek_int_t Lookup(const std::string& module_name, const char* name) const;
+	zeek_int_t Lookup(const std::string& full_name) const;
 
-	const char* Lookup(bro_int_t value) const; // Returns 0 if not found
+	const char* Lookup(zeek_int_t value) const; // Returns 0 if not found
 
 	// Returns the list of defined names with their values. The names
 	// will be fully qualified with their module name.
@@ -762,31 +798,32 @@ public:
 
 	bool HasRedefs() const { return has_redefs; }
 
-	void Describe(ODesc* d) const override;
 	void DescribeReST(ODesc* d, bool roles_only = false) const override;
 
-	const EnumValPtr& GetEnumVal(bro_int_t i);
+	const EnumValPtr& GetEnumVal(zeek_int_t i);
 
 	// Only for use by C++-generated code.  Non-protected because we
 	// don't know in advance the names of the functions that will
 	// access it.
-	void AddNameInternal(const std::string& full_name, bro_int_t val);
+	void AddNameInternal(const std::string& full_name, zeek_int_t val);
 
 protected:
-	void AddNameInternal(const std::string& module_name, const char* name, bro_int_t val,
+	void AddNameInternal(const std::string& module_name, const char* name, zeek_int_t val,
 	                     bool is_export);
 
-	void CheckAndAddName(const std::string& module_name, const char* name, bro_int_t val,
+	void CheckAndAddName(const std::string& module_name, const char* name, zeek_int_t val,
 	                     bool is_export, detail::Expr* deprecation = nullptr,
 	                     bool from_redef = false);
 
-	using NameMap = std::map<std::string, bro_int_t>;
+	void DoDescribe(ODesc* d) const override;
+
+	using NameMap = std::map<std::string, zeek_int_t>;
 	NameMap names;
 
 	// Whether any of the elements of the enum were added via redef's.
 	bool has_redefs = false;
 
-	using ValMap = std::unordered_map<bro_int_t, EnumValPtr>;
+	using ValMap = std::unordered_map<zeek_int_t, EnumValPtr>;
 	ValMap vals;
 
 	// The counter is initialized to 0 and incremented on every implicit
@@ -795,7 +832,7 @@ protected:
 	// specified, the counter is set to -1. This way counter can be used
 	// as a flag to prevent mixing of auto-increment and explicit
 	// enumerator specifications.
-	bro_int_t counter;
+	zeek_int_t counter;
 	};
 
 class VectorType final : public Type
@@ -813,10 +850,13 @@ public:
 	// gets using an empty "vector()" constructor.
 	bool IsUnspecifiedVector() const;
 
-	void Describe(ODesc* d) const override;
 	void DescribeReST(ODesc* d, bool roles_only = false) const override;
 
+	detail::TraversalCode Traverse(detail::TraversalCallback* cb) const override;
+
 protected:
+	void DoDescribe(ODesc* d) const override;
+
 	TypePtr yield_type;
 	};
 
@@ -888,7 +928,7 @@ TypePtr merge_types(const TypePtr& t1, const TypePtr& t2);
 TypePtr merge_type_list(detail::ListExpr* elements);
 
 // Given an expression, infer its type when used for an initialization.
-TypePtr init_type(detail::Expr* init);
+TypePtr init_type(const detail::ExprPtr& init);
 
 // Returns true if argument is an atomic type.
 bool is_atomic_type(const Type& t);
@@ -935,7 +975,7 @@ inline bool IsInterval(TypeTag t)
 // True if the given type tag corresponds to a record type.
 inline bool IsRecord(TypeTag t)
 	{
-	return (t == TYPE_RECORD || t == TYPE_UNION);
+	return (t == TYPE_RECORD);
 	}
 
 // True if the given type tag corresponds to a function type.
