@@ -6,12 +6,12 @@
 
 #include <netdb.h>
 #include <netinet/in.h>
-#include <stdio.h>
-#include <stdlib.h>
 #include <sys/param.h>
 #include <sys/types.h>
 #include <unistd.h>
 #include <cmath>
+#include <cstdio>
+#include <cstdlib>
 #include <set>
 
 #include "zeek/Attr.h"
@@ -160,20 +160,20 @@ bool Val::IsOne() const
 		}
 	}
 
-bro_int_t Val::InternalInt() const
+zeek_int_t Val::InternalInt() const
 	{
 	if ( type->InternalType() == TYPE_INTERNAL_INT )
 		return AsInt();
 	else if ( type->InternalType() == TYPE_INTERNAL_UNSIGNED )
 		// ### should check here for overflow
-		return static_cast<bro_int_t>(AsCount());
+		return static_cast<zeek_int_t>(AsCount());
 	else
 		InternalWarning("bad request for InternalInt");
 
 	return 0;
 	}
 
-bro_uint_t Val::InternalUnsigned() const
+zeek_uint_t Val::InternalUnsigned() const
 	{
 	if ( type->InternalType() == TYPE_INTERNAL_UNSIGNED )
 		return AsCount();
@@ -193,28 +193,28 @@ double Val::InternalDouble() const
 	return 0.0;
 	}
 
-bro_int_t Val::CoerceToInt() const
+zeek_int_t Val::CoerceToInt() const
 	{
 	if ( type->InternalType() == TYPE_INTERNAL_INT )
 		return AsInt();
 	else if ( type->InternalType() == TYPE_INTERNAL_UNSIGNED )
-		return static_cast<bro_int_t>(AsCount());
+		return static_cast<zeek_int_t>(AsCount());
 	else if ( type->InternalType() == TYPE_INTERNAL_DOUBLE )
-		return static_cast<bro_int_t>(AsDouble());
+		return static_cast<zeek_int_t>(AsDouble());
 	else
 		InternalWarning("bad request for CoerceToInt");
 
 	return 0;
 	}
 
-bro_uint_t Val::CoerceToUnsigned() const
+zeek_uint_t Val::CoerceToUnsigned() const
 	{
 	if ( type->InternalType() == TYPE_INTERNAL_UNSIGNED )
 		return AsCount();
 	else if ( type->InternalType() == TYPE_INTERNAL_INT )
-		return static_cast<bro_uint_t>(AsInt());
+		return static_cast<zeek_uint_t>(AsInt());
 	else if ( type->InternalType() == TYPE_INTERNAL_DOUBLE )
-		return static_cast<bro_uint_t>(AsDouble());
+		return static_cast<zeek_uint_t>(AsDouble());
 	else
 		InternalWarning("bad request for CoerceToUnsigned");
 
@@ -258,11 +258,6 @@ ValPtr Val::SizeVal() const
 	return val_mgr->Count(0);
 	}
 
-unsigned int Val::MemoryAllocation() const
-	{
-	return padded_sizeof(*this);
-	}
-
 bool Val::AddTo(Val* v, bool is_first_init) const
 	{
 	Error("+= initializer only applies to aggregate values");
@@ -277,7 +272,7 @@ bool Val::RemoveFrom(Val* v) const
 
 void Val::Describe(ODesc* d) const
 	{
-	if ( d->IsBinary() || d->IsPortable() )
+	if ( d->IsBinary() )
 		{
 		type->Describe(d);
 		d->SP();
@@ -498,13 +493,10 @@ static void BuildJSON(threading::formatter::JSON::NullDoubleWriter& writer, Val*
 			else
 				writer.StartObject();
 
-			std::unique_ptr<detail::HashKey> k;
-			TableEntryVal* entry;
-
 			for ( const auto& te : *table )
 				{
-				entry = te.GetValue<TableEntryVal*>();
-				k = te.GetHashKey();
+				auto* entry = te.value;
+				auto k = te.GetHashKey();
 
 				auto lv = tval->RecreateIndex(*k);
 				Val* entry_key = lv->Length() == 1 ? lv->Idx(0).get() : lv.get();
@@ -730,7 +722,7 @@ uint32_t PortVal::Mask(uint32_t port_num, TransportProto port_type)
 	return port_num;
 	}
 
-PortVal::PortVal(uint32_t p) : UnsignedValImplementation(base_type(TYPE_PORT), bro_uint_t(p)) { }
+PortVal::PortVal(uint32_t p) : UnsignedValImplementation(base_type(TYPE_PORT), zeek_uint_t(p)) { }
 
 uint32_t PortVal::Port() const
 	{
@@ -807,14 +799,6 @@ AddrVal::~AddrVal()
 	delete addr_val;
 	}
 
-unsigned int AddrVal::MemoryAllocation() const
-	{
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-	return padded_sizeof(*this) + addr_val->MemoryAllocation();
-#pragma GCC diagnostic pop
-	}
-
 ValPtr AddrVal::SizeVal() const
 	{
 	if ( addr_val->GetFamily() == IPv4 )
@@ -877,14 +861,6 @@ int SubNetVal::Width() const
 	return subnet_val->Length();
 	}
 
-unsigned int SubNetVal::MemoryAllocation() const
-	{
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-	return padded_sizeof(*this) + subnet_val->MemoryAllocation();
-#pragma GCC diagnostic pop
-	}
-
 ValPtr SubNetVal::SizeVal() const
 	{
 	int retained = 128 - subnet_val->LengthIPv6();
@@ -1002,14 +978,6 @@ void StringVal::ValDescribe(ODesc* d) const
 		d->Add("\"");
 	}
 
-unsigned int StringVal::MemoryAllocation() const
-	{
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-	return padded_sizeof(*this) + string_val->MemoryAllocation();
-#pragma GCC diagnostic pop
-	}
-
 StringValPtr StringVal::Replace(RE_Matcher* re, const String& repl, bool do_all)
 	{
 	const u_char* s = Bytes();
@@ -1210,14 +1178,6 @@ void PatternVal::ValDescribe(ODesc* d) const
 	d->Add("/");
 	}
 
-unsigned int PatternVal::MemoryAllocation() const
-	{
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-	return padded_sizeof(*this) + re_val->MemoryAllocation();
-#pragma GCC diagnostic pop
-	}
-
 ValPtr PatternVal::DoClone(CloneState* state)
 	{
 	// We could likely treat this type as immutable and return a reference
@@ -1287,7 +1247,7 @@ TableValPtr ListVal::ToSetVal() const
 
 void ListVal::Describe(ODesc* d) const
 	{
-	if ( d->IsBinary() || d->IsPortable() )
+	if ( d->IsBinary() )
 		{
 		type->Describe(d);
 		d->SP();
@@ -1299,7 +1259,7 @@ void ListVal::Describe(ODesc* d) const
 		{
 		if ( i > 0u )
 			{
-			if ( d->IsReadable() || d->IsPortable() )
+			if ( d->IsReadable() )
 				{
 				d->Add(",");
 				d->SP();
@@ -1332,19 +1292,6 @@ unsigned int ListVal::ComputeFootprint(std::unordered_set<const Val*>* analyzed_
 	return fp;
 	}
 
-unsigned int ListVal::MemoryAllocation() const
-	{
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-	unsigned int size = 0;
-	for ( const auto& val : vals )
-		size += val->MemoryAllocation();
-
-	size += util::pad_size(vals.capacity() * sizeof(decltype(vals)::value_type));
-	return size + padded_sizeof(*this) + type->MemoryAllocation();
-#pragma GCC diagnostic pop
-	}
-
 TableEntryVal* TableEntryVal::Clone(Val::CloneState* state)
 	{
 	auto rval = new TableEntryVal(val ? val->Clone(state) : nullptr);
@@ -1515,7 +1462,7 @@ int TableVal::RecursiveSize() const
 
 	for ( const auto& ve : *table_val )
 		{
-		auto* tv = ve.GetValue<TableEntryVal*>();
+		auto* tv = ve.value;
 		if ( tv->GetVal() )
 			n += tv->GetVal()->AsTableVal()->RecursiveSize();
 		}
@@ -1684,7 +1631,7 @@ bool TableVal::AddTo(Val* val, bool is_first_init, bool propagate_ops) const
 	for ( const auto& tble : *table_val )
 		{
 		auto k = tble.GetHashKey();
-		auto* v = tble.GetValue<TableEntryVal*>();
+		auto* v = tble.value;
 
 		if ( is_first_init && t->AsTable()->Lookup(k.get()) )
 			{
@@ -2305,7 +2252,7 @@ std::unordered_map<ValPtr, ValPtr> TableVal::ToMap() const
 	for ( const auto& iter : *table_val )
 		{
 		auto k = iter.GetHashKey();
-		auto v = iter.GetValue<TableEntryVal*>();
+		auto v = iter.value;
 		auto vl = table_hash->RecoverVals(*k);
 
 		res[std::move(vl)] = v->GetVal();
@@ -2323,7 +2270,7 @@ void TableVal::Describe(ODesc* d) const
 	{
 	int n = table_val->Length();
 
-	if ( d->IsBinary() || d->IsPortable() )
+	if ( d->IsBinary() )
 		{
 		table_type->Describe(d);
 		d->SP();
@@ -2331,7 +2278,7 @@ void TableVal::Describe(ODesc* d) const
 		d->SP();
 		}
 
-	if ( d->IsPortable() || d->IsReadable() )
+	if ( d->IsReadable() )
 		{
 		d->Add("{");
 		d->PushIndent();
@@ -2348,7 +2295,7 @@ void TableVal::Describe(ODesc* d) const
 			reporter->InternalError("hash table underflow in TableVal::Describe");
 
 		auto k = iter->GetHashKey();
-		auto* v = iter->GetValue<TableEntryVal*>();
+		auto* v = iter->value;
 
 		auto vl = table_hash->RecoverVals(*k);
 		int dim = vl->Length();
@@ -2429,7 +2376,7 @@ void TableVal::Describe(ODesc* d) const
 			}
 		}
 
-	if ( d->IsPortable() || d->IsReadable() )
+	if ( d->IsReadable() )
 		{
 		d->PopIndent();
 		d->Add("}");
@@ -2495,13 +2442,13 @@ void TableVal::DoExpire(double t)
 	      i < zeek::detail::table_incremental_step && *expire_iterator != table_val->end_robust();
 	      ++i, ++(*expire_iterator) )
 		{
-		auto v = (*expire_iterator)->GetValue<TableEntryVal*>();
+		auto v = (*expire_iterator)->value;
 
 		if ( v->ExpireAccessTime() == 0 )
 			{
 			// This happens when we insert val while network_time
 			// hasn't been initialized yet (e.g. in zeek_init()), and
-			// also when bro_start_network_time hasn't been initialized
+			// also when zeek_start_network_time hasn't been initialized
 			// (e.g. before first packet).  The expire_access_time is
 			// correct, so we just need to wait.
 			}
@@ -2674,7 +2621,7 @@ ValPtr TableVal::DoClone(CloneState* state)
 	for ( const auto& tble : *table_val )
 		{
 		auto key = tble.GetHashKey();
-		auto* val = tble.GetValue<TableEntryVal*>();
+		auto* val = tble.value;
 		TableEntryVal* nval = val->Clone(state);
 		tv->table_val->Insert(key.get(), nval);
 
@@ -2714,7 +2661,7 @@ unsigned int TableVal::ComputeFootprint(std::unordered_set<const Val*>* analyzed
 		{
 		auto k = iter.GetHashKey();
 		auto vl = table_hash->RecoverVals(*k);
-		auto v = iter.GetValue<TableEntryVal*>()->GetVal();
+		auto v = iter.value->GetVal();
 
 		fp += vl->Footprint(analyzed_vals);
 		if ( v )
@@ -2724,25 +2671,6 @@ unsigned int TableVal::ComputeFootprint(std::unordered_set<const Val*>* analyzed
 	return fp;
 	}
 
-unsigned int TableVal::MemoryAllocation() const
-	{
-	unsigned int size = 0;
-
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-	for ( const auto& ve : *table_val )
-		{
-		auto* tv = ve.GetValue<TableEntryVal*>();
-		if ( tv->GetVal() )
-			size += tv->GetVal()->MemoryAllocation();
-		size += padded_sizeof(TableEntryVal);
-		}
-
-	return size + padded_sizeof(*this) + table_val->MemoryAllocation() +
-	       table_hash->MemoryAllocation();
-#pragma GCC diagnostic pop
-	}
-
 std::unique_ptr<detail::HashKey> TableVal::MakeHashKey(const Val& index) const
 	{
 	return table_hash->MakeHashKey(index, true);
@@ -2780,7 +2708,7 @@ TableVal::ParseTimeTableState TableVal::DumpTableState()
 	for ( const auto& tble : *table_val )
 		{
 		auto key = tble.GetHashKey();
-		auto* val = tble.GetValue<TableEntryVal*>();
+		auto* val = tble.value;
 
 		rval.emplace_back(RecreateIndex(*key), val->GetVal());
 		}
@@ -3007,7 +2935,7 @@ void RecordVal::Describe(ODesc* d) const
 	{
 	auto n = record_val->size();
 
-	if ( d->IsBinary() || d->IsPortable() )
+	if ( d->IsBinary() )
 		{
 		rt->Describe(d);
 		d->SP();
@@ -3107,27 +3035,6 @@ unsigned int RecordVal::ComputeFootprint(std::unordered_set<const Val*>* analyze
 	return fp;
 	}
 
-unsigned int RecordVal::MemoryAllocation() const
-	{
-	unsigned int size = 0;
-
-	int n = NumFields();
-	for ( auto i = 0; i < n; ++i )
-		{
-		auto f_i = GetField(i);
-		if ( f_i )
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-			size += f_i->MemoryAllocation();
-#pragma GCC diagnostic pop
-		}
-
-	size += util::pad_size(record_val->capacity() * sizeof(ZVal));
-	size += padded_sizeof(*record_val);
-
-	return size + padded_sizeof(*this);
-	}
-
 ValPtr EnumVal::SizeVal() const
 	{
 	return val_mgr->Int(AsInt());
@@ -3719,26 +3626,14 @@ void VectorVal::ValDescribe(ODesc* d) const
 	d->Add("]");
 	}
 
-ValPtr check_and_promote(ValPtr v, const TypePtr& t, bool is_init,
+ValPtr check_and_promote(ValPtr v, const TypePtr& new_type, bool is_init,
                          const detail::Location* expr_location)
-	{
-		// Once 5.0 comes out, this function can merge with the deprecated one below it, and this
-		// pragma block can go away.
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-	return check_and_promote(v, t.get(), is_init, expr_location);
-#pragma GCC diagnostic pop
-	}
-
-[[deprecated("Remove in v5.1. Use version that takes TypePtr instead.")]] ValPtr
-check_and_promote(ValPtr v, const Type* t, bool is_init, const detail::Location* expr_location)
 	{
 	if ( ! v )
 		return nullptr;
 
 	Type* vt = flatten_type(v->GetType().get());
-	t = flatten_type(t);
-
+	Type* t = flatten_type(new_type.get());
 	TypeTag t_tag = t->Tag();
 	TypeTag v_tag = vt->Tag();
 
@@ -4016,12 +3911,12 @@ ValPtr Val::MakeBool(bool b)
 	return make_intrusive<BoolVal>(b);
 	}
 
-ValPtr Val::MakeInt(bro_int_t i)
+ValPtr Val::MakeInt(zeek_int_t i)
 	{
 	return make_intrusive<IntVal>(i);
 	}
 
-ValPtr Val::MakeCount(bro_uint_t u)
+ValPtr Val::MakeCount(zeek_uint_t u)
 	{
 	return make_intrusive<CountVal>(u);
 	}
