@@ -176,7 +176,8 @@ static void initialize_var(const IDPtr& id, InitClass c, ExprPtr init)
 	else if ( c == INIT_REMOVE )
 		assignment = make_intrusive<RemoveFromExpr>(lhs, init);
 	else
-		reporter->InternalError("bad InitClass in initialize_var");
+		// This can happen due to error propagation.
+		return;
 
 	if ( assignment->IsError() )
 		return;
@@ -223,6 +224,12 @@ static void make_var(const IDPtr& id, TypePtr t, InitClass c, ExprPtr init,
 				id->Warn("redefinition requires \"redef\"", redef_obj, true);
 			}
 
+		else if ( dt == VAR_REDEF && ! id->IsRedefinable() )
+			{
+			id->Error("cannot redefine a variable not marked with &redef", init.get());
+			return;
+			}
+
 		else if ( dt != VAR_REDEF || init || ! attr )
 			{
 			if ( IsFunc(id->GetType()->Tag()) )
@@ -423,14 +430,25 @@ void add_type(ID* id, TypePtr t, std::unique_ptr<std::vector<AttrPtr>> attr)
 	{
 	std::string new_type_name = id->Name();
 	std::string old_type_name = t->GetName();
+
 	TypePtr tnew;
 
 	if ( (t->Tag() == TYPE_RECORD || t->Tag() == TYPE_ENUM) && old_type_name.empty() )
 		// An extensible type (record/enum) being declared for first time.
 		tnew = std::move(t);
 	else
+		{
+		// If the old type is an error or the old type doesn't exist, then return
+		// an error instead of trying to clone it.
+		if ( t->Tag() == TYPE_ERROR && t->InternalType() == TYPE_INTERNAL_ERROR )
+			{
+			reporter->Error("Error trying to create alias to nonexistent type");
+			return;
+			}
+
 		// Clone the type to preserve type name aliasing.
 		tnew = t->ShallowClone();
+		}
 
 	Type::RegisterAlias(new_type_name, tnew);
 
@@ -745,16 +763,12 @@ TraversalCode OuterIDBindingFinder::PreStmt(const Stmt* stmt)
 	if ( stmt->Tag() != STMT_WHEN )
 		return TC_CONTINUE;
 
-	auto ws = static_cast<const WhenStmt*>(stmt);
-	auto lambda = ws->Info()->Lambda();
-
-	if ( ! lambda )
-		// Old-style semantics.
-		return TC_CONTINUE;
-
 	// The semantics of identifiers for the "when" statement are those
 	// of the lambda it's transformed into.
-	lambda->Traverse(this);
+
+	auto ws = static_cast<const WhenStmt*>(stmt);
+	ws->Info()->Lambda()->Traverse(this);
+
 	return TC_ABORTSTMT;
 	}
 
