@@ -1,19 +1,21 @@
 #include "zeek/WeirdState.h"
+
 #include "zeek/RunState.h"
 #include "zeek/util.h"
 
-namespace zeek::detail {
+namespace zeek::detail
+	{
 
-bool PermitWeird(WeirdStateMap& wsm, const char* name, uint64_t threshold,
-                 uint64_t rate, double duration)
-    {
+bool PermitWeird(WeirdStateMap& wsm, const char* name, uint64_t threshold, uint64_t rate,
+                 double duration)
+	{
 	auto& state = wsm[name];
 	++state.count;
 
 	if ( state.count <= threshold )
 		return true;
 
-	if ( state.count == threshold + 1)
+	if ( state.count == threshold + 1 )
 		state.sampling_start_time = run_state::network_time;
 	else
 		{
@@ -30,6 +32,6 @@ bool PermitWeird(WeirdStateMap& wsm, const char* name, uint64_t threshold,
 		return num_above_threshold % rate == 0;
 	else
 		return false;
-    }
+	}
 
-} // namespace zeek::detail
+	} // namespace zeek::detail
