@@ -4,8 +4,8 @@
 
 #include "zeek/zeek-config.h"
 
-#include <ctype.h>
 #include <algorithm>
+#include <cctype>
 #include <iostream>
 #include <sstream> // Needed for unit testing
 
@@ -26,9 +26,6 @@ using namespace std::string_literals;
 namespace zeek
 	{
 
-constexpr int String::EXPANDED_STRING;
-constexpr int String::BRO_STRING_LITERAL;
-
 // This constructor forces the user to specify arg_final_NUL.  When str
 // is a *normal* NUL-terminated string, make arg_n == strlen(str) and
 // arg_final_NUL == 1; when str is a sequence of n bytes, make
@@ -294,11 +291,6 @@ void String::ToUpper()
 			b[i] = toupper(b[i]);
 	}
 
-unsigned int String::MemoryAllocation() const
-	{
-	return padded_sizeof(*this) + util::pad_size(n + final_NUL);
-	}
-
 String* String::GetSubstring(int start, int len) const
 	{
 	// This code used to live in zeek.bif's sub_bytes() routine.
@@ -540,6 +532,9 @@ TEST_CASE("construction")
 	CHECK_EQ(s7.Len(), 6);
 	CHECK_EQ(s7.Bytes(), text2);
 
+	// Construct a temporary reporter object for the next two tests
+	zeek::reporter = new zeek::Reporter(false);
+
 	zeek::byte_vec text3 = new u_char[7];
 	memcpy(text3, text.c_str(), 7);
 	zeek::String s8{false, text3, 6};
@@ -551,6 +546,8 @@ TEST_CASE("construction")
 	zeek::String s9{false, text4, 6};
 	CHECK_EQ(std::string(s9.CheckString()), "<string-with-NUL>");
 
+	delete zeek::reporter;
+
 	zeek::byte_vec text5 = (zeek::byte_vec)malloc(7);
 	memcpy(text5, text.c_str(), 7);
 	zeek::String s10{true, text5, 6};
@@ -678,7 +675,7 @@ TEST_CASE("rendering")
 	CHECK_EQ(test_length, 7);
 	delete[] r;
 
-	r = s2.Render(zeek::String::BRO_STRING_LITERAL);
+	r = s2.Render(zeek::String::ZEEK_STRING_LITERAL);
 	CHECK_EQ(std::string(r), "\\x03\\x04\\x05\\x06\\\\\\\'");
 	delete[] r;
 
