@@ -5,7 +5,6 @@
 #include <binpac.h>
 #include <algorithm>
 
-#include "zeek/3rdparty/doctest.h"
 #include "zeek/Event.h"
 #include "zeek/ZeekString.h"
 #include "zeek/analyzer/Manager.h"
@@ -481,11 +480,11 @@ void Analyzer::PreventChildren(zeek::Tag tag)
 bool Analyzer::HasChildAnalyzer(zeek::Tag tag)
 	{
 	LOOP_OVER_CHILDREN(i)
-	if ( (*i)->tag == tag && ! ((*i)->removing || (*i)->finished) )
+	if ( (*i)->tag == tag )
 		return true;
 
 	LOOP_OVER_GIVEN_CHILDREN(i, new_children)
-	if ( (*i)->tag == tag && ! ((*i)->removing || (*i)->finished) )
+	if ( (*i)->tag == tag )
 		return true;
 
 	return false;
@@ -493,7 +492,7 @@ bool Analyzer::HasChildAnalyzer(zeek::Tag tag)
 
 Analyzer* Analyzer::FindChild(ID arg_id)
 	{
-	if ( id == arg_id && ! (removing || finished) )
+	if ( id == arg_id )
 		return this;
 
 	LOOP_OVER_CHILDREN(i)
@@ -515,7 +514,7 @@ Analyzer* Analyzer::FindChild(ID arg_id)
 
 Analyzer* Analyzer::FindChild(zeek::Tag arg_tag)
 	{
-	if ( tag == arg_tag && ! (removing || finished) )
+	if ( tag == arg_tag )
 		return this;
 
 	LOOP_OVER_CHILDREN(i)
@@ -679,50 +678,6 @@ void Analyzer::FlipRoles()
 	resp_supporters = tmp;
 	}
 
-void Analyzer::ProtocolConfirmation(zeek::Tag arg_tag)
-	{
-	if ( protocol_confirmed )
-		return;
-
-	protocol_confirmed = true;
-
-	const auto& tval = arg_tag ? arg_tag.AsVal() : tag.AsVal();
-	// Enqueue both of these events. In the base scripts, only the analyzer version is handled.
-	// The protocol remains just for handling scripts that haven't been updated. Once that event
-	// is removed, this method is also removed.
-	if ( analyzer_confirmation )
-		event_mgr.Enqueue(analyzer_confirmation, ConnVal(), tval, val_mgr->Count(id));
-	if ( protocol_confirmation )
-		event_mgr.Enqueue(protocol_confirmation, ConnVal(), tval, val_mgr->Count(id));
-	}
-
-void Analyzer::ProtocolViolation(const char* reason, const char* data, int len)
-	{
-	if ( ! protocol_violation && ! analyzer_violation )
-		return;
-
-	StringValPtr r;
-
-	if ( data && len )
-		{
-		const char* tmp = util::copy_string(reason);
-		r = make_intrusive<StringVal>(util::fmt(
-			"%s [%s%s]", tmp, util::fmt_bytes(data, min(40, len)), len > 40 ? "..." : ""));
-		delete[] tmp;
-		}
-	else
-		r = make_intrusive<StringVal>(reason);
-
-	const auto& tval = tag.AsVal();
-	// Enqueue both of these events. In the base scripts, only the analyzer version is handled.
-	// The protocol remains just for handling scripts that haven't been updated. Once that event
-	// is removed, this method is also removed.
-	if ( analyzer_confirmation )
-		event_mgr.Enqueue(analyzer_violation, ConnVal(), tval, val_mgr->Count(id), std::move(r));
-	if ( protocol_confirmation )
-		event_mgr.Enqueue(protocol_violation, ConnVal(), tval, val_mgr->Count(id), std::move(r));
-	}
-
 void Analyzer::AnalyzerConfirmation(zeek::Tag arg_tag)
 	{
 	if ( analyzer_confirmed )
@@ -742,6 +697,8 @@ void Analyzer::AnalyzerViolation(const char* reason, const char* data, int len,
 	if ( ! analyzer_violation )
 		return;
 
+	StringValPtr r;
+
 	++analyzer_violations;
 
 	if ( analyzer_violations > BifConst::max_analyzer_violations )
@@ -752,8 +709,6 @@ void Analyzer::AnalyzerViolation(const char* reason, const char* data, int len,
 		return;
 		}
 
-	StringValPtr r;
-
 	if ( data && len )
 		{
 		const char* tmp = util::copy_string(reason);
@@ -806,25 +761,6 @@ void Analyzer::AppendNewChildren()
 	new_children.clear();
 	}
 
-unsigned int Analyzer::MemoryAllocation() const
-	{
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-	unsigned int mem = padded_sizeof(*this) + (timers.MemoryAllocation() - padded_sizeof(timers));
-
-	LOOP_OVER_CONST_CHILDREN(i)
-	mem += (*i)->MemoryAllocation();
-
-	for ( SupportAnalyzer* a = orig_supporters; a; a = a->sibling )
-		mem += a->MemoryAllocation();
-
-	for ( SupportAnalyzer* a = resp_supporters; a; a = a->sibling )
-		mem += a->MemoryAllocation();
-
-	return mem;
-#pragma GCC diagnostic pop
-	}
-
 void Analyzer::UpdateConnVal(RecordVal* conn_val)
 	{
 	LOOP_OVER_CHILDREN(i)
@@ -874,11 +810,6 @@ void SupportAnalyzer::ForwardPacket(int len, const u_char* data, bool is_orig, u
 		return;
 		}
 
-	// If the parent is being removed or has finished, there's little point
-	// for a support analyzers to move packets forward.
-	if ( Parent()->Removing() || Parent()->IsFinished() )
-		return;
-
 	SupportAnalyzer* next_sibling = Sibling(true);
 
 	if ( next_sibling )
@@ -899,11 +830,6 @@ void SupportAnalyzer::ForwardStream(int len, const u_char* data, bool is_orig)
 		return;
 		}
 
-	// If the parent is being removed or has finished, there's little point
-	// for a support analyzers to move stream data forward.
-	if ( Parent()->Removing() || Parent()->IsFinished() )
-		return;
-
 	SupportAnalyzer* next_sibling = Sibling(true);
 
 	if ( next_sibling )
@@ -935,41 +861,3 @@ void SupportAnalyzer::ForwardUndelivered(uint64_t seq, int len, bool is_orig)
 	}
 
 	} // namespace zeek::analyzer
-
-TEST_SUITE("Analyzer management")
-	{
-	TEST_CASE("Re-add analyzer after removal")
-		{
-		// This test tries to reactivate an analyzer which was previously removed.
-		// It's a regression test for #2801.
-		REQUIRE(zeek::analyzer_mgr);
-
-		zeek::Packet p;
-		zeek::ConnTuple t;
-		auto conn = std::make_unique<zeek::Connection>(zeek::detail::ConnKey(t), 0, &t, 0, &p);
-		auto* tcp = new zeek::packet_analysis::TCP::TCPSessionAdapter(conn.get());
-		conn->SetSessionAdapter(tcp, nullptr);
-
-		auto a = zeek::analyzer_mgr->InstantiateAnalyzer("SSH", conn.get());
-		REQUIRE(a);
-		auto b1 = zeek::analyzer_mgr->InstantiateAnalyzer("IMAP", a->Conn());
-		REQUIRE(b1);
-
-		tcp->AddChildAnalyzer(a);
-		a->AddChildAnalyzer(b1);
-
-		CHECK(conn->FindAnalyzer("SSH"));
-		CHECK(conn->FindAnalyzer("IMAP"));
-
-		a->RemoveChildAnalyzer(b1);
-
-		CHECK(! conn->FindAnalyzer("IMAP"));
-
-		auto b2 = zeek::analyzer_mgr->InstantiateAnalyzer("IMAP", a->Conn());
-		REQUIRE(b2);
-
-		REQUIRE(a->AddChildAnalyzer(b2));
-		CHECK(conn->FindAnalyzer("IMAP"));
-		conn->Done();
-		}
-	}
