@@ -3,24 +3,22 @@
 #include "zeek/analyzer/Manager.h"
 
 #include "zeek/Hash.h"
-#include "zeek/Val.h"
 #include "zeek/IntrusivePtr.h"
 #include "zeek/RunState.h"
-
+#include "zeek/Val.h"
 #include "zeek/analyzer/protocol/conn-size/ConnSize.h"
 #include "zeek/analyzer/protocol/pia/PIA.h"
 #include "zeek/analyzer/protocol/tcp/TCP.h"
+#include "zeek/analyzer/protocol/tcp/events.bif.h"
 #include "zeek/packet_analysis/protocol/ip/IPBasedAnalyzer.h"
 #include "zeek/packet_analysis/protocol/ip/SessionAdapter.h"
-
 #include "zeek/plugin/Manager.h"
 
-#include "zeek/analyzer/protocol/tcp/events.bif.h"
+namespace zeek::analyzer
+	{
 
-namespace zeek::analyzer {
-
-Manager::ConnIndex::ConnIndex(const IPAddr& _orig, const IPAddr& _resp,
-                              uint16_t _resp_p, uint16_t _proto)
+Manager::ConnIndex::ConnIndex(const IPAddr& _orig, const IPAddr& _resp, uint16_t _resp_p,
+                              uint16_t _proto)
 	{
 	if ( _orig == IPAddr::v4_unspecified )
 		// don't use the IPv4 mapping, use the literal unspecified address
@@ -59,7 +57,7 @@ bool Manager::ConnIndex::operator<(const ConnIndex& other) const
 	}
 
 Manager::Manager()
-	: plugin::ComponentManager<analyzer::Tag, analyzer::Component>("Analyzer", "Tag")
+	: plugin::ComponentManager<analyzer::Component>("Analyzer", "Tag", "AllAnalyzers")
 	{
 	}
 
@@ -76,10 +74,10 @@ Manager::~Manager()
 
 void Manager::InitPostScript()
 	{
-	const auto& id = detail::global_scope()->Find("Tunnel::vxlan_ports");
+	const auto& id = detail::global_scope()->Find("PacketAnalyzer::VXLAN::vxlan_ports");
 
 	if ( ! (id && id->GetVal()) )
-		reporter->FatalError("Tunnel::vxlan_ports not defined");
+		reporter->FatalError("PacketAnalyzer::VXLAN::vxlan_ports not defined");
 
 	auto table_val = id->GetVal()->AsTableVal();
 	auto port_list = table_val->ToPureListVal();
@@ -87,10 +85,11 @@ void Manager::InitPostScript()
 	for ( auto i = 0; i < port_list->Length(); ++i )
 		vxlan_ports.emplace_back(port_list->Idx(i)->AsPortVal()->Port());
 
-	for ( const auto& p : pending_analyzers_for_ports ) {
+	for ( const auto& p : pending_analyzers_for_ports )
+		{
 		if ( ! RegisterAnalyzerForPort(p) )
 			reporter->Warning("cannot register analyzer for port %u", std::get<2>(p));
-	}
+		}
 
 	pending_analyzers_for_ports.clear();
 
@@ -102,7 +101,8 @@ void Manager::DumpDebug()
 #ifdef DEBUG
 	DBG_LOG(DBG_ANALYZER, "Available analyzers after zeek_init():");
 	std::list<Component*> all_analyzers = GetComponents();
-	for ( std::list<Component*>::const_iterator i = all_analyzers.begin(); i != all_analyzers.end(); ++i )
+	for ( std::list<Component*>::const_iterator i = all_analyzers.begin(); i != all_analyzers.end();
+	      ++i )
 		DBG_LOG(DBG_ANALYZER, "    %s (%s)", (*i)->Name().c_str(),
 		        IsEnabled((*i)->Tag()) ? "enabled" : "disabled");
 
@@ -124,15 +124,13 @@ void Manager::DumpDebug()
 #endif
 	}
 
-void Manager::Done()
-	{
-	}
+void Manager::Done() { }
 
-bool Manager::EnableAnalyzer(const Tag& tag)
+bool Manager::EnableAnalyzer(const zeek::Tag& tag)
 	{
 	Component* p = Lookup(tag);
 
-	if ( ! p  )
+	if ( ! p )
 		return false;
 
 	DBG_LOG(DBG_ANALYZER, "Enabling analyzer %s", p->Name().c_str());
@@ -145,7 +143,7 @@ bool Manager::EnableAnalyzer(EnumVal* val)
 	{
 	Component* p = Lookup(val);
 
-	if ( ! p  )
+	if ( ! p )
 		return false;
 
 	DBG_LOG(DBG_ANALYZER, "Enabling analyzer %s", p->Name().c_str());
@@ -154,11 +152,11 @@ bool Manager::EnableAnalyzer(EnumVal* val)
 	return true;
 	}
 
-bool Manager::DisableAnalyzer(const Tag& tag)
+bool Manager::DisableAnalyzer(const zeek::Tag& tag)
 	{
 	Component* p = Lookup(tag);
 
-	if ( ! p  )
+	if ( ! p )
 		return false;
 
 	DBG_LOG(DBG_ANALYZER, "Disabling analyzer %s", p->Name().c_str());
@@ -171,7 +169,7 @@ bool Manager::DisableAnalyzer(EnumVal* val)
 	{
 	Component* p = Lookup(val);
 
-	if ( ! p  )
+	if ( ! p )
 		return false;
 
 	DBG_LOG(DBG_ANALYZER, "Disabling analyzer %s", p->Name().c_str());
@@ -185,23 +183,24 @@ void Manager::DisableAllAnalyzers()
 	DBG_LOG(DBG_ANALYZER, "Disabling all analyzers");
 
 	std::list<Component*> all_analyzers = GetComponents();
-	for ( std::list<Component*>::const_iterator i = all_analyzers.begin(); i != all_analyzers.end(); ++i )
+	for ( std::list<Component*>::const_iterator i = all_analyzers.begin(); i != all_analyzers.end();
+	      ++i )
 		(*i)->SetEnabled(false);
 	}
 
-analyzer::Tag Manager::GetAnalyzerTag(const char* name)
+zeek::Tag Manager::GetAnalyzerTag(const char* name)
 	{
 	return GetComponentTag(name);
 	}
 
-bool Manager::IsEnabled(const Tag& tag)
+bool Manager::IsEnabled(const zeek::Tag& tag)
 	{
 	if ( ! tag )
 		return false;
 
 	Component* p = Lookup(tag);
 
-	if ( ! p  )
+	if ( ! p )
 		return false;
 
 	return p->Enabled();
@@ -211,18 +210,17 @@ bool Manager::IsEnabled(EnumVal* val)
 	{
 	Component* p = Lookup(val);
 
-	if ( ! p  )
+	if ( ! p )
 		return false;
 
 	return p->Enabled();
 	}
 
-
 bool Manager::RegisterAnalyzerForPort(EnumVal* val, PortVal* port)
 	{
 	Component* p = Lookup(val);
 
-	if ( ! p  )
+	if ( ! p )
 		return false;
 
 	return RegisterAnalyzerForPort(p->Tag(), port->PortType(), port->Port());
@@ -232,13 +230,13 @@ bool Manager::UnregisterAnalyzerForPort(EnumVal* val, PortVal* port)
 	{
 	Component* p = Lookup(val);
 
-	if ( ! p  )
+	if ( ! p )
 		return false;
 
 	return UnregisterAnalyzerForPort(p->Tag(), port->PortType(), port->Port());
 	}
 
-bool Manager::RegisterAnalyzerForPort(const Tag& tag, TransportProto proto, uint32_t port)
+bool Manager::RegisterAnalyzerForPort(const zeek::Tag& tag, TransportProto proto, uint32_t port)
 	{
 	if ( initialized )
 		return RegisterAnalyzerForPort(std::make_tuple(tag, proto, port));
@@ -252,7 +250,7 @@ bool Manager::RegisterAnalyzerForPort(const Tag& tag, TransportProto proto, uint
 		}
 	}
 
-bool Manager::RegisterAnalyzerForPort(const std::tuple<Tag, TransportProto, uint32_t>& p)
+bool Manager::RegisterAnalyzerForPort(const std::tuple<zeek::Tag, TransportProto, uint32_t>& p)
 	{
 	const auto& [tag, proto, port] = p;
 
@@ -272,9 +270,10 @@ bool Manager::RegisterAnalyzerForPort(const std::tuple<Tag, TransportProto, uint
 	return ipba->RegisterAnalyzerForPort(tag, port);
 	}
 
-bool Manager::UnregisterAnalyzerForPort(const Tag& tag, TransportProto proto, uint32_t port)
+bool Manager::UnregisterAnalyzerForPort(const zeek::Tag& tag, TransportProto proto, uint32_t port)
 	{
-	if ( auto i = pending_analyzers_for_ports.find(std::make_tuple(tag, proto, port)); i != pending_analyzers_for_ports.end() )
+	if ( auto i = pending_analyzers_for_ports.find(std::make_tuple(tag, proto, port));
+	     i != pending_analyzers_for_ports.end() )
 		pending_analyzers_for_ports.erase(i);
 
 	// TODO: this class is becoming more generic and removing a lot of the
@@ -293,7 +292,7 @@ bool Manager::UnregisterAnalyzerForPort(const Tag& tag, TransportProto proto, ui
 	return ipba->UnregisterAnalyzerForPort(tag, port);
 	}
 
-Analyzer* Manager::InstantiateAnalyzer(const Tag& tag, Connection* conn)
+Analyzer* Manager::InstantiateAnalyzer(const zeek::Tag& tag, Connection* conn)
 	{
 	Component* c = Lookup(tag);
 
@@ -309,7 +308,7 @@ Analyzer* Manager::InstantiateAnalyzer(const Tag& tag, Connection* conn)
 	if ( ! c->Factory() )
 		{
 		reporter->InternalWarning("analyzer %s cannot be instantiated dynamically",
-					  GetComponentName(tag).c_str());
+		                          GetComponentName(tag).c_str());
 		return nullptr;
 		}
 
@@ -328,7 +327,7 @@ Analyzer* Manager::InstantiateAnalyzer(const Tag& tag, Connection* conn)
 
 Analyzer* Manager::InstantiateAnalyzer(const char* name, Connection* conn)
 	{
-	Tag tag = GetComponentTag(name);
+	zeek::Tag tag = GetComponentTag(name);
 	return tag ? InstantiateAnalyzer(tag, conn) : nullptr;
 	}
 
@@ -370,10 +369,8 @@ void Manager::ExpireScheduledAnalyzers()
 		}
 	}
 
-void Manager::ScheduleAnalyzer(const IPAddr& orig, const IPAddr& resp,
-			uint16_t resp_p,
-			TransportProto proto, const Tag& analyzer,
-			double timeout)
+void Manager::ScheduleAnalyzer(const IPAddr& orig, const IPAddr& resp, uint16_t resp_p,
+                               TransportProto proto, const zeek::Tag& analyzer, double timeout)
 	{
 	if ( ! run_state::network_time )
 		{
@@ -395,14 +392,12 @@ void Manager::ScheduleAnalyzer(const IPAddr& orig, const IPAddr& resp,
 	conns_by_timeout.push(a);
 	}
 
-void Manager::ScheduleAnalyzer(const IPAddr& orig, const IPAddr& resp,
-			uint16_t resp_p,
-			TransportProto proto, const char* analyzer,
-			double timeout)
+void Manager::ScheduleAnalyzer(const IPAddr& orig, const IPAddr& resp, uint16_t resp_p,
+                               TransportProto proto, const char* analyzer, double timeout)
 	{
-	Tag tag = GetComponentTag(analyzer);
+	zeek::Tag tag = GetComponentTag(analyzer);
 
-	if ( tag != Tag() )
+	if ( tag != zeek::Tag() )
 		ScheduleAnalyzer(orig, resp, resp_p, proto, tag, timeout);
 	}
 
@@ -411,13 +406,12 @@ void Manager::ScheduleAnalyzer(const IPAddr& orig, const IPAddr& resp, PortVal*
 	{
 	EnumValPtr ev{NewRef{}, analyzer->AsEnumVal()};
 	return ScheduleAnalyzer(orig, resp, resp_p->Port(), resp_p->PortType(),
-	                        Tag(std::move(ev)), timeout);
+	                        zeek::Tag(std::move(ev)), timeout);
 	}
 
 Manager::tag_set Manager::GetScheduled(const Connection* conn)
 	{
-	ConnIndex c(conn->OrigAddr(), conn->RespAddr(),
-		    ntohs(conn->RespPort()), conn->ConnTransport());
+	ConnIndex c(conn->OrigAddr(), conn->RespAddr(), ntohs(conn->RespPort()), conn->ConnTransport());
 
 	std::pair<conns_map::iterator, conns_map::iterator> all = conns.equal_range(c);
 
@@ -462,8 +456,7 @@ bool Manager::ApplyScheduledAnalyzers(Connection* conn, bool init,
 		parent->AddChildAnalyzer(analyzer, init);
 
 		if ( scheduled_analyzer_applied )
-			conn->EnqueueEvent(scheduled_analyzer_applied, nullptr,
-			                   conn->GetVal(), it->AsVal());
+			conn->EnqueueEvent(scheduled_analyzer_applied, nullptr, conn->GetVal(), it->AsVal());
 
 		DBG_ANALYZER_ARGS(conn, "activated %s analyzer as scheduled",
 		                  analyzer_mgr->GetComponentName(*it).c_str());
@@ -472,4 +465,4 @@ bool Manager::ApplyScheduledAnalyzers(Connection* conn, bool init,
 	return expected.size();
 	}
 
-} // namespace zeek::analyzer
+	} // namespace zeek::analyzer
