@@ -3,10 +3,10 @@
 #include "zeek/analyzer/protocol/dhcp/events.bif.h"
 #include "zeek/analyzer/protocol/dhcp/types.bif.h"
 
-namespace zeek::analyzer::dhcp {
+namespace zeek::analyzer::dhcp
+	{
 
-DHCP_Analyzer::DHCP_Analyzer(Connection* conn)
-: Analyzer("DHCP", conn)
+DHCP_Analyzer::DHCP_Analyzer(Connection* conn) : Analyzer("DHCP", conn)
 	{
 	interp = new binpac::DHCP::DHCP_Conn(this);
 	}
@@ -21,8 +21,8 @@ void DHCP_Analyzer::Done()
 	Analyzer::Done();
 	}
 
-void DHCP_Analyzer::DeliverPacket(int len, const u_char* data,
-			bool orig, uint64_t seq, const IP_Hdr* ip, int caplen)
+void DHCP_Analyzer::DeliverPacket(int len, const u_char* data, bool orig, uint64_t seq,
+                                  const IP_Hdr* ip, int caplen)
 	{
 	Analyzer::DeliverPacket(len, data, orig, seq, ip, caplen);
 
@@ -32,9 +32,8 @@ void DHCP_Analyzer::DeliverPacket(int len, const u_char* data,
 		}
 	catch ( const binpac::Exception& e )
 		{
-		ProtocolViolation(util::fmt("Binpac exception: %s", e.c_msg()));
+		AnalyzerViolation(util::fmt("Binpac exception: %s", e.c_msg()));
 		}
-
 	}
 
-} // namespace zeek::analyzer::dhcp
+	} // namespace zeek::analyzer::dhcp
