@@ -1,16 +1,20 @@
 // See the file  in the main distribution directory for copyright.
 
 #include "zeek/plugin/Plugin.h"
+
 #include "zeek/analyzer/Component.h"
 #include "zeek/analyzer/protocol/dns/DNS.h"
 
-namespace zeek::plugin::detail::Zeek_DNS {
+namespace zeek::plugin::detail::Zeek_DNS
+	{
 
-class Plugin : public zeek::plugin::Plugin {
+class Plugin : public zeek::plugin::Plugin
+	{
 public:
 	zeek::plugin::Configuration Configure() override
 		{
-		AddComponent(new zeek::analyzer::Component("DNS", zeek::analyzer::dns::DNS_Analyzer::Instantiate));
+		AddComponent(
+			new zeek::analyzer::Component("DNS", zeek::analyzer::dns::DNS_Analyzer::Instantiate));
 		AddComponent(new zeek::analyzer::Component("Contents_DNS", nullptr));
 
 		zeek::plugin::Configuration config;
@@ -18,6 +22,6 @@ public:
 		config.description = "DNS analyzer";
 		return config;
 		}
-} plugin;
+	} plugin;
 
-} // namespace zeek::plugin::detail::Zeek_DNS
+	} // namespace zeek::plugin::detail::Zeek_DNS
