@@ -1,16 +1,16 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
+#include "zeek/analyzer/protocol/login/Telnet.h"
+
 #include "zeek/zeek-config.h"
 
-#include "zeek/analyzer/protocol/login/Telnet.h"
 #include "zeek/analyzer/protocol/login/NVT.h"
-
 #include "zeek/analyzer/protocol/login/events.bif.h"
 
-namespace zeek::analyzer::login {
+namespace zeek::analyzer::login
+	{
 
-Telnet_Analyzer::Telnet_Analyzer(Connection* conn)
-: Login_Analyzer("TELNET", conn)
+Telnet_Analyzer::Telnet_Analyzer(Connection* conn) : Login_Analyzer("TELNET", conn)
 	{
 	NVT_Analyzer* nvt_orig = new NVT_Analyzer(conn, true);
 	NVT_Analyzer* nvt_resp = new NVT_Analyzer(conn, false);
@@ -22,4 +22,4 @@ Telnet_Analyzer::Telnet_Analyzer(Connection* conn)
 	AddSupportAnalyzer(nvt_resp);
 	}
 
-} // namespace zeek::analyzer::login
+	} // namespace zeek::analyzer::login
