@@ -1,12 +1,12 @@
 #include "zeek/analyzer/protocol/modbus/Modbus.h"
-#include "zeek/analyzer/protocol/tcp/TCP_Reassembler.h"
 
 #include "zeek/analyzer/protocol/modbus/events.bif.h"
+#include "zeek/analyzer/protocol/tcp/TCP_Reassembler.h"
 
-namespace zeek::analyzer::modbus {
+namespace zeek::analyzer::modbus
+	{
 
-ModbusTCP_Analyzer::ModbusTCP_Analyzer(Connection* c)
-	: TCP_ApplicationAnalyzer("MODBUS", c)
+ModbusTCP_Analyzer::ModbusTCP_Analyzer(Connection* c) : TCP_ApplicationAnalyzer("MODBUS", c)
 	{
 	interp = new binpac::ModbusTCP::ModbusTCP_Conn(this);
 	}
@@ -42,4 +42,4 @@ void ModbusTCP_Analyzer::EndpointEOF(bool is_orig)
 	interp->FlowEOF(is_orig);
 	}
 
-} // namespace zeek::analyzer::modbus
+	} // namespace zeek::analyzer::modbus
