@@ -1,16 +1,17 @@
 #include "zeek/analyzer/protocol/pia/PIA.h"
 
-#include "zeek/RuleMatcher.h"
-#include "zeek/Event.h"
-#include "zeek/NetVar.h"
-#include "zeek/IP.h"
 #include "zeek/DebugLogger.h"
+#include "zeek/Event.h"
+#include "zeek/IP.h"
+#include "zeek/NetVar.h"
 #include "zeek/Reporter.h"
+#include "zeek/RuleMatcher.h"
 #include "zeek/RunState.h"
 #include "zeek/analyzer/protocol/tcp/TCP_Flags.h"
 #include "zeek/analyzer/protocol/tcp/TCP_Reassembler.h"
 
-namespace zeek::analyzer::pia {
+namespace zeek::analyzer::pia
+	{
 
 PIA::PIA(analyzer::Analyzer* arg_as_analyzer)
 	: state(INIT), as_analyzer(arg_as_analyzer), conn(), current_packet()
@@ -29,7 +30,7 @@ void PIA::ClearBuffer(Buffer* buffer)
 		{
 		next = b->next;
 		delete b->ip;
-		delete [] b->data;
+		delete[] b->data;
 		delete b;
 		}
 
@@ -37,8 +38,8 @@ void PIA::ClearBuffer(Buffer* buffer)
 	buffer->size = 0;
 	}
 
-void PIA::AddToBuffer(Buffer* buffer, uint64_t seq, int len, const u_char* data,
-                      bool is_orig, const IP_Hdr* ip)
+void PIA::AddToBuffer(Buffer* buffer, uint64_t seq, int len, const u_char* data, bool is_orig,
+                      const IP_Hdr* ip)
 	{
 	u_char* tmp = nullptr;
 
@@ -64,11 +65,11 @@ void PIA::AddToBuffer(Buffer* buffer, uint64_t seq, int len, const u_char* data,
 	else
 		buffer->head = buffer->tail = b;
 
-	buffer->size += len;
+	if ( data )
+		buffer->size += len;
 	}
 
-void PIA::AddToBuffer(Buffer* buffer, int len, const u_char* data, bool is_orig,
-                      const IP_Hdr* ip)
+void PIA::AddToBuffer(Buffer* buffer, int len, const u_char* data, bool is_orig, const IP_Hdr* ip)
 	{
 	AddToBuffer(buffer, -1, len, data, is_orig, ip);
 	}
@@ -102,13 +103,12 @@ void PIA::PIA_DeliverPacket(int len, const u_char* data, bool is_orig, uint64_t
 	if ( pkt_buffer.state == INIT )
 		new_state = BUFFERING;
 
-	if ( (pkt_buffer.state == BUFFERING || new_state == BUFFERING) &&
-	     len > 0 )
+	if ( (pkt_buffer.state == BUFFERING || new_state == BUFFERING) && len > 0 )
 		{
 		AddToBuffer(&pkt_buffer, seq, len, data, is_orig, ip);
-		if ( pkt_buffer.size > zeek::detail::dpd_buffer_size || ++pkt_buffer.chunks > zeek::detail::dpd_max_packets )
-			new_state = zeek::detail::dpd_match_only_beginning ?
-						SKIPPING : MATCHING_ONLY;
+		if ( pkt_buffer.size > zeek::detail::dpd_buffer_size ||
+		     ++pkt_buffer.chunks > zeek::detail::dpd_max_packets )
+			new_state = zeek::detail::dpd_match_only_beginning ? SKIPPING : MATCHING_ONLY;
 		}
 
 	// FIXME: I'm not sure why it does not work with eol=true...
@@ -122,8 +122,8 @@ void PIA::PIA_DeliverPacket(int len, const u_char* data, bool is_orig, uint64_t
 	current_packet.data = nullptr;
 	}
 
-void PIA::Match(zeek::detail::Rule::PatternType type, const u_char* data, int len,
-                bool is_orig, bool bol, bool eol, bool clear_state)
+void PIA::Match(zeek::detail::Rule::PatternType type, const u_char* data, int len, bool is_orig,
+                bool bol, bool eol, bool clear_state)
 	{
 	if ( ! MatcherInitialized(is_orig) )
 		InitEndpointMatcher(AsAnalyzer(), nullptr, 0, is_orig, this);
@@ -131,8 +131,8 @@ void PIA::Match(zeek::detail::Rule::PatternType type, const u_char* data, int le
 	zeek::detail::RuleMatcherState::Match(type, data, len, is_orig, bol, eol, clear_state);
 	}
 
-void PIA::DoMatch(const u_char* data, int len, bool is_orig, bool bol, bool eol,
-                  bool clear_state, const IP_Hdr* ip)
+void PIA::DoMatch(const u_char* data, int len, bool is_orig, bool bol, bool eol, bool clear_state,
+                  const IP_Hdr* ip)
 	{
 	if ( ! zeek::detail::rule_matcher )
 		return;
@@ -143,11 +143,11 @@ void PIA::DoMatch(const u_char* data, int len, bool is_orig, bool bol, bool eol,
 	if ( ! MatcherInitialized(is_orig) )
 		InitEndpointMatcher(AsAnalyzer(), ip, len, is_orig, this);
 
-	zeek::detail::RuleMatcherState::Match(zeek::detail::Rule::PAYLOAD, data, len, is_orig,
-	                                      bol, eol, clear_state);
+	zeek::detail::RuleMatcherState::Match(zeek::detail::Rule::PAYLOAD, data, len, is_orig, bol, eol,
+	                                      clear_state);
 	}
 
-void PIA_UDP::ActivateAnalyzer(analyzer::Tag tag, const zeek::detail::Rule* rule)
+void PIA_UDP::ActivateAnalyzer(zeek::Tag tag, const zeek::detail::Rule* rule)
 	{
 	if ( pkt_buffer.state == MATCHING_ONLY )
 		{
@@ -181,7 +181,7 @@ void PIA_UDP::ActivateAnalyzer(analyzer::Tag tag, const zeek::detail::Rule* rule
 	ReplayPacketBuffer(a);
 	}
 
-void PIA_UDP::DeactivateAnalyzer(analyzer::Tag tag)
+void PIA_UDP::DeactivateAnalyzer(zeek::Tag tag)
 	{
 	reporter->InternalError("PIA_UDP::Deact not implemented yet");
 	}
@@ -220,9 +220,8 @@ void PIA_TCP::FirstPacket(bool is_orig, const IP_Hdr* ip)
 		// else would be *really* ugly ...
 		if ( ! ip4_hdr )
 			{
-			ip4 = (struct ip*) dummy_packet;
-			tcp4 = (struct tcphdr*)
-				(dummy_packet + sizeof(struct ip));
+			ip4 = (struct ip*)dummy_packet;
+			tcp4 = (struct tcphdr*)(dummy_packet + sizeof(struct ip));
 			ip4->ip_len = sizeof(struct ip) + sizeof(struct tcphdr);
 			ip4->ip_hl = sizeof(struct ip) >> 2;
 			ip4->ip_p = IPPROTO_TCP;
@@ -281,9 +280,9 @@ void PIA_TCP::DeliverStream(int len, const u_char* data, bool is_orig)
 	if ( stream_buffer.state == BUFFERING || new_state == BUFFERING )
 		{
 		AddToBuffer(&stream_buffer, len, data, is_orig);
-		if ( stream_buffer.size > zeek::detail::dpd_buffer_size || ++stream_buffer.chunks > zeek::detail::dpd_max_packets )
-			new_state = zeek::detail::dpd_match_only_beginning ?
-						SKIPPING : MATCHING_ONLY;
+		if ( stream_buffer.size > zeek::detail::dpd_buffer_size ||
+		     ++stream_buffer.chunks > zeek::detail::dpd_max_packets )
+			new_state = zeek::detail::dpd_match_only_beginning ? SKIPPING : MATCHING_ONLY;
 		}
 
 	DoMatch(data, len, is_orig, false, false, false, nullptr);
@@ -308,7 +307,7 @@ void PIA_TCP::Undelivered(uint64_t seq, int len, bool is_orig)
 		}
 	}
 
-void PIA_TCP::ActivateAnalyzer(analyzer::Tag tag, const zeek::detail::Rule* rule)
+void PIA_TCP::ActivateAnalyzer(zeek::Tag tag, const zeek::detail::Rule* rule)
 	{
 	if ( stream_buffer.state == MATCHING_ONLY )
 		{
@@ -376,8 +375,8 @@ void PIA_TCP::ActivateAnalyzer(analyzer::Tag tag, const zeek::detail::Rule* rule
 		// we have been inserted somewhere further down in the
 		// analyzer tree.  In this case, we will never have seen
 		// any input at this point (because we don't get packets).
-		assert(!pkt_buffer.head);
-		assert(!stream_buffer.head);
+		assert(! pkt_buffer.head);
+		assert(! stream_buffer.head);
 		return;
 		}
 
@@ -399,11 +398,11 @@ void PIA_TCP::ActivateAnalyzer(analyzer::Tag tag, const zeek::detail::Rule* rule
 		// worth the effort.
 
 		if ( b->is_orig )
-			reass_orig->DataSent(run_state::network_time, orig_seq = b->seq,
-			                     b->len, b->data, tcp::TCP_Flags(), true);
+			reass_orig->DataSent(run_state::network_time, orig_seq = b->seq, b->len, b->data,
+			                     tcp::TCP_Flags(), true);
 		else
-			reass_resp->DataSent(run_state::network_time, resp_seq = b->seq,
-			                     b->len, b->data, tcp::TCP_Flags(), true);
+			reass_resp->DataSent(run_state::network_time, resp_seq = b->seq, b->len, b->data,
+			                     tcp::TCP_Flags(), true);
 		}
 
 	// We also need to pass the current packet on.
@@ -411,13 +410,11 @@ void PIA_TCP::ActivateAnalyzer(analyzer::Tag tag, const zeek::detail::Rule* rule
 	if ( current->data )
 		{
 		if ( current->is_orig )
-			reass_orig->DataSent(run_state::network_time,
-					orig_seq = current->seq,
-					current->len, current->data, analyzer::tcp::TCP_Flags(), true);
+			reass_orig->DataSent(run_state::network_time, orig_seq = current->seq, current->len,
+			                     current->data, analyzer::tcp::TCP_Flags(), true);
 		else
-			reass_resp->DataSent(run_state::network_time,
-					resp_seq = current->seq,
-					current->len, current->data, analyzer::tcp::TCP_Flags(), true);
+			reass_resp->DataSent(run_state::network_time, resp_seq = current->seq, current->len,
+			                     current->data, analyzer::tcp::TCP_Flags(), true);
 		}
 
 	ClearBuffer(&pkt_buffer);
@@ -432,7 +429,7 @@ void PIA_TCP::ActivateAnalyzer(analyzer::Tag tag, const zeek::detail::Rule* rule
 	tcp->SetReassembler(reass_orig, reass_resp);
 	}
 
-void PIA_TCP::DeactivateAnalyzer(analyzer::Tag tag)
+void PIA_TCP::DeactivateAnalyzer(zeek::Tag tag)
 	{
 	reporter->InternalError("PIA_TCP::Deact not implemented yet");
 	}
@@ -450,4 +447,4 @@ void PIA_TCP::ReplayStreamBuffer(analyzer::Analyzer* analyzer)
 		}
 	}
 
-} // namespace zeek::analyzer::pia
+	} // namespace zeek::analyzer::pia
