@@ -46,10 +46,7 @@ void SOCKS_Analyzer::DeliverStream(int len, const u_char* data, bool orig)
 	{
 	analyzer::tcp::TCP_ApplicationAnalyzer::DeliverStream(len, data, orig);
 
-	assert(TCP());
-
-	if ( TCP()->IsPartial() )
-		// punt on partial.
+	if ( TCP() && TCP()->IsPartial() )
 		return;
 
 	if ( orig_done && resp_done )
