@@ -1,16 +1,20 @@
 // See the file  in the main distribution directory for copyright.
 
 #include "zeek/plugin/Plugin.h"
+
 #include "zeek/analyzer/Component.h"
 #include "zeek/analyzer/protocol/ssh/SSH.h"
 
-namespace zeek::plugin::detail::Zeek_SSH {
+namespace zeek::plugin::detail::Zeek_SSH
+	{
 
-class Plugin : public zeek::plugin::Plugin {
+class Plugin : public zeek::plugin::Plugin
+	{
 public:
 	zeek::plugin::Configuration Configure() override
 		{
-		AddComponent(new zeek::analyzer::Component("SSH", zeek::analyzer::ssh::SSH_Analyzer::Instantiate));
+		AddComponent(
+			new zeek::analyzer::Component("SSH", zeek::analyzer::ssh::SSH_Analyzer::Instantiate));
 
 		zeek::plugin::Configuration config;
 		config.name = "Zeek::SSH";
@@ -19,4 +23,4 @@ public:
 		}
 	} plugin;
 
-} // namespace zeek::plugin::detail::Zeek_SSH
+	} // namespace zeek::plugin::detail::Zeek_SSH
