@@ -39,6 +39,24 @@ public:
 
 	static analyzer::Analyzer* Instantiate(Connection* conn) { return new DTLS_Analyzer(conn); }
 
+	/**
+	 * Check if the connection is flipped--meaning that the TLS client is the responder of the
+	 * connection.
+	 *
+	 * @return True if connection is flipped.
+	 */
+	bool GetFlipped();
+
+	/**
+	 * Try to decrypt TLS application data from a packet.
+	 *
+	 * For DTLS, this operation is not currently implemented and this function will
+	 * always return false.
+	 *
+	 **/
+	bool TryDecryptApplicationData(int len, const u_char* data, bool is_orig, uint8_t content_type,
+	                               uint16_t raw_tls_version);
+
 protected:
 	binpac::DTLS::SSL_Conn* interp;
 	binpac::TLSHandshake::Handshake_Conn* handshake_interp;
