@@ -417,20 +417,8 @@ struct val_converter
 					return nullptr;
 
 				auto* b = dynamic_cast<zeek::detail::ScriptFunc*>(rval->AsFunc());
-				if ( ! b )
+				if ( ! b || ! b->DeserializeCaptures(*frame) )
 					return nullptr;
-
-				if ( b->HasCopySemantics() )
-					{
-					if ( ! b->DeserializeCaptures(*frame) )
-						return nullptr;
-					}
-				else
-					{
-					// Support for deprecated serialization.
-					if ( ! b->UpdateClosure(*frame) )
-						return nullptr;
-					}
 				}
 
 			return rval;
@@ -906,7 +894,7 @@ broker::expected<broker::data> val_to_data(const Val* v)
 				// Only ScriptFuncs have closures.
 				if ( auto b = dynamic_cast<const zeek::detail::ScriptFunc*>(f) )
 					{
-					auto bc = b->SerializeClosure();
+					auto bc = b->SerializeCaptures();
 					if ( ! bc )
 						return broker::ec::invalid_data;
 
@@ -936,8 +924,6 @@ broker::expected<broker::data> val_to_data(const Val* v)
 			for ( const auto& te : *table )
 				{
 				auto hk = te.GetHashKey();
-				auto* entry = te.GetValue<TableEntryVal*>();
-
 				auto vl = table_val->RecreateIndex(*hk);
 
 				broker::vector composite_key;
@@ -964,7 +950,7 @@ broker::expected<broker::data> val_to_data(const Val* v)
 					get<broker::set>(rval).emplace(move(key));
 				else
 					{
-					auto val = val_to_data(entry->GetVal().get());
+					auto val = val_to_data(te.value->GetVal().get());
 
 					if ( ! val )
 						return broker::ec::invalid_data;
