@@ -401,6 +401,21 @@ void Manager::InitPostScript()
 			opt.broker_write(std::move(str_ls));
 			}
 		}
+	WITH_OPT_MAPPING("broker.metrics.import.topics", "Broker::metrics_import_topics")
+		{
+		if ( auto topics = opt.broker_read<std::vector<std::string>>() )
+			{
+			opt.zeek_write(*topics);
+			}
+		else
+			{
+			auto ptr = opt.zeek_read()->AsVectorVal();
+			std::vector<std::string> str_ls;
+			for ( unsigned index = 0; index < ptr->Size(); ++index )
+				str_ls.emplace_back(ptr->StringValAt(index)->ToStdString());
+			opt.broker_write(std::move(str_ls));
+			}
+		}
 
 	auto cqs = get_option("Broker::congestion_queue_size")->AsCount();
 	bstate = std::make_shared<BrokerState>(std::move(config), cqs);
@@ -2066,9 +2081,9 @@ void Manager::PrepareForwarding(const std::string& name)
 
 void Manager::SetMetricsExportInterval(double value)
 	{
-	broker::timespan ts;
-	if ( broker::convert(value, ts) )
-		bstate->endpoint.metrics_exporter().set_interval(ts);
+	using dbl_seconds = std::chrono::duration<double>;
+	auto ts = std::chrono::duration_cast<broker::timespan>(dbl_seconds{value});
+	bstate->endpoint.metrics_exporter().set_interval(ts);
 	}
 
 void Manager::SetMetricsExportTopic(std::string value)
@@ -2076,6 +2091,11 @@ void Manager::SetMetricsExportTopic(std::string value)
 	bstate->endpoint.metrics_exporter().set_target(std::move(value));
 	}
 
+void Manager::SetMetricsImportTopics(std::vector<std::string> topics)
+	{
+	bstate->endpoint.metrics_exporter().set_import_topics(std::move(topics));
+	}
+
 void Manager::SetMetricsExportEndpointName(std::string value)
 	{
 	bstate->endpoint.metrics_exporter().set_id(std::move(value));
