@@ -5,6 +5,7 @@
 #include <broker/store.hh>
 #include <broker/store_event.hh>
 
+#include "zeek/Expr.h"
 #include "zeek/OpaqueVal.h"
 #include "zeek/Trigger.h"
 #include "zeek/broker/data.bif.h"
@@ -52,9 +53,9 @@ inline RecordValPtr query_result(RecordValPtr data)
  * @param e: expire interval as double; 0 if no expiry
  * @return expire interval in Broker format
  */
-static broker::optional<broker::timespan> convert_expiry(double e)
+static std::optional<broker::timespan> convert_expiry(double e)
 	{
-	broker::optional<broker::timespan> ts;
+	std::optional<broker::timespan> ts;
 
 	if ( e )
 		{
@@ -72,9 +73,9 @@ static broker::optional<broker::timespan> convert_expiry(double e)
 class StoreQueryCallback
 	{
 public:
-	StoreQueryCallback(zeek::detail::trigger::Trigger* arg_trigger,
-	                   const zeek::detail::CallExpr* arg_call, broker::store store)
-		: trigger(arg_trigger), call(arg_call), store(std::move(store))
+	StoreQueryCallback(zeek::detail::trigger::Trigger* arg_trigger, const void* arg_assoc,
+	                   broker::store store)
+		: trigger(arg_trigger), assoc(arg_assoc), store(std::move(store))
 		{
 		Ref(trigger);
 		}
@@ -83,14 +84,14 @@ public:
 
 	void Result(const RecordValPtr& result)
 		{
-		trigger->Cache(call, result.get());
+		trigger->Cache(assoc, result.get());
 		trigger->Release();
 		}
 
 	void Abort()
 		{
 		auto result = query_result();
-		trigger->Cache(call, result.get());
+		trigger->Cache(assoc, result.get());
 		trigger->Release();
 		}
 
@@ -100,7 +101,7 @@ public:
 
 private:
 	zeek::detail::trigger::Trigger* trigger;
-	const zeek::detail::CallExpr* call;
+	const void* assoc;
 	broker::store store;
 	};
 
@@ -122,7 +123,7 @@ public:
 
 	broker::store store;
 	broker::store::proxy proxy;
-	broker::publisher_id store_pid;
+	broker::entity_id store_pid;
 	// Zeek table that events are forwarded to.
 	TableValPtr forward_to;
 	bool have_store = false;
