@@ -2,7 +2,6 @@
 
 #include "zeek/file_analysis/File.h"
 
-#include <limits>
 #include <utility>
 
 #include "zeek/Event.h"
@@ -378,7 +377,7 @@ void File::DeliverStream(const u_char* data, uint64_t len)
 
 	for ( const auto& entry : analyzers )
 		{
-		auto* a = entry.GetValue<file_analysis::Analyzer*>();
+		auto* a = entry.value;
 
 		DBG_LOG(DBG_FILE_ANALYSIS, "stream delivery to analyzer %s",
 		        file_mgr->GetComponentName(a->Tag()).c_str());
@@ -432,15 +431,6 @@ void File::DeliverStream(const u_char* data, uint64_t len)
 
 void File::DeliverChunk(const u_char* data, uint64_t len, uint64_t offset)
 	{
-	if ( std::numeric_limits<uint64_t>::max() - offset < len )
-		{
-		reporter->Weird(this, "file_offset_overflow",
-		                zeek::util::fmt("offset=%" PRIx64 " len=%" PRIx64, offset, len),
-		                GetSource().c_str());
-
-		len = std::numeric_limits<uint64_t>::max() - offset;
-		}
-
 	// Potentially handle reassembly and deliver to the stream analyzers.
 	if ( file_reassembler )
 		{
@@ -485,7 +475,7 @@ void File::DeliverChunk(const u_char* data, uint64_t len, uint64_t offset)
 
 	for ( const auto& entry : analyzers )
 		{
-		auto* a = entry.GetValue<file_analysis::Analyzer*>();
+		auto* a = entry.value;
 
 		DBG_LOG(DBG_FILE_ANALYSIS, "chunk delivery to analyzer %s",
 		        file_mgr->GetComponentName(a->Tag()).c_str());
@@ -549,7 +539,7 @@ void File::EndOfFile()
 
 	for ( const auto& entry : analyzers )
 		{
-		auto* a = entry.GetValue<file_analysis::Analyzer*>();
+		auto* a = entry.value;
 
 		if ( ! a->EndOfFile() )
 			analyzers.QueueRemove(a->Tag(), a->GetArgs());
@@ -584,7 +574,7 @@ void File::Gap(uint64_t offset, uint64_t len)
 
 	for ( const auto& entry : analyzers )
 		{
-		auto* a = entry.GetValue<file_analysis::Analyzer*>();
+		auto* a = entry.value;
 
 		if ( ! a->Undelivered(offset, len) )
 			analyzers.QueueRemove(a->Tag(), a->GetArgs());
