@@ -2,23 +2,23 @@
 
 #pragma once
 
-#include <string>
 #include <cstdio>
+#include <string>
 
 #include "zeek/Val.h"
-#include "zeek/file_analysis/File.h"
 #include "zeek/file_analysis/Analyzer.h"
-
+#include "zeek/file_analysis/File.h"
 #include "zeek/file_analysis/analyzer/extract/events.bif.h"
 
-namespace zeek::file_analysis::detail {
+namespace zeek::file_analysis::detail
+	{
 
 /**
  * An analyzer to extract content of files to local disk.
  */
-class Extract : public file_analysis::Analyzer {
+class Extract : public file_analysis::Analyzer
+	{
 public:
-
 	/**
 	 * Destructor.  Will close the file that was used for data extraction.
 	 */
@@ -48,8 +48,7 @@ public:
 	 * @return the new Extract analyzer instance or a null pointer if the
 	 *         the "extraction_file" field of \a args wasn't set.
 	 */
-	static file_analysis::Analyzer* Instantiate(RecordValPtr args,
-	                                            file_analysis::File* file);
+	static file_analysis::Analyzer* Instantiate(RecordValPtr args, file_analysis::File* file);
 
 	/**
 	 * Sets the maximum allowed extracted file size.  A value of zero means
@@ -59,7 +58,6 @@ public:
 	void SetLimit(uint64_t bytes) { limit = bytes; }
 
 protected:
-
 	/**
 	 * Constructor.
 	 * @param args the \c AnalyzerArgs value which represents the analyzer.
@@ -68,14 +66,14 @@ protected:
 	 *        to which the contents of the file will be extracted/written.
 	 * @param arg_limit the maximum allowed file size.
 	 */
-	Extract(RecordValPtr args, file_analysis::File* file,
-	        const std::string& arg_filename, uint64_t arg_limit);
+	Extract(RecordValPtr args, file_analysis::File* file, const std::string& arg_filename,
+	        uint64_t arg_limit);
 
 private:
 	std::string filename;
 	FILE* file_stream;
 	uint64_t limit;
 	uint64_t depth;
-};
+	};
 
-} // namespace zeek::file_analysis::detail
+	} // namespace zeek::file_analysis::detail
