@@ -2,23 +2,22 @@
 
 #include "zeek/file_analysis/analyzer/x509/X509Common.h"
 
+#include <openssl/asn1.h>
+#include <openssl/err.h>
+#include <openssl/opensslconf.h>
 #include <openssl/x509.h>
 #include <openssl/x509v3.h>
-#include <openssl/asn1.h>
-#include <openssl/opensslconf.h>
-#include <openssl/err.h>
 
 #include "zeek/Reporter.h"
-
-#include "zeek/file_analysis/analyzer/x509/x509-extension_pac.h"
 #include "zeek/file_analysis/analyzer/x509/events.bif.h"
 #include "zeek/file_analysis/analyzer/x509/ocsp_events.bif.h"
 #include "zeek/file_analysis/analyzer/x509/types.bif.h"
+#include "zeek/file_analysis/analyzer/x509/x509-extension_pac.h"
 
-namespace zeek::file_analysis::detail {
+namespace zeek::file_analysis::detail
+	{
 
-X509Common::X509Common(const file_analysis::Tag& arg_tag,
-                       RecordValPtr arg_args,
+X509Common::X509Common(const zeek::Tag& arg_tag, RecordValPtr arg_args,
                        file_analysis::File* arg_file)
 	: file_analysis::Analyzer(arg_tag, std::move(arg_args), arg_file)
 	{
@@ -32,14 +31,15 @@ static void EmitWeird(const char* name, file_analysis::File* file, const char* a
 		reporter->Weird(name);
 	}
 
-double X509Common::GetTimeFromAsn1(const ASN1_TIME* atime, file_analysis::File* f, Reporter* reporter)
+double X509Common::GetTimeFromAsn1(const ASN1_TIME* atime, file_analysis::File* f,
+                                   Reporter* reporter)
 	{
 	time_t lResult = 0;
 
 	char lBuffer[26];
 	char* pBuffer = lBuffer;
 
-	const char *pString = (const char *) atime->data;
+	const char* pString = (const char*)atime->data;
 	unsigned int remaining = atime->length;
 
 	if ( atime->type == V_ASN1_UTCTIME )
@@ -50,7 +50,7 @@ double X509Common::GetTimeFromAsn1(const ASN1_TIME* atime, file_analysis::File*
 			return 0;
 			}
 
-		if ( pString[remaining-1] != 'Z' )
+		if ( pString[remaining - 1] != 'Z' )
 			{
 			// not valid according to RFC 2459 4.1.2.5.1
 			EmitWeird("x509_utc_format", f);
@@ -145,7 +145,7 @@ double X509Common::GetTimeFromAsn1(const ASN1_TIME* atime, file_analysis::File*
 			return 0;
 			}
 
-		if ((*pString != '+') && (*pString != '-'))
+		if ( (*pString != '+') && (*pString != '-') )
 			{
 			EmitWeird("x509_time_offset_type", f);
 			return 0;
@@ -154,31 +154,32 @@ double X509Common::GetTimeFromAsn1(const ASN1_TIME* atime, file_analysis::File*
 		lSecondsFromUTC = ((pString[1] - '0') * 10 + (pString[2] - '0')) * 60;
 		lSecondsFromUTC += (pString[3] - '0') * 10 + (pString[4] - '0');
 
-		if (*pString == '-')
+		if ( *pString == '-' )
 			lSecondsFromUTC = -lSecondsFromUTC;
 		}
 
 	tm lTime;
-	lTime.tm_sec  = ((lBuffer[12] - '0') * 10) + (lBuffer[13] - '0');
-	lTime.tm_min  = ((lBuffer[10] - '0') * 10) + (lBuffer[11] - '0');
+	lTime.tm_sec = ((lBuffer[12] - '0') * 10) + (lBuffer[13] - '0');
+	lTime.tm_min = ((lBuffer[10] - '0') * 10) + (lBuffer[11] - '0');
 	lTime.tm_hour = ((lBuffer[8] - '0') * 10) + (lBuffer[9] - '0');
 	lTime.tm_mday = ((lBuffer[6] - '0') * 10) + (lBuffer[7] - '0');
-	lTime.tm_mon  = (((lBuffer[4] - '0') * 10) + (lBuffer[5] - '0')) - 1;
-	lTime.tm_year = (lBuffer[0] - '0') * 1000 + (lBuffer[1] - '0') * 100 + ((lBuffer[2] - '0') * 10) + (lBuffer[3] - '0');
+	lTime.tm_mon = (((lBuffer[4] - '0') * 10) + (lBuffer[5] - '0')) - 1;
+	lTime.tm_year = (lBuffer[0] - '0') * 1000 + (lBuffer[1] - '0') * 100 +
+	                ((lBuffer[2] - '0') * 10) + (lBuffer[3] - '0');
 
-	if ( lTime.tm_year > 1900)
+	if ( lTime.tm_year > 1900 )
 		lTime.tm_year -= 1900;
 
 	lTime.tm_wday = 0;
 	lTime.tm_yday = 0;
-	lTime.tm_isdst = 0;  // No DST adjustment requested
+	lTime.tm_isdst = 0; // No DST adjustment requested
 
 	lResult = mktime(&lTime);
 
 	if ( lResult )
 		{
-		if ( lTime.tm_isdst  != 0 )
-			lResult -= 3600;  // mktime may adjust for DST  (OS dependent)
+		if ( lTime.tm_isdst != 0 )
+			lResult -= 3600; // mktime may adjust for DST  (OS dependent)
 
 		lResult += lSecondsFromUTC;
 		}
@@ -187,7 +188,7 @@ double X509Common::GetTimeFromAsn1(const ASN1_TIME* atime, file_analysis::File*
 		lResult = 0;
 
 	return lResult;
-}
+	}
 
 void X509Common::ParseSignedCertificateTimestamps(X509_EXTENSION* ext)
 	{
@@ -200,25 +201,28 @@ void X509Common::ParseSignedCertificateTimestamps(X509_EXTENSION* ext)
 	// the octet string of the extension contains the octet string which in turn
 	// contains the SCT. Obviously.
 
-	unsigned char* ext_val_copy = (unsigned char*) OPENSSL_malloc(ext_val->length);
+	unsigned char* ext_val_copy = (unsigned char*)OPENSSL_malloc(ext_val->length);
 	unsigned char* ext_val_second_pointer = ext_val_copy;
 	memcpy(ext_val_copy, ext_val->data, ext_val->length);
 
-	ASN1_OCTET_STRING* inner = d2i_ASN1_OCTET_STRING(NULL, (const unsigned char**) &ext_val_copy, ext_val->length);
-	if ( !inner )
+	ASN1_OCTET_STRING* inner = d2i_ASN1_OCTET_STRING(NULL, (const unsigned char**)&ext_val_copy,
+	                                                 ext_val->length);
+	if ( ! inner )
 		{
-		reporter->Error("X509::ParseSignedCertificateTimestamps could not parse inner octet string");
+		reporter->Error(
+			"X509::ParseSignedCertificateTimestamps could not parse inner octet string");
 		return;
 		}
 
 	binpac::X509Extension::MockConnection* conn = new binpac::X509Extension::MockConnection(this);
-	binpac::X509Extension::SignedCertTimestampExt* interp = new binpac::X509Extension::SignedCertTimestampExt(conn);
+	binpac::X509Extension::SignedCertTimestampExt* interp =
+		new binpac::X509Extension::SignedCertTimestampExt(conn);
 
 	try
 		{
 		interp->NewData(inner->data, inner->data + inner->length);
 		}
-	catch( const binpac::Exception& e )
+	catch ( const binpac::Exception& e )
 		{
 		// throw a warning or sth
 		reporter->Error("X509::ParseSignedCertificateTimestamps could not parse SCT");
@@ -248,12 +252,12 @@ void X509Common::ParseExtension(X509_EXTENSION* ex, const EventHandlerPtr& h, bo
 	if ( X509_EXTENSION_get_critical(ex) != 0 )
 		critical = 1;
 
-	BIO *bio = BIO_new(BIO_s_mem());
-	if( ! X509V3_EXT_print(bio, ex, 0, 0))
+	BIO* bio = BIO_new(BIO_s_mem());
+	if ( ! X509V3_EXT_print(bio, ex, 0, 0) )
 		{
-		unsigned char *buf = nullptr;
+		unsigned char* buf = nullptr;
 		int len = i2d_ASN1_OCTET_STRING(X509_EXTENSION_get_data(ex), &buf);
-		if ( len >=0 )
+		if ( len >= 0 )
 			{
 			BIO_write(bio, buf, len);
 			OPENSSL_free(buf);
@@ -290,9 +294,7 @@ void X509Common::ParseExtension(X509_EXTENSION* ex, const EventHandlerPtr& h, bo
 	// but I am not sure if there is a better way to do it...
 
 	if ( h == ocsp_extension )
-		event_mgr.Enqueue(h, GetFile()->ToVal(),
-		                  std::move(pX509Ext),
-		                  val_mgr->Bool(global));
+		event_mgr.Enqueue(h, GetFile()->ToVal(), std::move(pX509Ext), val_mgr->Bool(global));
 	else
 		event_mgr.Enqueue(h, GetFile()->ToVal(), std::move(pX509Ext));
 
@@ -321,7 +323,7 @@ StringValPtr X509Common::GetExtensionFromBIO(BIO* bio, file_analysis::File* f)
 		return val_mgr->EmptyString();
 		}
 
-	char* buffer = (char*) malloc(length);
+	char* buffer = (char*)malloc(length);
 
 	if ( ! buffer )
 		{
@@ -332,7 +334,7 @@ StringValPtr X509Common::GetExtensionFromBIO(BIO* bio, file_analysis::File* f)
 		return nullptr;
 		}
 
-	BIO_read(bio, (void*) buffer, length);
+	BIO_read(bio, (void*)buffer, length);
 	auto ext_val = make_intrusive<StringVal>(length, buffer);
 
 	free(buffer);
@@ -341,4 +343,4 @@ StringValPtr X509Common::GetExtensionFromBIO(BIO* bio, file_analysis::File* f)
 	return ext_val;
 	}
 
-} // namespace zeek::file_analysis::detail
+	} // namespace zeek::file_analysis::detail
