@@ -3,12 +3,12 @@
 #include <unistd.h>
 #include <cstdlib>
 
-#include "zeek/zeek-setup.h"
-
 #include "zeek/Event.h"
-#include "zeek/session/Manager.h"
+#include "zeek/EventRegistry.h"
 #include "zeek/broker/Manager.h"
 #include "zeek/file_analysis/Manager.h"
+#include "zeek/session/Manager.h"
+#include "zeek/zeek-setup.h"
 
 extern "C" int LLVMFuzzerInitialize(int* argc, char*** argv)
 	{
@@ -42,10 +42,16 @@ extern "C" int LLVMFuzzerInitialize(int* argc, char*** argv)
 	if ( zeek::detail::setup(*argc, *argv, &options).code )
 		abort();
 
+	// We have to trick the event handlers into returning true that they exist here
+	// even if they don't, because otherwise we lose a bit of coverage where if
+	// statements return false that would otherwise not.
+	zeek::event_registry->ActivateAllHandlers();
+
 	return 0;
 	}
 
-namespace zeek::detail {
+namespace zeek::detail
+	{
 
 void fuzzer_cleanup_one_input()
 	{
@@ -61,4 +67,4 @@ void fuzzer_cleanup_one_input()
 	run_state::terminating = false;
 	}
 
-} // namespace zeek::detail
+	} // namespace zeek::detail
