@@ -1,15 +1,16 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
 #include "zeek/input/Component.h"
-#include "zeek/input/Manager.h"
 
 #include "zeek/Desc.h"
+#include "zeek/input/Manager.h"
 #include "zeek/util.h"
 
-namespace zeek::input {
+namespace zeek::input
+	{
 
 Component::Component(const std::string& name, factory_callback arg_factory)
-	: plugin::Component(plugin::component::READER, name)
+	: plugin::Component(plugin::component::READER, name, 0, input_mgr->GetTagType())
 	{
 	factory = arg_factory;
 	}
@@ -20,9 +21,7 @@ void Component::Initialize()
 	input_mgr->RegisterComponent(this, "READER_");
 	}
 
-Component::~Component()
-	{
-	}
+Component::~Component() { }
 
 void Component::DoDescribe(ODesc* d) const
 	{
@@ -30,4 +29,4 @@ void Component::DoDescribe(ODesc* d) const
 	d->Add(CanonicalName());
 	}
 
-} // namespace zeek::input
+	} // namespace zeek::input
