@@ -272,7 +272,7 @@ bool Manager::CreateStream(Stream* info, RecordVal* description)
 		for ( const auto& icte : *info_config_table )
 			{
 			auto k = icte.GetHashKey();
-			auto* v = icte.GetValue<TableEntryVal*>();
+			auto* v = icte.value;
 
 			auto index = info->config->RecreateIndex(*k);
 			string key = index->Idx(0)->AsString()->CheckString();
@@ -1402,7 +1402,7 @@ void Manager::EndCurrentSend(ReaderFrontend* reader)
 	for ( auto it = stream->lastDict->begin_robust(); it != stream->lastDict->end_robust(); ++it )
 		{
 		auto lastDictIdxKey = it->GetHashKey();
-		InputHash* ih = it->GetValue<InputHash*>();
+		InputHash* ih = it->value;
 
 		ValPtr val;
 		ValPtr predidx;
@@ -2414,19 +2414,11 @@ Val* Manager::ValueToVal(const Stream* i, const Value* val, Type* request_type,
 			// Well, this is kind of stupid, because EnumType just
 			// mangles the module name and the var name together again...
 			// but well.
-			bro_int_t index = request_type->AsEnumType()->Lookup(module, var.c_str());
+			zeek_int_t index = request_type->AsEnumType()->Lookup(module, var.c_str());
 			if ( index == -1 )
 				{
-				auto source = i->reader->Info().source;
-				auto file_pos = val->GetFileLineNumber();
-
-				const char* warning = zeek::util::fmt(
-					"Value '%s' for stream '%s' is not a valid enum.", enum_string.c_str(),
-					i->name.c_str());
-				if ( source && file_pos != -1 )
-					Warning(i, "%s, line %d: %s", source, file_pos, warning);
-				else
-					Warning(i, "%s", warning);
+				Warning(i, "Value '%s' for stream '%s' is not a valid enum.", enum_string.c_str(),
+				        i->name.c_str());
 
 				have_error = true;
 				return nullptr;
