@@ -2,10 +2,10 @@
 
 #include "zeek/input/readers/ascii/Ascii.h"
 
-#include <errno.h>
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <unistd.h>
+#include <cerrno>
 #include <sstream>
 
 #include "zeek/input/readers/ascii/ascii.bif.h"
@@ -55,9 +55,10 @@ Ascii::Ascii(ReaderFrontend* frontend) : ReaderBackend(frontend)
 	fail_on_invalid_lines = false;
 	}
 
-Ascii::~Ascii() { }
-
-void Ascii::DoClose() { }
+void Ascii::DoClose()
+	{
+	read_location.reset();
+	}
 
 bool Ascii::DoInit(const ReaderInfo& info, int num_fields, const Field* const* fields)
 	{
@@ -82,26 +83,25 @@ bool Ascii::DoInit(const ReaderInfo& info, int num_fields, const Field* const* f
 	                   BifConst::InputAscii::path_prefix->Len());
 
 	// Set per-filter configuration options.
-	for ( ReaderInfo::config_map::const_iterator i = info.config.begin(); i != info.config.end();
-	      i++ )
+	for ( const auto& [k, v] : info.config )
 		{
-		if ( strcmp(i->first, "separator") == 0 )
-			separator.assign(i->second);
+		if ( strcmp(k, "separator") == 0 )
+			separator.assign(v);
 
-		else if ( strcmp(i->first, "set_separator") == 0 )
-			set_separator.assign(i->second);
+		else if ( strcmp(k, "set_separator") == 0 )
+			set_separator.assign(v);
 
-		else if ( strcmp(i->first, "empty_field") == 0 )
-			empty_field.assign(i->second);
+		else if ( strcmp(k, "empty_field") == 0 )
+			empty_field.assign(v);
 
-		else if ( strcmp(i->first, "unset_field") == 0 )
-			unset_field.assign(i->second);
+		else if ( strcmp(k, "unset_field") == 0 )
+			unset_field.assign(v);
 
-		else if ( strcmp(i->first, "fail_on_invalid_lines") == 0 )
-			fail_on_invalid_lines = (strncmp(i->second, "T", 1) == 0);
+		else if ( strcmp(k, "fail_on_invalid_lines") == 0 )
+			fail_on_invalid_lines = (strncmp(v, "T", 1) == 0);
 
-		else if ( strcmp(i->first, "fail_on_file_problem") == 0 )
-			fail_on_file_problem = (strncmp(i->second, "T", 1) == 0);
+		else if ( strcmp(k, "fail_on_file_problem") == 0 )
+			fail_on_file_problem = (strncmp(v, "T", 1) == 0);
 		}
 
 	if ( separator.size() != 1 )
@@ -156,6 +156,12 @@ bool Ascii::OpenFile()
 		return ! fail_on_file_problem;
 		}
 
+	if ( ! read_location )
+		{
+		read_location = LocationPtr(new zeek::detail::Location());
+		read_location->filename = util::copy_string(fname.c_str());
+		}
+
 	StopWarningSuppression();
 	return true;
 	}
@@ -164,7 +170,6 @@ bool Ascii::ReadHeader(bool useCached)
 	{
 	// try to read the header line...
 	string line;
-	map<string, uint32_t> ifields;
 
 	if ( ! useCached )
 		{
@@ -184,26 +189,18 @@ bool Ascii::ReadHeader(bool useCached)
 		line = headerline;
 
 	// construct list of field names.
-	istringstream splitstream(line);
-	int pos = 0;
-	while ( splitstream )
-		{
-		string s;
-		if ( ! getline(splitstream, s, separator[0]) )
-			break;
-
-		ifields[s] = pos;
-		pos++;
-		}
+	auto ifields = util::split(line, separator[0]);
 
 	// printf("Updating fields from description %s\n", line.c_str());
 	columnMap.clear();
 
+	const auto* fields = Fields();
+
 	for ( int i = 0; i < NumFields(); i++ )
 		{
-		const Field* field = Fields()[i];
+		const Field* field = fields[i];
 
-		map<string, uint32_t>::iterator fit = ifields.find(field->name);
+		auto fit = std::find(ifields.begin(), ifields.end(), field->name);
 		if ( fit == ifields.end() )
 			{
 			if ( field->optional )
@@ -224,11 +221,12 @@ bool Ascii::ReadHeader(bool useCached)
 			return false;
 			}
 
-		FieldMapping f(field->name, field->type, field->subtype, ifields[field->name]);
+		int index = static_cast<int>(std::distance(ifields.begin(), fit));
+		FieldMapping f(field->name, field->type, field->subtype, index);
 
 		if ( field->secondary_name && strlen(field->secondary_name) != 0 )
 			{
-			map<string, uint32_t>::iterator fit2 = ifields.find(field->secondary_name);
+			auto fit2 = std::find(ifields.begin(), ifields.end(), field->secondary_name);
 			if ( fit2 == ifields.end() )
 				{
 				FailWarn(fail_on_file_problem,
@@ -239,7 +237,7 @@ bool Ascii::ReadHeader(bool useCached)
 				return false;
 				}
 
-			f.secondary_position = ifields[field->secondary_name];
+			f.secondary_position = static_cast<int>(std::distance(ifields.begin(), fit2));
 			}
 
 		columnMap.push_back(f);
@@ -253,7 +251,13 @@ bool Ascii::GetLine(string& str)
 	{
 	while ( getline(file, str) )
 		{
-		if ( ! str.size() )
+		if ( read_location )
+			{
+			read_location->first_line++;
+			read_location->last_line++;
+			}
+
+		if ( str.empty() )
 			continue;
 
 		if ( str.back() == '\r' ) // deal with \r\n by removing \r
@@ -278,6 +282,12 @@ bool Ascii::DoUpdate()
 	if ( ! OpenFile() )
 		return ! fail_on_file_problem;
 
+	if ( read_location )
+		{
+		read_location->first_line = 0;
+		read_location->last_line = 0;
+		}
+
 	switch ( Info().mode )
 		{
 		case MODE_REREAD:
@@ -346,45 +356,34 @@ bool Ascii::DoUpdate()
 		{
 		// split on tabs
 		bool error = false;
-		istringstream splitstream(line);
+		auto stringfields = util::split(line, separator[0]);
 
-		map<int, string> stringfields;
-		int pos = 0;
-		while ( splitstream )
-			{
-			string s;
-			if ( ! getline(splitstream, s, separator[0]) )
-				break;
-
-			stringfields[pos] = s;
-			pos++;
-			}
-
-		pos--; // for easy comparisons of max element.
+		// This needs to be a signed value or the comparisons below will fail.
+		int pos = static_cast<int>(stringfields.size() - 1);
 
 		Value** fields = new Value*[NumFields()];
 
 		int fpos = 0;
-		for ( vector<FieldMapping>::iterator fit = columnMap.begin(); fit != columnMap.end();
-		      fit++ )
+		for ( const auto& fit : columnMap )
 			{
-
-			if ( ! fit->present )
+			if ( ! fit.present )
 				{
 				// add non-present field
-				fields[fpos] = new Value((*fit).type, false);
+				fields[fpos] = new Value(fit.type, false);
+				if ( read_location )
+					fields[fpos]->SetFileLineNumber(read_location->first_line);
 				fpos++;
 				continue;
 				}
 
-			assert(fit->position >= 0);
+			assert(fit.position >= 0);
 
-			if ( (*fit).position > pos || (*fit).secondary_position > pos )
+			if ( fit.position > pos || fit.secondary_position > pos )
 				{
 				FailWarn(fail_on_invalid_lines, Fmt("Not enough fields in line '%s' of %s. Found "
 				                                    "%d fields, want positions %d and %d",
-				                                    line.c_str(), fname.c_str(), pos,
-				                                    (*fit).position, (*fit).secondary_position));
+				                                    line.c_str(), fname.c_str(), pos, fit.position,
+				                                    fit.secondary_position));
 
 				if ( fail_on_invalid_lines )
 					{
@@ -402,9 +401,8 @@ bool Ascii::DoUpdate()
 					}
 				}
 
-			Value* val = formatter->ParseValue(stringfields[(*fit).position], (*fit).name,
-			                                   (*fit).type, (*fit).subtype);
-
+			Value* val = formatter->ParseValue(stringfields[fit.position], fit.name, fit.type,
+			                                   fit.subtype);
 			if ( ! val )
 				{
 				Warning(Fmt("Could not convert line '%s' of %s to Val. Ignoring line.",
@@ -413,14 +411,17 @@ bool Ascii::DoUpdate()
 				break;
 				}
 
-			if ( (*fit).secondary_position != -1 )
+			if ( read_location )
+				val->SetFileLineNumber(read_location->first_line);
+
+			if ( fit.secondary_position != -1 )
 				{
 				// we have a port definition :)
 				assert(val->type == TYPE_PORT);
 				//	Error(Fmt("Got type %d != PORT with secondary position!", val->type));
 
 				val->val.port_val.proto = formatter->ParseProto(
-					stringfields[(*fit).secondary_position]);
+					stringfields[fit.secondary_position]);
 				}
 
 			fields[fpos] = val;
