@@ -2,24 +2,26 @@
 
 #include "zeek/zeek-config.h"
 
-#include <stdint.h>
 #include <sys/types.h> // for u_char
+#include <cstdint>
 #include <string>
 
 #if defined(__OpenBSD__)
 #include <net/bpf.h>
-typedef struct bpf_timeval pkt_timeval;
+using pkt_timeval = bpf_timeval;
 #else
-typedef struct timeval pkt_timeval;
+using pkt_timeval = struct timeval;
 #endif
 
 #include <pcap.h> // For DLT_ constants
 
+#include "zeek/IP.h"
 #include "zeek/NetVar.h" // For BifEnum::Tunnel
 #include "zeek/TunnelEncapsulation.h"
-#include "zeek/IP.h"
+#include "zeek/session/Session.h"
 
-namespace zeek {
+namespace zeek
+	{
 
 class ODesc;
 class Val;
@@ -34,17 +36,19 @@ using RecordValPtr = IntrusivePtr<RecordVal>;
  * This enum is sized as an int32_t to make the Packet structure align
  * correctly.
  */
-enum Layer3Proto : int32_t {
-	L3_UNKNOWN = -1,	/// Layer 3 type could not be determined.
-	L3_IPV4 = 1,		/// Layer 3 is IPv4.
-	L3_IPV6 = 2,		/// Layer 3 is IPv6.
-	L3_ARP = 3,			/// Layer 3 is ARP.
-};
+enum Layer3Proto : int32_t
+	{
+	L3_UNKNOWN = -1, /// Layer 3 type could not be determined.
+	L3_IPV4 = 1, /// Layer 3 is IPv4.
+	L3_IPV6 = 2, /// Layer 3 is IPv6.
+	L3_ARP = 3, /// Layer 3 is ARP.
+	};
 
 /**
  * A link-layer packet.
  */
-class Packet {
+class Packet
+	{
 public:
 	/**
 	 * Construct and initialize from packet data.
@@ -68,12 +72,11 @@ public:
 	 * @param tag A textual tag to associate with the packet for
 	 * differentiating the input streams.
 	 */
-	Packet(int link_type, pkt_timeval *ts, uint32_t caplen,
-	       uint32_t len, const u_char *data, bool copy = false,
-	       std::string tag = "")
-	       {
-	       Init(link_type, ts, caplen, len, data, copy, tag);
-	       }
+	Packet(int link_type, pkt_timeval* ts, uint32_t caplen, uint32_t len, const u_char* data,
+	       bool copy = false, std::string tag = "")
+		{
+		Init(link_type, ts, caplen, len, data, copy, tag);
+		}
 
 	/**
 	 * Default constructor. For internal use only.
@@ -111,9 +114,8 @@ public:
 	 * @param tag A textual tag to associate with the packet for
 	 * differentiating the input streams.
 	 */
-	void Init(int link_type, pkt_timeval *ts, uint32_t caplen,
-	          uint32_t len, const u_char *data, bool copy = false,
-	          std::string tag = "");
+	void Init(int link_type, pkt_timeval* ts, uint32_t caplen, uint32_t len, const u_char* data,
+	          bool copy = false, std::string tag = "");
 
 	/**
 	 * Returns a \c raw_pkt_hdr RecordVal, which includes layer 2 and
@@ -121,6 +123,12 @@ public:
 	 */
 	RecordValPtr ToRawPktHdrVal() const;
 
+	/**
+	 * Returns a RecordVal that represents the Packet. This is used
+	 * by the get_current_packet bif.
+	 */
+	static RecordValPtr ToVal(const Packet* p);
+
 	/**
 	 * Maximal length of a layer 2 address.
 	 */
@@ -128,19 +136,19 @@ public:
 
 	/**
 	 * Empty layer 2 address to be used as default value. For example, the
-	 * LinuxSLL packet analyzer doesn't have a destination address in the
-	 * header and thus sets it to this default address.
+	 * LinuxSLL/LinuxSLL2 packet analyzers don't have a destination address
+	 * in the header and thus sets it to this default address.
 	 */
-	static constexpr const u_char L2_EMPTY_ADDR[L2_ADDR_LEN] = { 0 };
+	static constexpr const u_char L2_EMPTY_ADDR[L2_ADDR_LEN] = {0};
 
 	// These are passed in through the constructor.
-	std::string tag;				/// Used in serialization
-	double time;					/// Timestamp reconstituted as float
-	pkt_timeval ts;					/// Capture timestamp
-	const u_char* data = nullptr;	/// Packet data.
-	uint32_t len;					/// Actual length on wire
-	uint32_t cap_len;				/// Captured packet length
-	uint32_t link_type;				/// pcap link_type (DLT_EN10MB, DLT_RAW, etc)
+	std::string tag; /// Used in serialization
+	double time; /// Timestamp reconstituted as float
+	pkt_timeval ts; /// Capture timestamp
+	const u_char* data = nullptr; /// Packet data.
+	uint32_t len; /// Actual length on wire
+	uint32_t cap_len; /// Captured packet length
+	uint32_t link_type; /// pcap link_type (DLT_EN10MB, DLT_RAW, etc)
 
 	/**
 	 * Layer 3 protocol identified (if any).
@@ -165,29 +173,45 @@ public:
 	/**
 	 * (Outermost) VLAN tag if any, else 0.
 	 */
-	uint32_t vlan;
+	uint32_t vlan = 0;
 
 	/**
 	 * (Innermost) VLAN tag if any, else 0.
 	 */
-	uint32_t inner_vlan;
+	uint32_t inner_vlan = 0;
 
 	/**
-	 * Indicates whether the layer 2 checksum was validated by the
-	 * hardware/kernel before being received by zeek.
+	 * If this packet is related to a connection, this flag denotes whether
+	 * this packet is from the originator of the connection.
 	 */
-	bool l2_checksummed;
+	bool is_orig = false;
+
+	// Note: The following checksummed variables only apply to packets
+	// received via a packet source, and not to packets contained inside
+	// tunnels, etc.
 
 	/**
-	 * Indicates whether the layer 3 checksum was validated by the
-	 * hardware/kernel before being received by zeek.
+	 * Indicates whether the data link layer/layer 2 checksum was validated
+	 * the hardware/kernel before being received by zeek.
 	 */
-	bool l3_checksummed;
+	bool l2_checksummed = false;
+
+	/**
+	 * Indicates whether the network layer/layer 3 checksum was validated by
+	 * the hardware/kernel before being received by zeek.
+	 */
+	bool l3_checksummed = false;
+
+	/**
+	 * Indicates whether the transport layer/layer 4 checksum was validated
+	 * by the hardware/kernel before being received by zeek.
+	 */
+	bool l4_checksummed = false;
 
 	/**
 	 * Indicates whether this packet should be recorded.
 	 */
-	mutable bool dump_packet;
+	mutable bool dump_packet = false;
 
 	/**
 	 * Indicates the amount of data to be dumped. If only a header is needed,
@@ -211,7 +235,7 @@ public:
 	 * The IP header for this packet. This is filled in by the IP analyzer
 	 * during processing if the packet contains an IP header.
 	 */
-	std::unique_ptr<IP_Hdr> ip_hdr = nullptr;
+	std::shared_ptr<IP_Hdr> ip_hdr = nullptr;
 
 	/**
 	 * The protocol of the packet. This is used by the tunnel analyzers to
@@ -240,6 +264,19 @@ public:
 	 */
 	int gre_link_type = DLT_RAW;
 
+	/**
+	 * This flag indicates whether a packet has been processed. This can
+	 * mean different things depending on the traffic, but generally it
+	 * means that a packet has been logged in some way. We default to
+	 * false, and this can be set to true for any number of reasons.
+	 */
+	bool processed = false;
+
+	/**
+	 * The session related to this packet, if one exists.
+	 */
+	session::Session* session = nullptr;
+
 private:
 	// Renders an MAC address into its ASCII representation.
 	ValPtr FmtEUI48(const u_char* mac) const;
@@ -247,6 +284,6 @@ private:
 	// True if we need to delete associated packet memory upon
 	// destruction.
 	bool copy;
-};
+	};
 
-} // namespace zeek
+	} // namespace zeek
