@@ -30,8 +30,6 @@ PktSrc::Properties::Properties()
 PktSrc::PktSrc()
 	{
 	have_packet = false;
-	// Small lie to make a new PktSrc look like the previous ExtractNextPacket() was successful.
-	had_packet = true;
 	errbuf = "";
 	SetClosed(true);
 	}
@@ -85,11 +83,17 @@ void PktSrc::Opened(const Properties& arg_props)
 		}
 
 	if ( props.is_live )
+		{
 		Info(util::fmt("listening on %s\n", props.path.c_str()));
 
-	if ( props.selectable_fd != -1 )
-		if ( ! iosource_mgr->RegisterFd(props.selectable_fd, this) )
-			reporter->FatalError("Failed to register pktsrc fd with iosource_mgr");
+		// We only register the file descriptor if we're in live
+		// mode because libpcap's file descriptor for trace files
+		// isn't a reliable way to know whether we actually have
+		// data to read.
+		if ( props.selectable_fd != -1 )
+			if ( ! iosource_mgr->RegisterFd(props.selectable_fd, this) )
+				reporter->FatalError("Failed to register pktsrc fd with iosource_mgr");
+		}
 
 	DBG_LOG(DBG_PKTIO, "Opened source %s", props.path.c_str());
 	}
@@ -98,7 +102,7 @@ void PktSrc::Closed()
 	{
 	SetClosed(true);
 
-	if ( props.selectable_fd != -1 )
+	if ( props.is_live && props.selectable_fd != -1 )
 		iosource_mgr->UnregisterFd(props.selectable_fd, this);
 
 	DBG_LOG(DBG_PKTIO, "Closed source %s", props.path.c_str());
@@ -175,8 +179,6 @@ bool PktSrc::ExtractNextPacketInternal()
 
 	if ( ExtractNextPacket(&current_packet) )
 		{
-		had_packet = true;
-
 		if ( current_packet.time < 0 )
 			{
 			Weird("negative_packet_timestamp", &current_packet);
@@ -189,10 +191,6 @@ bool PktSrc::ExtractNextPacketInternal()
 		have_packet = true;
 		return true;
 		}
-	else
-		{
-		had_packet = false;
-		}
 
 	if ( run_state::pseudo_realtime && ! IsOpen() )
 		{
@@ -280,41 +278,39 @@ bool PktSrc::GetCurrentPacket(const Packet** pkt)
 
 double PktSrc::GetNextTimeout()
 	{
+	bool pkt_available = have_packet;
+
+	if ( props.selectable_fd == -1 || run_state::pseudo_realtime )
+		pkt_available = ExtractNextPacketInternal();
+
 	if ( run_state::is_processing_suspended() )
 		return -1;
 
-	// If we're in pseudo-realtime mode, find the next time that a packet is ready
-	// and have poll block until then.
-	if ( run_state::pseudo_realtime )
-		{
-		ExtractNextPacketInternal();
-
-		// This duplicates the calculation used in run_state::check_pseudo_time().
-		double pseudo_time = current_packet.time - run_state::detail::first_timestamp;
-		double ct = (util::current_time(true) - run_state::detail::first_wallclock) *
-		            run_state::pseudo_realtime;
-		return std::max(0.0, pseudo_time - ct);
-		}
-
-	// If there's no file descriptor for the source, which is the case for some interfaces
-	// like myricom, we can't rely on the polling mechanism to wait for data to be
-	// available. As gross as it is, just spin with a short timeout here so that it will
-	// continually poll the interface. The old IOSource code had a 20 microsecond timeout
-	// between calls to select() so just use that.
-
-	// A heuristic to avoid short sleeps when a non-selectable packet source has more
-	// packets queued is to return 0.0 if the source has yielded a packet on the
-	// last call to ExtractNextPacket().
+	// If there's no file descriptor for the source, which is the case for some interfaces like
+	// myricom, we can't rely on the polling mechanism to wait for data to be available. As gross
+	// as it is, just spin with a short timeout here so that it will continually poll the
+	// interface. The old IOSource code had a 20 microsecond timeout between calls to select()
+	// so just use that.
 	if ( props.selectable_fd == -1 )
 		{
-		if ( have_packet || had_packet )
-			return 0.0;
-
-		return BifConst::Pcap::non_fd_timeout;
+		if ( ! pkt_available && ! run_state::pseudo_realtime )
+			return 0.00002;
 		}
+	// If we're live we want poll to do what it has to with the file descriptor. If we're not live
+	// but we're not in pseudo-realtime mode, let the loop just spin as fast as it can. If we're
+	// in pseudo-realtime mode, find the next time that a packet is ready and have poll block until
+	// then.
+	else if ( IsLive() )
+		return -1;
 
-	// If there's an FD (offline or live) we want poll to do what it has to with it.
-	return -1.0;
+	if ( ! run_state::pseudo_realtime )
+		return 0;
+
+	// This duplicates the calculation used in run_state::check_pseudo_time().
+	double pseudo_time = current_packet.time - run_state::detail::first_timestamp;
+	double ct = (util::current_time(true) - run_state::detail::first_wallclock) *
+	            run_state::pseudo_realtime;
+	return std::max(0.0, pseudo_time - ct);
 	}
 
 	} // namespace zeek::iosource
