@@ -889,7 +889,7 @@ bool Manager::Write(EnumVal* id, RecordVal* columns_arg)
 			for ( const auto& fcte : *filter_config_table )
 				{
 				auto k = fcte.GetHashKey();
-				auto* v = fcte.GetValue<TableEntryVal*>();
+				auto* v = fcte.value;
 
 				auto index = filter->config->RecreateIndex(*k);
 				string key = index->Idx(0)->AsString()->CheckString();
@@ -1041,7 +1041,7 @@ threading::Value* Manager::ValToLogVal(Val* val, Type* ty)
 			lval->val.set_val.size = set->Length();
 			lval->val.set_val.vals = new threading::Value*[lval->val.set_val.size];
 
-			for ( bro_int_t i = 0; i < lval->val.set_val.size; i++ )
+			for ( zeek_int_t i = 0; i < lval->val.set_val.size; i++ )
 				lval->val.set_val.vals[i] = ValToLogVal(set->Idx(i).get());
 
 			break;
@@ -1053,7 +1053,7 @@ threading::Value* Manager::ValToLogVal(Val* val, Type* ty)
 			lval->val.vector_val.size = vec->Size();
 			lval->val.vector_val.vals = new threading::Value*[lval->val.vector_val.size];
 
-			for ( bro_int_t i = 0; i < lval->val.vector_val.size; i++ )
+			for ( zeek_int_t i = 0; i < lval->val.vector_val.size; i++ )
 				{
 				lval->val.vector_val.vals[i] = ValToLogVal(vec->ValAt(i).get(),
 				                                           vec->GetType()->Yield().get());
@@ -1529,6 +1529,13 @@ std::string Manager::FormatRotationPath(EnumValPtr writer, std::string_view path
 		auto prefix = rp_val->GetFieldAs<StringVal>(1)->CheckString();
 		auto dir = dir_val->AsString()->CheckString();
 
+		// If rotation_format_func returned an empty dir in RotationPath
+		// and Log::default_logdir is set, use it so that rotation is
+		// confined within it.
+		auto default_logdir = zeek::id::find_const<StringVal>("Log::default_logdir")->ToStdString();
+		if ( util::streq(dir, "") && ! default_logdir.empty() )
+			dir = default_logdir.c_str();
+
 		if ( ! util::streq(dir, "") && ! util::detail::ensure_intermediate_dirs(dir) )
 			{
 			reporter->Error("Failed to create dir '%s' returned by "
