@@ -4,12 +4,13 @@
 
 #include "zeek/zeek-config.h"
 
-#include <errno.h>
+#include <cerrno>
 #include <string>
 #include <vector>
 
 #include "zeek/logging/writers/sqlite/sqlite.bif.h"
 #include "zeek/threading/SerialTypes.h"
+#include "zeek/util.h"
 
 using namespace std;
 using zeek::threading::Field;
@@ -128,8 +129,11 @@ bool SQLite::DoInit(const WriterInfo& info, int arg_num_fields, const Field* con
 	num_fields = arg_num_fields;
 	fields = arg_fields;
 
-	string fullpath(info.path);
-	fullpath.append(".sqlite");
+	auto fullpath = zeek::filesystem::path(
+		zeek::id::find_const<StringVal>("Log::default_logdir")->ToStdString());
+
+	fullpath /= info.path;
+	fullpath += ".sqlite";
 	string tablename;
 
 	WriterInfo::config_map::const_iterator it = info.config.find("tablename");
@@ -292,7 +296,7 @@ int SQLite::AddParams(Value* val, int pos)
 			if ( ! val->val.set_val.size )
 				desc.Add(empty_field);
 			else
-				for ( bro_int_t j = 0; j < val->val.set_val.size; j++ )
+				for ( zeek_int_t j = 0; j < val->val.set_val.size; j++ )
 					{
 					if ( j > 0 )
 						desc.AddRaw(set_separator);
@@ -315,7 +319,7 @@ int SQLite::AddParams(Value* val, int pos)
 			if ( ! val->val.vector_val.size )
 				desc.Add(empty_field);
 			else
-				for ( bro_int_t j = 0; j < val->val.vector_val.size; j++ )
+				for ( zeek_int_t j = 0; j < val->val.vector_val.size; j++ )
 					{
 					if ( j > 0 )
 						desc.AddRaw(set_separator);
