@@ -4,10 +4,7 @@
 
 using namespace zeek::packet_analysis::Null;
 
-NullAnalyzer::NullAnalyzer()
-	: zeek::packet_analysis::Analyzer("Null")
-	{
-	}
+NullAnalyzer::NullAnalyzer() : zeek::packet_analysis::Analyzer("Null") { }
 
 bool NullAnalyzer::AnalyzePacket(size_t len, const uint8_t* data, Packet* packet)
 	{
