@@ -125,7 +125,7 @@ void TCPAnalyzer::DeliverPacket(Connection* c, double t, bool is_orig, int remai
 	pkt->session = c;
 
 	// Send the packet back into the packet analysis framework.
-	ForwardPacket(std::min(len, remaining), data, pkt);
+	ForwardPacket(len, data, pkt);
 
 	// Call DeliverPacket on the adapter directly here. Normally we'd call ForwardPacket
 	// but this adapter does some other things in its DeliverPacket with the packet children
@@ -163,7 +163,7 @@ bool TCPAnalyzer::ValidateChecksum(const IP_Hdr* ip, const struct tcphdr* tp,
                                    analyzer::tcp::TCP_Endpoint* endpoint, int len, int caplen,
                                    TCPSessionAdapter* adapter)
 	{
-	if ( ! run_state::current_pkt->l3_checksummed && ! detail::ignore_checksums &&
+	if ( ! run_state::current_pkt->l4_checksummed && ! detail::ignore_checksums &&
 	     ! GetIgnoreChecksumsNets()->Contains(ip->IPHeaderSrcAddr()) && caplen >= len &&
 	     ! endpoint->ValidChecksum(tp, len, ip->IP4_Hdr()) )
 		{
