@@ -77,7 +77,7 @@ void TCPSessionAdapter::Done()
 	finished = 1;
 	}
 
-int TCPSessionAdapter::get_segment_len(int payload_len, analyzer::tcp::TCP_Flags flags)
+static int get_segment_len(int payload_len, analyzer::tcp::TCP_Flags flags)
 	{
 	int seg_len = payload_len;
 
@@ -175,9 +175,8 @@ static void init_endpoint(analyzer::tcp::TCP_Endpoint* endpoint, analyzer::tcp::
 		}
 	}
 
-uint64_t TCPSessionAdapter::get_relative_seq(const analyzer::tcp::TCP_Endpoint* endpoint,
-                                             uint32_t cur_base, uint32_t last, uint32_t wraps,
-                                             bool* underflow)
+static uint64_t get_relative_seq(const analyzer::tcp::TCP_Endpoint* endpoint, uint32_t cur_base,
+                                 uint32_t last, uint32_t wraps, bool* underflow)
 	{
 	int32_t delta = seq_delta(cur_base, last);
 
@@ -430,7 +429,7 @@ static zeek::RecordValPtr build_syn_packet_val(bool is_orig, const zeek::IP_Hdr*
 	}
 
 static void init_window(analyzer::tcp::TCP_Endpoint* endpoint, analyzer::tcp::TCP_Endpoint* peer,
-                        analyzer::tcp::TCP_Flags flags, bro_int_t scale, uint32_t base_seq,
+                        analyzer::tcp::TCP_Flags flags, zeek_int_t scale, uint32_t base_seq,
                         uint32_t ack_seq)
 	{
 	// ### In the following, we could be fooled by an
@@ -1804,6 +1803,51 @@ int TCPSessionAdapter::ParseTCPOptions(const struct tcphdr* tcp, bool is_orig)
 						}
 					break;
 
+				case 27:
+					// TCP Quick Start Response
+					if ( length == 8 )
+						{
+						auto rate = o[2];
+						auto ttl_diff = o[3];
+						auto qs_nonce = ntohl(*reinterpret_cast<const uint32_t*>(o + 4));
+						option_record->Assign(8, rate);
+						option_record->Assign(9, ttl_diff);
+						option_record->Assign(10, qs_nonce);
+						}
+					else
+						{
+						add_option_data(option_record, o, length);
+						Weird("tcp_option_qsresponse_invalid_len", util::fmt("%d", length));
+						}
+					break;
+
+				case 28:
+					// TCP User Timeout option UTO
+					if ( length != 4 )
+						{
+						add_option_data(option_record, o, length);
+						Weird("tcp_option_uto_invalid_len", util::fmt("%d", length));
+						}
+					break;
+
+				case 29:
+					// TCP Auth Option AO
+					if ( length < 4 )
+						{
+						add_option_data(option_record, o, length);
+						Weird("tcp_option_ao_invalid_len", util::fmt("%d", length));
+						}
+					break;
+
+				case 34:
+					// TCP Fast open TFO
+					if ( (length != 2) && (length < 6 || length > 18) )
+						{
+						add_option_data(option_record, o, length);
+						Weird("tcp_option_tfo_invalid_len", util::fmt("%d", length));
+						}
+					break;
+
 				default:
 					add_option_data(option_record, o, length);
 					break;
