@@ -4,10 +4,10 @@
 
 #include <dirent.h>
 #include <dlfcn.h>
-#include <errno.h>
 #include <glob.h>
-#include <limits.h> // for PATH_MAX
 #include <sys/stat.h>
+#include <cerrno>
+#include <climits> // for PATH_MAX
 #include <cstdlib>
 #include <fstream>
 #include <optional>
@@ -669,6 +669,11 @@ void Manager::RequestBroObjDtor(Obj* obj, Plugin* plugin)
 	obj->NotifyPluginsOnDtor();
 	}
 
+void Manager::RequestObjDtor(Obj* obj, Plugin* plugin)
+	{
+	obj->NotifyPluginsOnDtor();
+	}
+
 int Manager::HookLoadFile(const Plugin::LoadType type, const string& file, const string& resolved)
 	{
 	HookArgumentList args;
@@ -889,20 +894,55 @@ void Manager::HookBroObjDtor(void* obj) const
 	if ( HavePluginForHook(META_HOOK_PRE) )
 		{
 		args.push_back(HookArgument(obj));
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 		MetaHookPre(HOOK_BRO_OBJ_DTOR, args);
+#pragma GCC diagnostic pop
 		}
 
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 	hook_list* l = hooks[HOOK_BRO_OBJ_DTOR];
+#pragma GCC diagnostic pop
 
 	if ( l )
 		for ( hook_list::iterator i = l->begin(); i != l->end(); ++i )
 			{
 			Plugin* p = (*i).second;
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 			p->HookBroObjDtor(obj);
+#pragma GCC diagnostic pop
 			}
 
 	if ( HavePluginForHook(META_HOOK_POST) )
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 		MetaHookPost(HOOK_BRO_OBJ_DTOR, args, HookArgument());
+#pragma GCC diagnostic pop
+	}
+
+void Manager::HookObjDtor(void* obj) const
+	{
+	HookArgumentList args;
+
+	if ( HavePluginForHook(META_HOOK_PRE) )
+		{
+		args.push_back(HookArgument(obj));
+		MetaHookPre(HOOK_OBJ_DTOR, args);
+		}
+
+	hook_list* l = hooks[HOOK_OBJ_DTOR];
+
+	if ( l )
+		for ( hook_list::iterator i = l->begin(); i != l->end(); ++i )
+			{
+			Plugin* p = (*i).second;
+			p->HookObjDtor(obj);
+			}
+
+	if ( HavePluginForHook(META_HOOK_POST) )
+		MetaHookPost(HOOK_OBJ_DTOR, args, HookArgument());
 	}
 
 void Manager::HookLogInit(const std::string& writer, const std::string& instantiating_filter,
