@@ -142,6 +142,24 @@ CounterVector& CounterVector::Merge(const CounterVector& other)
 	return *this;
 	}
 
+BitVector CounterVector::ToBitVector() const
+	{
+	auto newbits = BitVector(Size());
+
+	for ( size_t cell = 0; cell < Size(); ++cell )
+		{
+		size_t lsb = cell * width;
+		bool set = false;
+
+		for ( size_t i = 0; i < width; ++i )
+			set |= (*bits)[lsb + 1];
+
+		newbits[cell] = set;
+		}
+
+	return newbits;
+	}
+
 CounterVector& CounterVector::operator|=(const CounterVector& other)
 	{
 	return Merge(other);
@@ -169,11 +187,11 @@ broker::expected<broker::data> CounterVector::Serialize() const
 
 std::unique_ptr<CounterVector> CounterVector::Unserialize(const broker::data& data)
 	{
-	auto v = caf::get_if<broker::vector>(&data);
+	auto v = broker::get_if<broker::vector>(&data);
 	if ( ! (v && v->size() >= 2) )
 		return nullptr;
 
-	auto width = caf::get_if<uint64_t>(&(*v)[0]);
+	auto width = broker::get_if<uint64_t>(&(*v)[0]);
 	auto bits = BitVector::Unserialize((*v)[1]);
 
 	if ( ! (width && bits) )
