@@ -32,7 +32,7 @@
 // find optimization opportunities, including inlining.
 //
 // For some Zeek scripting types, we use their natural C++ counterparts,
-// such as "bro_uint_t" for "count" values.  In the source code these
+// such as "zeek_uint_t" for "count" values.  In the source code these
 // are referred to as "native" types.  Other types, like tables, keep
 // their interpreter-equivalent type (e.g., TableVal).  These are dealt
 // with almost entirely using IntrusivePtr's.  The few exceptions (i.e.,
@@ -435,7 +435,7 @@ private:
 	std::unordered_map<std::string, std::string> events;
 
 	// Globals that correspond to variables, not functions.
-	std::unordered_set<const ID*> global_vars;
+	IDSet global_vars;
 
 	//
 	// End of methods related to script/C++ variables.
@@ -539,7 +539,7 @@ private:
 	std::unordered_map<const ID*, std::string> lambda_names;
 
 	// The function's parameters.  Tracked so we don't re-declare them.
-	std::unordered_set<const ID*> params;
+	IDSet params;
 
 	// Whether we're compiling a hook.
 	bool in_hook = false;
@@ -718,11 +718,16 @@ private:
 	void GenAddStmt(const ExprStmt* es);
 	void GenDeleteStmt(const ExprStmt* es);
 	void GenEventStmt(const EventStmt* ev);
-	void GenSwitchStmt(const SwitchStmt* sw);
 
+	void GenSwitchStmt(const SwitchStmt* sw);
+	void GenTypeSwitchStmt(const Expr* e, const case_list* cases);
+	void GenTypeSwitchCase(const ID* id, int case_offset, bool is_multi);
+	void GenValueSwitchStmt(const Expr* e, const case_list* cases);
+
+	void GenWhenStmt(const WhenStmt* w);
 	void GenForStmt(const ForStmt* f);
 	void GenForOverTable(const ExprPtr& tbl, const IDPtr& value_var, const IDPList* loop_vars);
-	void GenForOverVector(const ExprPtr& tbl, const IDPList* loop_vars);
+	void GenForOverVector(const ExprPtr& tbl, const IDPtr& value_var, const IDPList* loop_vars);
 	void GenForOverString(const ExprPtr& str, const IDPList* loop_vars);
 
 	// Nested level of loops/switches for which "break"'s should be
@@ -788,6 +793,7 @@ private:
 	std::string GenIndexExpr(const Expr* e, GenType gt);
 	std::string GenAssignExpr(const Expr* e, GenType gt, bool top_level);
 	std::string GenAddToExpr(const Expr* e, GenType gt, bool top_level);
+	std::string GenRemoveFromExpr(const Expr* e, GenType gt, bool top_level);
 	std::string GenSizeExpr(const Expr* e, GenType gt);
 	std::string GenScheduleExpr(const Expr* e);
 	std::string GenLambdaExpr(const Expr* e);
@@ -893,7 +899,7 @@ private:
 	//
 
 	// "Native" types are those Zeek scripting types that we support
-	// using low-level C++ types (like "bro_uint_t" for "count").
+	// using low-level C++ types (like "zeek_uint_t" for "count").
 	// Types that we instead support using some form of ValPtr
 	// representation are "non-native".
 	bool IsNativeType(const TypePtr& t) const;
