@@ -89,6 +89,10 @@ string CPPCompile::GenExpr(const Expr* e, GenType gt, bool top_level)
 			return GenBinary(e, gt, "|", "or");
 		case EXPR_XOR:
 			return GenBinary(e, gt, "^", "xor");
+		case EXPR_LSHIFT:
+			return GenBinary(e, gt, "<<", "lshift");
+		case EXPR_RSHIFT:
+			return GenBinary(e, gt, ">>", "rshift");
 		case EXPR_AND_AND:
 			return GenBinary(e, gt, "&&", "andand");
 		case EXPR_OR_OR:
@@ -666,10 +670,10 @@ string CPPCompile::GenArithCoerceExpr(const Expr* e, GenType gt)
 	switch ( t->InternalType() )
 		{
 		case TYPE_INTERNAL_INT:
-			cast_name = "bro_int_t";
+			cast_name = "zeek_int_t";
 			break;
 		case TYPE_INTERNAL_UNSIGNED:
-			cast_name = "bro_uint_t";
+			cast_name = "zeek_uint_t";
 			break;
 		case TYPE_INTERNAL_DOUBLE:
 			cast_name = "double";
