@@ -33,6 +33,14 @@ extern ValPtr index_table__CPP(const TableValPtr& t, std::vector<ValPtr> indices
 extern ValPtr index_vec__CPP(const VectorValPtr& vec, int index);
 extern ValPtr index_string__CPP(const StringValPtr& svp, std::vector<ValPtr> indices);
 
+// The same, but for indexing happening inside a "when" clause.
+extern ValPtr when_index_table__CPP(const TableValPtr& t, std::vector<ValPtr> indices);
+extern ValPtr when_index_vec__CPP(const VectorValPtr& vec, int index);
+
+// For vector slices, we use the existing index_slice(), but we need a
+// custom one for those occurring inside a "when" clause.
+extern ValPtr when_index_slice__CPP(VectorVal* vec, const ListVal* lv);
+
 // Calls out to the given script or BiF function.  A separate function because
 // of the need to (1) construct the "args" vector using {} initializers,
 // but (2) needing to have the address of that vector.
@@ -41,6 +49,18 @@ inline ValPtr invoke__CPP(Func* f, std::vector<ValPtr> args, Frame* frame)
 	return f->Invoke(&args, frame);
 	}
 
+// The same, but raises an interpreter exception if the function does
+// not return a value.  Used for calls inside "when" conditions.  The
+// last argument is the address of the calling function; we just need
+// it to be distinct to the call, so we can associate a Trigger cache
+// with it.
+extern ValPtr when_invoke__CPP(Func* f, std::vector<ValPtr> args, Frame* frame, void* caller_addr);
+
+// Thrown when a call inside a "when" delays.
+class DelayedCallException : public InterpreterException
+	{
+	};
+
 // Assigns the given value to the given global.  A separate function because
 // we also need to return the value, for use in assignment cascades.
 inline ValPtr set_global__CPP(IDPtr g, ValPtr v)
@@ -113,6 +133,21 @@ inline TableValPtr table_coerce__CPP(const ValPtr& v, const TypePtr& t)
 	return make_intrusive<TableVal>(cast_intrusive<TableType>(t), tv->GetAttrs());
 	}
 
+// For tables, executes t1 += t2.
+inline TableValPtr table_append__CPP(const TableValPtr& t1, const TableValPtr& t2)
+	{
+	t2->AddTo(t1.get(), false);
+	return t1;
+	}
+
+// For tables, executes t1 -= t2.
+inline TableValPtr table_remove_from__CPP(const TableValPtr& t1, const TableValPtr& t2)
+	{
+	if ( t2->Size() > 0 )
+		t2->RemoveFrom(t1.get());
+	return t1;
+	}
+
 // The same, for an empty record.
 inline VectorValPtr vector_coerce__CPP(const ValPtr& v, const TypePtr& t)
 	{
@@ -147,13 +182,20 @@ extern RecordValPtr record_constructor_map__CPP(std::vector<ValPtr> vals, std::v
 // Constructs a vector of the given type, populated with the given values.
 extern VectorValPtr vector_constructor__CPP(std::vector<ValPtr> vals, VectorTypePtr t);
 
+// For patterns, executes p1 += p2.
+inline PatternValPtr re_append__CPP(const PatternValPtr& p1, const PatternValPtr& p2)
+	{
+	p2->AddTo(p1.get(), false);
+	return p1;
+	}
+
 // Schedules an event to occur at the given absolute time, parameterized
 // with the given set of values.  A separate function to facilitate avoiding
 // the scheduling if Zeek is terminating.
 extern ValPtr schedule__CPP(double dt, EventHandlerPtr event, std::vector<ValPtr> args);
 
 // Simple helper functions for supporting absolute value.
-inline bro_uint_t iabs__CPP(bro_int_t v)
+inline zeek_uint_t iabs__CPP(zeek_int_t v)
 	{
 	return v < 0 ? -v : v;
 	}
@@ -165,28 +207,28 @@ inline double fabs__CPP(double v)
 
 // The following operations are provided using functions to support
 // error checking/reporting.
-inline bro_int_t idiv__CPP(bro_int_t v1, bro_int_t v2)
+inline zeek_int_t idiv__CPP(zeek_int_t v1, zeek_int_t v2)
 	{
 	if ( v2 == 0 )
 		reporter->CPPRuntimeError("division by zero");
 	return v1 / v2;
 	}
 
-inline bro_int_t imod__CPP(bro_int_t v1, bro_int_t v2)
+inline zeek_int_t imod__CPP(zeek_int_t v1, zeek_int_t v2)
 	{
 	if ( v2 == 0 )
 		reporter->CPPRuntimeError("modulo by zero");
 	return v1 % v2;
 	}
 
-inline bro_uint_t udiv__CPP(bro_uint_t v1, bro_uint_t v2)
+inline zeek_uint_t udiv__CPP(zeek_uint_t v1, zeek_uint_t v2)
 	{
 	if ( v2 == 0 )
 		reporter->CPPRuntimeError("division by zero");
 	return v1 / v2;
 	}
 
-inline bro_uint_t umod__CPP(bro_uint_t v1, bro_uint_t v2)
+inline zeek_uint_t umod__CPP(zeek_uint_t v1, zeek_uint_t v2)
 	{
 	if ( v2 == 0 )
 		reporter->CPPRuntimeError("modulo by zero");
