@@ -129,16 +129,15 @@ TraversalCode ProfileFunc::PreStmt(const Stmt* s)
 			return TC_ABORTSTMT;
 
 		case STMT_WHEN:
+			{
 			++num_when_stmts;
 
-			in_when = true;
-			s->AsWhenStmt()->Cond()->Traverse(this);
-			in_when = false;
-
-			// It doesn't do any harm for us to re-traverse the
-			// conditional, so we don't bother hand-traversing the
-			// rest of the "when", but just let the usual processing
-			// do it.
+			auto w = s->AsWhenStmt();
+			auto wi = w->Info();
+			auto wl = wi ? wi->Lambda() : nullptr;
+			if ( wl )
+				lambdas.push_back(wl.get());
+			}
 			break;
 
 		case STMT_FOR:
@@ -174,7 +173,11 @@ TraversalCode ProfileFunc::PreStmt(const Stmt* s)
 				if ( idl )
 					{
 					for ( auto id : *idl )
-						locals.insert(id);
+						// Make sure it's not a placeholder
+						// identifier, used when there's
+						// no explicit one.
+						if ( id->Name() )
+							locals.insert(id);
 
 					is_type_switch = true;
 					}
@@ -279,13 +282,26 @@ TraversalCode ProfileFunc::PreExpr(const Expr* e)
 		case EXPR_REMOVE_FROM:
 		case EXPR_ASSIGN:
 			{
-			if ( e->GetOp1()->Tag() == EXPR_REF )
+			if ( e->GetOp1()->Tag() != EXPR_REF )
+				// this isn't a direct assignment
+				break;
+
+			auto lhs = e->GetOp1()->GetOp1();
+			if ( lhs->Tag() != EXPR_NAME )
+				break;
+
+			auto id = lhs->AsNameExpr()->Id();
+			TrackAssignment(id);
+
+			if ( e->Tag() == EXPR_ASSIGN )
 				{
-				auto lhs = e->GetOp1()->GetOp1();
-				if ( lhs->Tag() == EXPR_NAME )
-					TrackAssignment(lhs->AsNameExpr()->Id());
+				auto a_e = static_cast<const AssignExpr*>(e);
+				auto& av = a_e->AssignVal();
+				if ( av )
+					// This is a funky "local" assignment
+					// inside a when clause.
+					when_locals.insert(id);
 				}
-			// else this isn't a direct assignment.
 			break;
 			}
 
@@ -320,9 +336,6 @@ TraversalCode ProfileFunc::PreExpr(const Expr* e)
 					{
 					auto bf = static_cast<ScriptFunc*>(func_vf);
 					script_calls.insert(bf);
-
-					if ( in_when )
-						when_calls.insert(bf);
 					}
 				else
 					BiF_globals.insert(func);
@@ -571,8 +584,6 @@ void ProfileFuncs::TraverseValue(const ValPtr& v)
 		case TYPE_STRING:
 		case TYPE_SUBNET:
 		case TYPE_TIME:
-		case TYPE_TIMER:
-		case TYPE_UNION:
 		case TYPE_VOID:
 			break;
 
@@ -772,8 +783,6 @@ p_hash_type ProfileFuncs::HashType(const Type* t)
 		case TYPE_STRING:
 		case TYPE_SUBNET:
 		case TYPE_TIME:
-		case TYPE_TIMER:
-		case TYPE_UNION:
 		case TYPE_VOID:
 			h = merge_p_hashes(h, p_hash(t));
 			break;
