@@ -14,6 +14,7 @@
 #include "zeek/script_opt/Inline.h"
 #include "zeek/script_opt/ProfileFunc.h"
 #include "zeek/script_opt/Reduce.h"
+#include "zeek/script_opt/UsageAnalyzer.h"
 #include "zeek/script_opt/UseDefs.h"
 #include "zeek/script_opt/ZAM/Compile.h"
 
@@ -286,9 +287,6 @@ static void init_options()
 	if ( analysis_options.use_CPP && generating_CPP )
 		reporter->FatalError("generating C++ incompatible with using C++");
 
-	if ( analysis_options.use_CPP && ! CPP_init_hook )
-		reporter->FatalError("no C++ functions available to use");
-
 	auto usage = getenv("ZEEK_USAGE_ISSUES");
 
 	if ( usage )
@@ -296,14 +294,14 @@ static void init_options()
 
 	if ( analysis_options.only_funcs.empty() )
 		{
-		auto zo = getenv("ZEEK_FUNC_ONLY");
+		auto zo = getenv("ZEEK_OPT_FUNCS");
 		if ( zo )
 			add_func_analysis_pattern(analysis_options, zo);
 		}
 
 	if ( analysis_options.only_files.empty() )
 		{
-		auto zo = getenv("ZEEK_FILE_ONLY");
+		auto zo = getenv("ZEEK_OPT_FILES");
 		if ( zo )
 			add_file_analysis_pattern(analysis_options, zo);
 		}
@@ -336,10 +334,7 @@ static void init_options()
 static void report_CPP()
 	{
 	if ( ! CPP_init_hook )
-		{
-		printf("no C++ script bodies available\n");
-		exit(0);
-		}
+		reporter->FatalError("no C++ script bodies available");
 
 	printf("C++ script bodies available that match loaded scripts:\n");
 
@@ -373,6 +368,11 @@ static void report_CPP()
 
 static void use_CPP()
 	{
+	if ( ! CPP_init_hook )
+		reporter->FatalError("no C++ functions available to use");
+
+	int num_used = 0;
+
 	for ( auto& f : funcs )
 		{
 		auto hash = f.Profile()->HashVal();
@@ -380,6 +380,8 @@ static void use_CPP()
 
 		if ( s != compiled_scripts.end() )
 			{
+			++num_used;
+
 			auto b = s->second.body;
 			b->SetHash(hash);
 
@@ -410,6 +412,9 @@ static void use_CPP()
 			}
 		}
 
+	if ( num_used == 0 )
+		reporter->FatalError("no C++ functions found to use");
+
 	// Now that we've loaded all of the compiled scripts
 	// relevant for the AST, activate standalone ones.
 	for ( auto cb : standalone_activations )
@@ -515,7 +520,7 @@ static void analyze_scripts_for_ZAM(std::unique_ptr<ProfileFuncs>& pfs)
 	finalize_functions(funcs);
 	}
 
-void analyze_scripts()
+void analyze_scripts(bool no_unused_warnings)
 	{
 	static bool did_init = false;
 
@@ -525,6 +530,10 @@ void analyze_scripts()
 		did_init = true;
 		}
 
+	std::unique_ptr<UsageAnalyzer> ua;
+	if ( ! no_unused_warnings )
+		ua = std::make_unique<UsageAnalyzer>(funcs);
+
 	auto& ofuncs = analysis_options.only_funcs;
 	auto& ofiles = analysis_options.only_files;
 
@@ -555,7 +564,14 @@ void analyze_scripts()
 	auto pfs = std::make_unique<ProfileFuncs>(funcs, is_CPP_compilable, false);
 
 	if ( CPP_init_hook )
+		{
 		(*CPP_init_hook)();
+		if ( compiled_scripts.empty() )
+			// The initialization failed to produce any
+			// script bodies.  Make this easily available
+			// to subsequent checks.
+			CPP_init_hook = nullptr;
+		}
 
 	if ( analysis_options.report_CPP )
 		{
@@ -580,4 +596,23 @@ void analyze_scripts()
 	analyze_scripts_for_ZAM(pfs);
 	}
 
+void profile_script_execution()
+	{
+	if ( analysis_options.profile_ZAM )
+		{
+		report_ZOP_profile();
+
+		for ( auto& f : funcs )
+			{
+			if ( f.Body()->Tag() == STMT_ZAM )
+				cast_intrusive<ZBody>(f.Body())->ProfileExecution();
+			}
+		}
+	}
+
+void finish_script_execution()
+	{
+	profile_script_execution();
+	}
+
 	} // namespace zeek::detail
