@@ -624,7 +624,7 @@ StmtPtr ForStmt::DoReduce(Reducer* c)
 	body = body->Reduce(c);
 
 	if ( body->Tag() == STMT_NULL )
-		Error("empty \"for\" body leaves loop variables in indeterminant state");
+		Warn("empty \"for\" body leaves loop variables in indeterminant state");
 
 	if ( red_e_stmt )
 		return TransformMe(make_intrusive<StmtList>(red_e_stmt, this), c);
@@ -895,7 +895,7 @@ StmtPtr InitStmt::Duplicate()
 	// Need to duplicate the initializer list since later reductions
 	// can modify it in place.
 	std::vector<IDPtr> new_inits;
-	for ( auto id : inits )
+	for ( const auto& id : inits )
 		new_inits.push_back(id);
 
 	return SetSucc(new InitStmt(new_inits));
