@@ -400,6 +400,16 @@ void ZAMCompiler::ComputeFrameLifetimes()
 				}
 				break;
 
+			case OP_NEXT_VECTOR_ITER_VAL_VAR_VVVV:
+				{
+				CheckSlotAssignment(inst->v2, inst);
+
+				auto depth = inst->loop_depth;
+				ExtendLifetime(inst->v1, EndOfLoop(inst, depth));
+				ExtendLifetime(inst->v2, EndOfLoop(inst, depth));
+				}
+				break;
+
 			case OP_NEXT_VECTOR_ITER_VVV:
 			case OP_NEXT_STRING_ITER_VVV:
 				// Sometimes loops are written that don't actually
@@ -478,7 +488,7 @@ void ZAMCompiler::ReMapFrame()
 	frame1_to_frame2.resize(frame_layout1.size(), -1);
 	managed_slotsI.clear();
 
-	for ( bro_uint_t i = 0; i < insts1.size(); ++i )
+	for ( zeek_uint_t i = 0; i < insts1.size(); ++i )
 		{
 		auto inst = insts1[i];
 
@@ -655,7 +665,7 @@ void ZAMCompiler::ReMapInterpreterFrame()
 		remapped_intrp_frame_sizes[func] = next_interp_slot;
 	}
 
-void ZAMCompiler::ReMapVar(const ID* id, int slot, bro_uint_t inst)
+void ZAMCompiler::ReMapVar(const ID* id, int slot, zeek_uint_t inst)
 	{
 	// A greedy algorithm for this is to simply find the first suitable
 	// frame slot.  We do that with one twist: we also look for a
@@ -731,7 +741,7 @@ void ZAMCompiler::ReMapVar(const ID* id, int slot, bro_uint_t inst)
 
 void ZAMCompiler::CheckSlotAssignment(int slot, const ZInstI* inst)
 	{
-	ASSERT(slot >= 0 && static_cast<bro_uint_t>(slot) < frame_denizens.size());
+	ASSERT(slot >= 0 && static_cast<zeek_uint_t>(slot) < frame_denizens.size());
 
 	// We construct temporaries such that their values are never used
 	// earlier than their definitions in loop bodies.  For other
@@ -770,7 +780,7 @@ void ZAMCompiler::CheckSlotUse(int slot, const ZInstI* inst)
 	if ( slot < 0 )
 		return;
 
-	ASSERT(static_cast<bro_uint_t>(slot) < frame_denizens.size());
+	ASSERT(static_cast<zeek_uint_t>(slot) < frame_denizens.size());
 
 	if ( denizen_beginning.count(slot) == 0 )
 		{
@@ -800,16 +810,9 @@ void ZAMCompiler::CheckSlotUse(int slot, const ZInstI* inst)
 
 void ZAMCompiler::ExtendLifetime(int slot, const ZInstI* inst)
 	{
-	// When using old-style lambda closure semantics, a function that
-	// returns a lambda needs to stick around for calls to that lambda.
-	// We ensure that by extending its lifetime to the end of this
-	// function.
 	auto id = frame_denizens[slot];
 	auto& t = id->GetType();
 
-	if ( t->Tag() == TYPE_FUNC && t->Yield() && t->Yield()->Tag() == TYPE_FUNC )
-		inst = insts1.back();
-
 	if ( denizen_ending.count(slot) > 0 )
 		{
 		// End of denizen's lifetime already seen.  Check for
@@ -923,6 +926,9 @@ bool ZAMCompiler::VarIsAssigned(int slot, const ZInstI* i) const
 		// *does* also assign to slot 1.
 		}
 
+	if ( i->op == OP_NEXT_VECTOR_ITER_VAL_VAR_VVVV && i->v2 == slot )
+		return true;
+
 	if ( i->op_type == OP_VV_FRAME )
 		// We don't want to consider these as assigning to the
 		// variable, since the point of this method is to figure
@@ -964,9 +970,9 @@ ZInstI* ZAMCompiler::FirstLiveInst(ZInstI* i, bool follow_gotos)
 		return nullptr;
 	}
 
-bro_uint_t ZAMCompiler::FirstLiveInst(bro_uint_t i, bool follow_gotos)
+zeek_uint_t ZAMCompiler::FirstLiveInst(zeek_uint_t i, bool follow_gotos)
 	{
-	bro_uint_t num_inspected = 0;
+	zeek_uint_t num_inspected = 0;
 	while ( i < insts1.size() )
 		{
 		auto i0 = insts1[i];
@@ -994,7 +1000,7 @@ bro_uint_t ZAMCompiler::FirstLiveInst(bro_uint_t i, bool follow_gotos)
 	return i;
 	}
 
-void ZAMCompiler::KillInst(bro_uint_t i)
+void ZAMCompiler::KillInst(zeek_uint_t i)
 	{
 	auto inst = insts1[i];
 
@@ -1049,7 +1055,7 @@ void ZAMCompiler::KillInst(bro_uint_t i)
 		}
 	}
 
-void ZAMCompiler::KillInsts(bro_uint_t i)
+void ZAMCompiler::KillInsts(zeek_uint_t i)
 	{
 	auto inst = insts1[i];
 
