@@ -76,9 +76,9 @@ public:
 
 	template <typename T> const CaseMaps<T>& GetCases() const
 		{
-		if constexpr ( std::is_same_v<T, bro_int_t> )
+		if constexpr ( std::is_same_v<T, zeek_int_t> )
 			return int_cases;
-		else if constexpr ( std::is_same_v<T, bro_uint_t> )
+		else if constexpr ( std::is_same_v<T, zeek_uint_t> )
 			return uint_cases;
 		else if constexpr ( std::is_same_v<T, double> )
 			return double_cases;
@@ -178,6 +178,8 @@ private:
 
 	const ZAMStmt CompileIncrExpr(const IncrExpr* e);
 	const ZAMStmt CompileAppendToExpr(const AppendToExpr* e);
+	const ZAMStmt CompileAddToExpr(const AddToExpr* e);
+	const ZAMStmt CompileRemoveFromExpr(const RemoveFromExpr* e);
 	const ZAMStmt CompileAssignExpr(const AssignExpr* e);
 	const ZAMStmt CompileAssignToIndex(const NameExpr* lhs, const IndexExpr* rhs);
 	const ZAMStmt CompileFieldLHSAssignExpr(const FieldLHSAssignExpr* e);
@@ -233,9 +235,6 @@ private:
 	const ZAMStmt AssignVecElems(const Expr* e);
 	const ZAMStmt AssignTableElem(const Expr* e);
 
-	const ZAMStmt AppendToField(const NameExpr* n1, const NameExpr* n2, const ConstExpr* c,
-	                            int offset);
-
 	const ZAMStmt ConstructTable(const NameExpr* n, const Expr* e);
 	const ZAMStmt ConstructSet(const NameExpr* n, const Expr* e);
 	const ZAMStmt ConstructRecord(const NameExpr* n, const Expr* e);
@@ -257,7 +256,7 @@ private:
 	// being the first argument (argument "0" in the list) and the
 	// low-ordered bit being the last.  Second parameter is the number
 	// of arguments that should be present.
-	bro_uint_t ConstArgsMask(const ExprPList& args, int nargs) const;
+	zeek_uint_t ConstArgsMask(const ExprPList& args, int nargs) const;
 
 	int ConvertToInt(const Expr* e)
 		{
@@ -349,10 +348,10 @@ private:
 
 	bool IsUnused(const IDPtr& id, const Stmt* where) const;
 
-	void LoadParam(ID* id);
-	const ZAMStmt LoadGlobal(ID* id);
+	void LoadParam(const ID* id);
+	const ZAMStmt LoadGlobal(const ID* id);
 
-	int AddToFrame(ID*);
+	int AddToFrame(const ID*);
 
 	int FrameSlot(const IDPtr& id) { return FrameSlot(id.get()); }
 	int FrameSlot(const ID* id);
@@ -420,7 +419,7 @@ private:
 
 	// Computes the remapping for a variable currently in the given slot,
 	// whose scope begins at the given instruction.
-	void ReMapVar(ID* id, int slot, bro_uint_t inst);
+	void ReMapVar(const ID* id, int slot, zeek_uint_t inst);
 
 	// Look to initialize the beginning of local lifetime based on slot
 	// assignment at instruction inst.
@@ -464,7 +463,7 @@ private:
 	// First form returns nil if there's nothing live after i.
 	// Second form returns insts1.size() in that case.
 	ZInstI* FirstLiveInst(ZInstI* i, bool follow_gotos = false);
-	bro_uint_t FirstLiveInst(bro_uint_t i, bool follow_gotos = false);
+	zeek_uint_t FirstLiveInst(zeek_uint_t i, bool follow_gotos = false);
 
 	// Same, but not including i.
 	ZInstI* NextLiveInst(ZInstI* i, bool follow_gotos = false)
@@ -483,12 +482,12 @@ private:
 	// into insts1; any labels associated with it are transferred
 	// to its next live successor, if any.
 	void KillInst(ZInstI* i) { KillInst(i->inst_num); }
-	void KillInst(bro_uint_t i);
+	void KillInst(zeek_uint_t i);
 
 	// The same, but kills any successor instructions until finding
 	// one that's labeled.
 	void KillInsts(ZInstI* i) { KillInsts(i->inst_num); }
-	void KillInsts(bro_uint_t i);
+	void KillInsts(zeek_uint_t i);
 
 	// The first of these is used as we compile down to ZInstI's.
 	// The second is the final intermediary code.  They're separate
@@ -541,7 +540,7 @@ private:
 
 	// A type for mapping an instruction to a set of locals associated
 	// with it.
-	using AssociatedLocals = std::unordered_map<const ZInstI*, std::unordered_set<ID*>>;
+	using AssociatedLocals = std::unordered_map<const ZInstI*, IDSet>;
 
 	// Maps (live) instructions to which frame denizens begin their
 	// lifetime via an initialization at that instruction, if any ...
@@ -570,8 +569,8 @@ private:
 
 	// Intermediary switch tables (branching to ZInst's rather
 	// than concrete instruction offsets).
-	CaseMapsI<bro_int_t> int_casesI;
-	CaseMapsI<bro_uint_t> uint_casesI;
+	CaseMapsI<zeek_int_t> int_casesI;
+	CaseMapsI<zeek_uint_t> uint_casesI;
 	CaseMapsI<double> double_casesI;
 
 	// Note, we use this not only for strings but for addresses
@@ -579,8 +578,8 @@ private:
 	CaseMapsI<std::string> str_casesI;
 
 	// Same, but for the concretized versions.
-	CaseMaps<bro_int_t> int_cases;
-	CaseMaps<bro_uint_t> uint_cases;
+	CaseMaps<zeek_int_t> int_cases;
+	CaseMaps<zeek_uint_t> uint_cases;
 	CaseMaps<double> double_cases;
 	CaseMaps<std::string> str_cases;
 
