@@ -227,7 +227,7 @@ const ZAMStmt ZAMCompiler::CompileAssignExpr(const AssignExpr* e)
 		return CondC2VVC(lhs, n1, c3);
 		}
 
-	if ( r1 && r2 )
+	if ( r1 && r2 && ! r3 )
 		{
 		auto v1 = IsVector(r1->GetType()->Tag());
 		auto v2 = IsVector(r2->GetType()->Tag());
@@ -641,7 +641,7 @@ const ZAMStmt ZAMCompiler::CompileIndex(const NameExpr* n1, int n2_slot, const T
 		auto var_ind = ind->Tag() == EXPR_NAME;
 		auto n3 = var_ind ? ind->AsNameExpr() : nullptr;
 		auto c3 = var_ind ? nullptr : ind->AsConstExpr();
-		bro_uint_t c = 0;
+		zeek_uint_t c = 0;
 
 		if ( ! var_ind )
 			{
