@@ -4,6 +4,8 @@
 
 #pragma once
 
+#include "zeek/Desc.h"
+#include "zeek/script_opt/ZAM/BuiltInSupport.h"
 #include "zeek/script_opt/ZAM/Support.h"
 #include "zeek/script_opt/ZAM/ZOp.h"
 
@@ -37,7 +39,7 @@ public:
 
 	// The ZAM instruction number where a given identifier starts its
 	// scope, parallel to "ids".
-	std::vector<bro_uint_t> id_start;
+	std::vector<zeek_uint_t> id_start;
 
 	// The current end of the frame slot's scope.  Gets updated as
 	// new IDs are added to share the slot.
@@ -69,7 +71,7 @@ public:
 	virtual ~ZInst() = default;
 
 	// Methods for printing out the instruction for debugging/maintenance.
-	void Dump(bro_uint_t inst_num, const FrameReMap* mappings) const;
+	void Dump(zeek_uint_t inst_num, const FrameReMap* mappings) const;
 	void Dump(const std::string& id1, const std::string& id2, const std::string& id3,
 	          const std::string& id4) const;
 
@@ -78,7 +80,7 @@ public:
 	// by its number within a larger set.  "mappings" provides the
 	// mappings used to translate raw slots to the corresponding
 	// script variable(s).
-	std::string VName(int n, bro_uint_t inst_num, const FrameReMap* mappings) const;
+	std::string VName(int n, zeek_uint_t inst_num, const FrameReMap* mappings) const;
 
 	// Number of slots that refer to a frame element.  These always
 	// come first, if we use additional slots.
@@ -222,6 +224,10 @@ public:
 	// given by slot 1 (v1).
 	bool AssignsToSlot1() const;
 
+	// True if the given instruction assigns to the frame location
+	// corresponding to the given slot.
+	bool AssignsToSlot(int slot) const;
+
 	// True if the given instruction uses the value in the given frame
 	// slot. (Assigning to the slot does not constitute using the value.)
 	bool UsesSlot(int slot) const;
@@ -315,6 +321,7 @@ public:
 		delete[] ints;
 		delete[] constants;
 		delete[] types;
+		delete[] cat_args;
 		}
 
 	// Returns the i'th element of the parallel arrays as a ValPtr.
@@ -401,6 +408,9 @@ public:
 	ValPtr* constants = nullptr;
 	TypePtr* types = nullptr;
 
+	// A parallel array for the cat() built-in replacement.
+	std::unique_ptr<CatArg>* cat_args = nullptr;
+
 	// Used for accessing function names.
 	const ID* id_val = nullptr;
 
