@@ -1,23 +1,24 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
-#include "zeek/zeek-config.h"
 #include "zeek/threading/formatters/JSON.h"
 
+#include "zeek/zeek-config.h"
+
 #ifndef __STDC_LIMIT_MACROS
 #define __STDC_LIMIT_MACROS
 #endif
 
-#include <errno.h>
-#include <math.h>
-#include <stdint.h>
-#include <sstream>
-
 #include <rapidjson/internal/ieee754.h>
+#include <cerrno>
+#include <cmath>
+#include <cstdint>
+#include <sstream>
 
 #include "zeek/Desc.h"
 #include "zeek/threading/MsgThread.h"
 
-namespace zeek::threading::formatter {
+namespace zeek::threading::formatter
+	{
 
 bool JSON::NullDoubleWriter::Double(double d)
 	{
@@ -27,17 +28,15 @@ bool JSON::NullDoubleWriter::Double(double d)
 	return rapidjson::Writer<rapidjson::StringBuffer>::Double(d);
 	}
 
-JSON::JSON(MsgThread* t, TimeFormat tf) : Formatter(t), surrounding_braces(true)
+JSON::JSON(MsgThread* t, TimeFormat tf, bool arg_include_unset_fields)
+	: Formatter(t), surrounding_braces(true), include_unset_fields(arg_include_unset_fields)
 	{
 	timestamps = tf;
 	}
 
-JSON::~JSON()
-	{
-	}
+JSON::~JSON() { }
 
-bool JSON::Describe(ODesc* desc, int num_fields, const Field* const * fields,
-                    Value** vals) const
+bool JSON::Describe(ODesc* desc, int num_fields, const Field* const* fields, Value** vals) const
 	{
 	rapidjson::StringBuffer buffer;
 	NullDoubleWriter writer(buffer);
@@ -46,7 +45,7 @@ bool JSON::Describe(ODesc* desc, int num_fields, const Field* const * fields,
 
 	for ( int i = 0; i < num_fields; i++ )
 		{
-		if ( vals[i]->present )
+		if ( vals[i]->present || include_unset_fields )
 			BuildJSON(writer, vals[i], fields[i]->name);
 		}
 
@@ -64,7 +63,7 @@ bool JSON::Describe(ODesc* desc, Value* val, const std::string& name) const
 		return false;
 		}
 
-	if ( ! val->present || name.empty() )
+	if ( (! val->present && ! include_unset_fields) || name.empty() )
 		return true;
 
 	rapidjson::Document doc;
@@ -79,8 +78,8 @@ bool JSON::Describe(ODesc* desc, Value* val, const std::string& name) const
 	return true;
 	}
 
-Value* JSON::ParseValue(const std::string& s, const std::string& name,
-                        TypeTag type, TypeTag subtype) const
+Value* JSON::ParseValue(const std::string& s, const std::string& name, TypeTag type,
+                        TypeTag subtype) const
 	{
 	GetThread()->Error("JSON formatter does not support parsing yet.");
 	return nullptr;
@@ -88,15 +87,15 @@ Value* JSON::ParseValue(const std::string& s, const std::string& name,
 
 void JSON::BuildJSON(NullDoubleWriter& writer, Value* val, const std::string& name) const
 	{
+	if ( ! name.empty() )
+		writer.Key(name);
+
 	if ( ! val->present )
 		{
 		writer.Null();
 		return;
 		}
 
-	if ( ! name.empty() )
-		writer.Key(name);
-
 	switch ( val->type )
 		{
 		case TYPE_BOOL:
@@ -140,7 +139,8 @@ void JSON::BuildJSON(NullDoubleWriter& writer, Value* val, const std::string& na
 				if ( ! gmtime_r(&the_time, &t) ||
 				     ! strftime(buffer, sizeof(buffer), "%Y-%m-%dT%H:%M:%S", &t) )
 					{
-					GetThread()->Error(GetThread()->Fmt("json formatter: failure getting time: (%lf)", val->val.double_val));
+					GetThread()->Error(GetThread()->Fmt(
+						"json formatter: failure getting time: (%lf)", val->val.double_val));
 					// This was a failure, doesn't really matter what gets put here
 					// but it should probably stand out...
 					writer.String("2000-01-01T00:00:00.000000");
@@ -164,7 +164,7 @@ void JSON::BuildJSON(NullDoubleWriter& writer, Value* val, const std::string& na
 			else if ( timestamps == TS_MILLIS )
 				{
 				// ElasticSearch uses milliseconds for timestamps
-				writer.Uint64((uint64_t) (val->val.double_val * 1000));
+				writer.Uint64((uint64_t)(val->val.double_val * 1000));
 				}
 
 			break;
@@ -176,7 +176,7 @@ void JSON::BuildJSON(NullDoubleWriter& writer, Value* val, const std::string& na
 		case TYPE_FUNC:
 			{
 			writer.String(util::json_escape_utf8(
-				              std::string(val->val.string_val.data, val->val.string_val.length)));
+				std::string(val->val.string_val.data, val->val.string_val.length)));
 			break;
 			}
 
@@ -184,7 +184,7 @@ void JSON::BuildJSON(NullDoubleWriter& writer, Value* val, const std::string& na
 			{
 			writer.StartArray();
 
-			for ( bro_int_t idx = 0; idx < val->val.set_val.size; idx++ )
+			for ( zeek_int_t idx = 0; idx < val->val.set_val.size; idx++ )
 				BuildJSON(writer, val->val.set_val.vals[idx]);
 
 			writer.EndArray();
@@ -195,7 +195,7 @@ void JSON::BuildJSON(NullDoubleWriter& writer, Value* val, const std::string& na
 			{
 			writer.StartArray();
 
-			for ( bro_int_t idx = 0; idx < val->val.vector_val.size; idx++ )
+			for ( zeek_int_t idx = 0; idx < val->val.vector_val.size; idx++ )
 				BuildJSON(writer, val->val.vector_val.vals[idx]);
 
 			writer.EndArray();
@@ -208,4 +208,4 @@ void JSON::BuildJSON(NullDoubleWriter& writer, Value* val, const std::string& na
 		}
 	}
 
-} // namespace zeek::threading::formatter
+	} // namespace zeek::threading::formatter
