@@ -15,13 +15,13 @@
 #endif
 
 #include <libgen.h>
-#include <stdarg.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
 #include <array>
 #include <cinttypes>
+#include <cstdarg>
 #include <cstdint>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
 #include <memory> // std::unique_ptr
 #include <string>
 #include <string_view>
@@ -29,18 +29,18 @@
 
 #ifdef TIME_WITH_SYS_TIME
 #include <sys/time.h>
-#include <time.h>
+#include <ctime>
 #else
 #ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
 #else
-#include <time.h>
+#include <ctime>
 #endif
 #endif
 
 #ifdef DEBUG
 
-#include <assert.h>
+#include <cassert>
 
 #define ASSERT(x) assert(x)
 #define DEBUG_MSG(x...) fprintf(stderr, x)
@@ -75,8 +75,12 @@ extern "C"
 #include "zeek/3rdparty/modp_numtoa.h"
 	}
 
-using bro_int_t = int64_t;
-using bro_uint_t = uint64_t;
+#include "zeek/3rdparty/ghc/filesystem.hpp"
+
+using zeek_int_t = int64_t;
+using zeek_uint_t = uint64_t;
+using bro_int_t [[deprecated("Remove in v6.1. Use zeek_int_t.")]] = zeek_int_t;
+using bro_uint_t [[deprecated("Remove in v6.1. Use zeek_uint_t.")]] = zeek_uint_t;
 
 #ifndef HAVE_STRCASESTR
 extern char* strcasestr(const char* s, const char* find);
@@ -91,6 +95,10 @@ namespace zeek
 class ODesc;
 class RecordVal;
 
+// Expose ghc::filesystem as zeek::filesystem until we can
+// switch to std::filesystem.
+namespace filesystem = ghc::filesystem;
+
 namespace util
 	{
 namespace detail
@@ -126,8 +134,6 @@ unsigned int initial_seed();
 // Returns true if the user explicitly set a seed via init_random_seed();
 extern bool have_random_seed();
 
-extern uint64_t rand64bit();
-
 /**
  * A platform-independent PRNG implementation.  Note that this is not
  * necessarily a "statistically sound" implementation as the main purpose is
@@ -169,7 +175,7 @@ void seed_random(unsigned int seed);
 void set_thread_name(const char* name, pthread_t tid = pthread_self());
 
 // Each event source that may generate events gets an internally unique ID.
-// This is always LOCAL for a local Bro. For remote event sources, it gets
+// This is always LOCAL for a local Zeek. For remote event sources, it gets
 // assigned by the RemoteSerializer.
 //
 // FIXME: Find a nicer place for this type definition.
@@ -424,6 +430,9 @@ extern struct timeval double_to_timeval(double t);
 // Return > 0 if tv_a > tv_b, 0 if equal, < 0 if tv_a < tv_b.
 extern int time_compare(struct timeval* tv_a, struct timeval* tv_b);
 
+// Returns the CPU time consumed to date.
+extern double curr_CPU_time();
+
 // Returns an integer that's very likely to be unique, even across Zeek
 // instances. The integer can be drawn from different pools, which is helpful
 // when the random number generator is seeded to be deterministic. In that
@@ -502,7 +511,7 @@ inline char* safe_strncpy(char* dest, const char* src, size_t n)
 
 // Memory alignment helpers.
 
-inline bool is_power_of_2(bro_uint_t x)
+inline bool is_power_of_2(zeek_uint_t x)
 	{
 	return ((x - 1) & x) == 0;
 	}
@@ -544,12 +553,6 @@ std::string canonify_name(const std::string& name);
  */
 void zeek_strerror_r(int zeek_errno, char* buf, size_t buflen);
 
-/**
- * A wrapper function for getenv().  Helps check for existence of
- * legacy environment variable names that map to the latest \a name.
- */
-[[deprecated("Remove in v5.1.  Use getenv() directly.")]] char* zeekenv(const char* name);
-
 /**
  * Escapes bytes in a string that are not valid UTF8 characters with \xYY format. Used
  * by the JSON writer and BIF methods.
@@ -568,5 +571,80 @@ std::string json_escape_utf8(const std::string& val, bool escape_printable_contr
 std::string json_escape_utf8(const char* val, size_t val_size,
                              bool escape_printable_controls = true);
 
+/**
+ * Splits a string at all occurrences of a delimiter. Successive occurrences
+ * of the delimiter will be split into multiple pieces.
+ *
+ * \note This function is not UTF8-aware.
+ */
+template <typename T> std::vector<T> split(T s, const T& delim)
+	{
+	// If there's no delimiter, return a copy of the existing string.
+	if ( delim.empty() )
+		return {T(s)};
+
+	// If the delimiter won't fit in the string, just return a copy as well.
+	if ( s.size() < delim.size() )
+		return {T(s)};
+
+	std::vector<T> l;
+
+	const bool ends_in_delim = (s.substr(s.size() - delim.size()) == delim);
+
+	do
+		{
+		size_t p = s.find(delim);
+		l.push_back(s.substr(0, p));
+		if ( p == std::string::npos )
+			break;
+
+		s = s.substr(p + delim.size());
+		} while ( ! s.empty() );
+
+	if ( ends_in_delim )
+		l.emplace_back(T{});
+
+	return l;
+	}
+
+/**
+ * Specialized version of util::split that allows for differing string and delimiter types,
+ * with the requirement that the delimiter must be of the same type as what is stored in the
+ * string type. For example, this allows passing a std::string as the string to split with
+ * a const char* delimiter.
+ *
+ * @param s the string to split
+ * @param delim the delimiter to split the string on
+ * @return a vector of containing the separate parts of the string.
+ */
+template <typename T, typename U = typename T::value_type*> std::vector<T> split(T s, U delim)
+	{
+	return split(s, T{delim});
+	}
+
+/**
+ * Specialized version of util::split that takes a const char* string and delimiter.
+ *
+ * @param s the string to split
+ * @param delim the delimiter to split the string on
+ * @return a vector of string_view objects containing the separate parts of the string.
+ */
+inline std::vector<std::string_view> split(const char* s, const char* delim)
+	{
+	return split(std::string_view(s), std::string_view(delim));
+	}
+
+/**
+ * Specialized version of util::split that takes a const wchar_t* string and delimiter.
+ *
+ * @param s the string to split
+ * @param delim the delimiter to split the string on
+ * @return a vector of wstring_view objects containing the separate parts of the string.
+ */
+inline std::vector<std::wstring_view> split(const wchar_t* s, const wchar_t* delim)
+	{
+	return split(std::wstring_view(s), std::wstring_view(delim));
+	}
+
 	} // namespace util
 	} // namespace zeek
