@@ -7,12 +7,12 @@
 #include <openssl/err.h>
 #include <openssl/opensslv.h>
 #include <openssl/ssl.h>
-#include <signal.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
 #include <sys/types.h>
 #include <unistd.h>
+#include <csignal>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
 #include <list>
 #include <optional>
 
@@ -456,7 +456,7 @@ static void atexit_handler()
 	util::detail::set_processing_status("TERMINATED", "atexit");
 	}
 
-static void bro_new_handler()
+static void zeek_new_handler()
 	{
 	out_of_memory("new");
 	}
@@ -498,7 +498,7 @@ static void set_signal_mask(bool do_block)
 SetupResult setup(int argc, char** argv, Options* zopts)
 	{
 	ZEEK_LSAN_DISABLE();
-	std::set_new_handler(bro_new_handler);
+	std::set_new_handler(zeek_new_handler);
 
 	auto zeek_exe_path = util::detail::get_exe_path(argv[0]);
 
@@ -642,7 +642,7 @@ SetupResult setup(int argc, char** argv, Options* zopts)
 	if ( r != SQLITE_OK )
 		reporter->Error("Failed to initialize sqlite3: %s", sqlite3_errstr(r));
 
-	timer_mgr = new PQ_TimerMgr();
+	timer_mgr = new TimerMgr();
 
 	auto zeekygen_cfg = options.zeekygen_config_file.value_or("");
 	zeekygen_mgr = new zeekygen::detail::Manager(zeekygen_cfg, zeek_argv[0]);
@@ -668,7 +668,7 @@ SetupResult setup(int argc, char** argv, Options* zopts)
 	if ( options.plugins_to_load.empty() && options.scripts_to_load.empty() &&
 	     options.script_options_to_set.empty() && ! options.pcap_file && ! options.interface &&
 	     ! options.identifier_to_print && ! command_line_policy && ! options.print_plugins &&
-	     ! options.supervisor_mode && ! Supervisor::ThisNode() && ! options.run_unit_tests )
+	     ! options.supervisor_mode && ! Supervisor::ThisNode() )
 		add_input_file("-");
 
 	for ( const auto& script_option : options.script_options_to_set )
@@ -715,6 +715,17 @@ SetupResult setup(int argc, char** argv, Options* zopts)
 
 	plugin_mgr->ActivateDynamicPlugins(! options.bare_mode);
 
+	// Delay the unit test until here so that plugins have been loaded.
+	if ( options.run_unit_tests )
+		{
+		set_signal_mask(false); // Allow ctrl-c to abort the tests early
+		doctest::Context context;
+		auto dargs = to_cargs(options.doctest_args);
+		context.applyCommandLine(dargs.size(), dargs.data());
+		ZEEK_LSAN_ENABLE();
+		exit(context.run());
+		}
+
 	// Print usage after plugins load so that any path extensions are properly shown.
 	if ( options.print_usage )
 		usage(argv[0], 0);
@@ -786,18 +797,6 @@ SetupResult setup(int argc, char** argv, Options* zopts)
 		init_net_var();
 		run_bif_initializers();
 
-		// Delay the unit test until here so that plugins and script
-		// types have been fully loaded.
-		if ( options.run_unit_tests )
-			{
-			set_signal_mask(false); // Allow ctrl-c to abort the tests early
-			doctest::Context context;
-			auto dargs = to_cargs(options.doctest_args);
-			context.applyCommandLine(dargs.size(), dargs.data());
-			ZEEK_LSAN_ENABLE();
-			exit(context.run());
-			}
-
 		// Assign the script_args for command line processing in Zeek scripts.
 		if ( ! options.script_args.empty() )
 			{
@@ -856,6 +855,20 @@ SetupResult setup(int argc, char** argv, Options* zopts)
 			exit(success ? 0 : 1);
 			}
 
+#ifdef DEBUG
+		// Check debug streams. Specifically that all plugin-
+		// streams are valid now that the active plugins are known.
+		std::set<std::string> active_plugins;
+		for ( const auto p : plugin_mgr->ActivePlugins() )
+			active_plugins.insert(p->Name());
+
+		if ( ! debug_logger.CheckStreams(active_plugins) )
+			{
+			early_shutdown();
+			exit(1);
+			}
+#endif
+
 		packet_mgr->InitPostScript(options.unprocessed_output_file.value_or(""));
 		analyzer_mgr->InitPostScript();
 		file_mgr->InitPostScript();
