@@ -1,19 +1,21 @@
 #include "Plugin.h"
+
+#include "LLCDemo.h"
+#include "RawLayer.h"
 #include "packet_analysis/Component.h"
 
-#include "RawLayer.h"
-#include "LLCDemo.h"
+namespace zeek::plugin::PacketDemo_Bar
+	{
 
-namespace zeek::plugin::PacketDemo_Bar {
-
-class Plugin : public zeek::plugin::Plugin {
+class Plugin : public zeek::plugin::Plugin
+	{
 public:
 	zeek::plugin::Configuration Configure()
 		{
-		AddComponent(new zeek::packet_analysis::Component("Raw_Layer",
-		                 zeek::packet_analysis::PacketDemo::RawLayer::Instantiate));
-		AddComponent(new zeek::packet_analysis::Component("LLC_Demo",
-		                 zeek::packet_analysis::PacketDemo::LLCDemo::Instantiate));
+		AddComponent(new zeek::packet_analysis::Component(
+			"Raw_Layer", zeek::packet_analysis::PacketDemo::RawLayer::Instantiate));
+		AddComponent(new zeek::packet_analysis::Component(
+			"LLC_Demo", zeek::packet_analysis::PacketDemo::LLCDemo::Instantiate));
 
 		zeek::plugin::Configuration config;
 		config.name = "PacketDemo::Bar";
@@ -24,6 +26,6 @@ public:
 		return config;
 		}
 
-} plugin;
+	} plugin;
 
-}
+	}
