@@ -3,19 +3,18 @@
 #include "zeek/packet_analysis/Analyzer.h"
 #include "zeek/packet_analysis/Component.h"
 
-namespace zeek::packet_analysis::PacketDemo {
+namespace zeek::packet_analysis::PacketDemo
+	{
 
-class RawLayer : public Analyzer {
+class RawLayer : public Analyzer
+	{
 public:
 	RawLayer();
 	~RawLayer() override = default;
 
 	bool AnalyzePacket(size_t len, const uint8_t* data, Packet* packet) override;
 
-	static AnalyzerPtr Instantiate()
-		{
-		return std::make_shared<RawLayer>();
-		}
-};
+	static AnalyzerPtr Instantiate() { return std::make_shared<RawLayer>(); }
+	};
 
-}
+	}
