@@ -3,9 +3,11 @@
 #include <Val.h>
 #include <iosource/PktDumper.h>
 
-namespace btest::plugin::Demo_Foo {
+namespace btest::plugin::Demo_Foo
+	{
 
-class Foo : public zeek::iosource::PktDumper {
+class Foo : public zeek::iosource::PktDumper
+	{
 public:
 	Foo(const std::string& path, bool is_live);
 	virtual ~Foo();
@@ -19,6 +21,6 @@ protected:
 
 private:
 	Properties props;
-};
+	};
 
-}
+	}
