@@ -4,13 +4,17 @@
 #include "Foo.h"
 #include "iosource/Component.h"
 
-namespace btest::plugin::Demo_Foo { Plugin plugin; }
+namespace btest::plugin::Demo_Foo
+	{
+Plugin plugin;
+	}
 
 using namespace btest::plugin::Demo_Foo;
 
 zeek::plugin::Configuration Plugin::Configure()
 	{
-	AddComponent(new zeek::iosource::PktDumperComponent("FooPktDumper", "foo", btest::plugin::Demo_Foo::Foo::Instantiate));
+	AddComponent(new zeek::iosource::PktDumperComponent("FooPktDumper", "foo",
+	                                                    btest::plugin::Demo_Foo::Foo::Instantiate));
 
 	zeek::plugin::Configuration config;
 	config.name = "Demo::Foo";
